module Text.Numerals.Languages.DutchSpec (
    spec
  ) where

import Data.Text(Text)
import Data.Time.LocalTime(TimeOfDay(TimeOfDay))

import Test.Hspec(Spec)
import Text.Numerals.Languages.Dutch(dutch)
import Text.Numerals.LanguageTest(testLanguage)

spec :: Spec
spec = testLanguage "Dutch" dutch (cardinals <> minusCardinals) ordinals shortOrdinals clockTime

cardinals :: [(Integer, Text)]
cardinals = [
    (0, "nul")
  , (1, "één")
  , (2, "twee")
  , (3, "drie")
  , (4, "vier")
  , (5, "vijf")
  , (6, "zes")
  , (7, "zeven")
  , (8, "acht")
  , (9, "negen")
  , (10, "tien")
  , (11, "elf")
  , (12, "twaalf")
  , (13, "dertien")
  , (14, "veertien")
  , (15, "vijftien")
  , (16, "zestien")
  , (17, "zeventien")
  , (18, "achttien")
  , (19, "negentien")
  , (20, "twintig")
  , (21, "eenentwintig")
  , (22, "tweeëntwintig")
  , (23, "drieëntwintig")
  , (24, "vierentwintig")
  , (25, "vijfentwintig")
  , (26, "zesentwintig")
  , (27, "zevenentwintig")
  , (28, "achtentwintig")
  , (29, "negenentwintig")
  , (30, "dertig")
  , (31, "eenendertig")
  , (32, "tweeëndertig")
  , (33, "drieëndertig")
  , (34, "vierendertig")
  , (35, "vijfendertig")
  , (36, "zesendertig")
  , (37, "zevenendertig")
  , (38, "achtendertig")
  , (39, "negenendertig")
  , (40, "veertig")
  , (41, "eenenveertig")
  , (42, "tweeënveertig")
  , (43, "drieënveertig")
  , (44, "vierenveertig")
  , (45, "vijfenveertig")
  , (46, "zesenveertig")
  , (47, "zevenenveertig")
  , (48, "achtenveertig")
  , (49, "negenenveertig")
  , (50, "vijftig")
  , (51, "eenenvijftig")
  , (52, "tweeënvijftig")
  , (53, "drieënvijftig")
  , (54, "vierenvijftig")
  , (55, "vijfenvijftig")
  , (56, "zesenvijftig")
  , (57, "zevenenvijftig")
  , (58, "achtenvijftig")
  , (59, "negenenvijftig")
  , (60, "zestig")
  , (61, "eenenzestig")
  , (62, "tweeënzestig")
  , (63, "drieënzestig")
  , (64, "vierenzestig")
  , (65, "vijfenzestig")
  , (66, "zesenzestig")
  , (67, "zevenenzestig")
  , (68, "achtenzestig")
  , (69, "negenenzestig")
  , (70, "zeventig")
  , (71, "eenenzeventig")
  , (72, "tweeënzeventig")
  , (73, "drieënzeventig")
  , (74, "vierenzeventig")
  , (75, "vijfenzeventig")
  , (76, "zesenzeventig")
  , (77, "zevenenzeventig")
  , (78, "achtenzeventig")
  , (79, "negenenzeventig")
  , (80, "tachtig")
  , (81, "eenentachtig")
  , (82, "tweeëntachtig")
  , (83, "drieëntachtig")
  , (84, "vierentachtig")
  , (85, "vijfentachtig")
  , (86, "zesentachtig")
  , (87, "zevenentachtig")
  , (88, "achtentachtig")
  , (89, "negenentachtig")
  , (90, "negentig")
  , (91, "eenennegentig")
  , (92, "tweeënnegentig")
  , (93, "drieënnegentig")
  , (94, "vierennegentig")
  , (95, "vijfennegentig")
  , (96, "zesennegentig")
  , (97, "zevenennegentig")
  , (98, "achtennegentig")
  , (99, "negenennegentig")
  , (100, "honderd")
  , (101, "honderdéén")
  , (102, "honderdtwee")
  , (103, "honderddrie")
  , (104, "honderdvier")
  , (105, "honderdvijf")
  , (106, "honderdzes")
  , (107, "honderdzeven")
  , (108, "honderdacht")
  , (109, "honderdnegen")
  , (110, "honderdtien")
  , (111, "honderdelf")
  , (112, "honderdtwaalf")
  , (113, "honderddertien")
  , (114, "honderdveertien")
  , (115, "honderdvijftien")
  , (116, "honderdzestien")
  , (117, "honderdzeventien")
  , (118, "honderdachttien")
  , (119, "honderdnegentien")
  , (120, "honderdtwintig")
  , (121, "honderdeenentwintig")
  , (122, "honderdtweeëntwintig")
  , (123, "honderddrieëntwintig")
  , (124, "honderdvierentwintig")
  , (125, "honderdvijfentwintig")
  , (126, "honderdzesentwintig")
  , (127, "honderdzevenentwintig")
  , (128, "honderdachtentwintig")
  , (129, "honderdnegenentwintig")
  , (130, "honderddertig")
  , (131, "honderdeenendertig")
  , (132, "honderdtweeëndertig")
  , (133, "honderddrieëndertig")
  , (134, "honderdvierendertig")
  , (135, "honderdvijfendertig")
  , (136, "honderdzesendertig")
  , (137, "honderdzevenendertig")
  , (138, "honderdachtendertig")
  , (139, "honderdnegenendertig")
  , (140, "honderdveertig")
  , (141, "honderdeenenveertig")
  , (142, "honderdtweeënveertig")
  , (143, "honderddrieënveertig")
  , (144, "honderdvierenveertig")
  , (145, "honderdvijfenveertig")
  , (146, "honderdzesenveertig")
  , (147, "honderdzevenenveertig")
  , (148, "honderdachtenveertig")
  , (149, "honderdnegenenveertig")
  , (150, "honderdvijftig")
  , (151, "honderdeenenvijftig")
  , (152, "honderdtweeënvijftig")
  , (153, "honderddrieënvijftig")
  , (154, "honderdvierenvijftig")
  , (155, "honderdvijfenvijftig")
  , (156, "honderdzesenvijftig")
  , (157, "honderdzevenenvijftig")
  , (158, "honderdachtenvijftig")
  , (159, "honderdnegenenvijftig")
  , (160, "honderdzestig")
  , (161, "honderdeenenzestig")
  , (162, "honderdtweeënzestig")
  , (163, "honderddrieënzestig")
  , (164, "honderdvierenzestig")
  , (165, "honderdvijfenzestig")
  , (166, "honderdzesenzestig")
  , (167, "honderdzevenenzestig")
  , (168, "honderdachtenzestig")
  , (169, "honderdnegenenzestig")
  , (170, "honderdzeventig")
  , (171, "honderdeenenzeventig")
  , (172, "honderdtweeënzeventig")
  , (173, "honderddrieënzeventig")
  , (174, "honderdvierenzeventig")
  , (175, "honderdvijfenzeventig")
  , (176, "honderdzesenzeventig")
  , (177, "honderdzevenenzeventig")
  , (178, "honderdachtenzeventig")
  , (179, "honderdnegenenzeventig")
  , (180, "honderdtachtig")
  , (181, "honderdeenentachtig")
  , (182, "honderdtweeëntachtig")
  , (183, "honderddrieëntachtig")
  , (184, "honderdvierentachtig")
  , (185, "honderdvijfentachtig")
  , (186, "honderdzesentachtig")
  , (187, "honderdzevenentachtig")
  , (188, "honderdachtentachtig")
  , (189, "honderdnegenentachtig")
  , (190, "honderdnegentig")
  , (191, "honderdeenennegentig")
  , (192, "honderdtweeënnegentig")
  , (193, "honderddrieënnegentig")
  , (194, "honderdvierennegentig")
  , (195, "honderdvijfennegentig")
  , (196, "honderdzesennegentig")
  , (197, "honderdzevenennegentig")
  , (198, "honderdachtennegentig")
  , (199, "honderdnegenennegentig")
  , (200, "tweehonderd")
  , (233, "tweehonderddrieëndertig")
  , (377, "driehonderdzevenenzeventig")
  , (610, "zeshonderdtien")
  , (987, "negenhonderdzevenentachtig")
  , (1597, "duizendvijfhonderdzevenennegentig")
  , (2584, "tweeduizendvijfhonderdvierentachtig")
  , (4181, "vierduizendhonderdeenentachtig")
  , (6765, "zesduizendzevenhonderdvijfenzestig")
  , (10946, "tienduizendnegenhonderdzesenveertig")
  , (17711, "zeventienduizendzevenhonderdelf")
  , (28657, "achtentwintigduizendzeshonderdzevenenvijftig")
  , (46368, "zesenveertigduizenddriehonderdachtenzestig")
  , (75025, "vijfenzeventigduizendvijfentwintig")
  , (121393, "honderdeenentwintigduizenddriehonderddrieënnegentig")
  , (196418, "honderdzesennegentigduizendvierhonderdachttien")
  , (317811, "driehonderdzeventienduizendachthonderdelf")
  , (514229, "vijfhonderdveertienduizendtweehonderdnegenentwintig")
  , (832040, "achthonderdtweeëndertigduizendveertig")
  , (1346269, "een miljoen driehonderdzesenveertigduizendtweehonderdnegenenzestig")
  , (2178309, "twee miljoen honderdachtenzeventigduizenddriehonderdnegen")
  , (3524578, "drie miljoen vijfhonderdvierentwintigduizendvijfhonderdachtenzeventig")
  , (5702887, "vijf miljoen zevenhonderdtweeduizendachthonderdzevenentachtig")
  , (9227465, "negen miljoen tweehonderdzevenentwintigduizendvierhonderdvijfenzestig")
  , (14930352, "veertien miljoen negenhonderddertigduizenddriehonderdtweeënvijftig")
  , (24157817, "vierentwintig miljoen honderdzevenenvijftigduizendachthonderdzeventien")
  , (39088169, "negenendertig miljoen achtentachtigduizendhonderdnegenenzestig")
  , (63245986, "drieënzestig miljoen tweehonderdvijfenveertigduizendnegenhonderdzesentachtig")
  , (102334155, "honderdtwee miljoen driehonderdvierendertigduizendhonderdvijfenvijftig")
  , (165580141, "honderdvijfenzestig miljoen vijfhonderdtachtigduizendhonderdeenenveertig")
  , (267914296, "tweehonderdzevenenzestig miljoen negenhonderdveertienduizendtweehonderdzesennegentig")
  , (433494437, "vierhonderddrieëndertig miljoen vierhonderdvierennegentigduizendvierhonderdzevenendertig")
  , (701408733, "zevenhonderdéén miljoen vierhonderdachtduizendzevenhonderddrieëndertig")
  , (1134903170, "een miljard honderdvierendertig miljoen negenhonderddrieduizendhonderdzeventig")
  , (1836311903, "een miljard achthonderdzesendertig miljoen driehonderdelfduizendnegenhonderddrie")
  , (2971215073, "twee miljard negenhonderdeenenzeventig miljoen tweehonderdvijftienduizenddrieënzeventig")
  , (4807526976, "vier miljard achthonderdzeven miljoen vijfhonderdzesentwintigduizendnegenhonderdzesenzeventig")
  , (7778742049, "zeven miljard zevenhonderdachtenzeventig miljoen zevenhonderdtweeënveertigduizendnegenenveertig")
  , (12586269025, "twaalf miljard vijfhonderdzesentachtig miljoen tweehonderdnegenenzestigduizendvijfentwintig")
  , (20365011074, "twintig miljard driehonderdvijfenzestig miljoen elfduizendvierenzeventig")
  , (32951280099, "tweeëndertig miljard negenhonderdeenenvijftig miljoen tweehonderdtachtigduizendnegenennegentig")
  , (53316291173, "drieënvijftig miljard driehonderdzestien miljoen tweehonderdeenennegentigduizendhonderddrieënzeventig")
  , (86267571272, "zesentachtig miljard tweehonderdzevenenzestig miljoen vijfhonderdeenenzeventigduizendtweehonderdtweeënzeventig")
  , (139583862445, "honderdnegenendertig miljard vijfhonderddrieëntachtig miljoen achthonderdtweeënzestigduizendvierhonderdvijfenveertig")
  , (225851433717, "tweehonderdvijfentwintig miljard achthonderdeenenvijftig miljoen vierhonderddrieëndertigduizendzevenhonderdzeventien")
  , (365435296162, "driehonderdvijfenzestig miljard vierhonderdvijfendertig miljoen tweehonderdzesennegentigduizendhonderdtweeënzestig")
  , (591286729879, "vijfhonderdeenennegentig miljard tweehonderdzesentachtig miljoen zevenhonderdnegenentwintigduizendachthonderdnegenenzeventig")
  , (956722026041, "negenhonderdzesenvijftig miljard zevenhonderdtweeëntwintig miljoen zesentwintigduizendeenenveertig")
  , (1548008755920, "een biljoen vijfhonderdachtenveertig miljard acht miljoen zevenhonderdvijfenvijftigduizendnegenhonderdtwintig")
  , (2504730781961, "twee biljoen vijfhonderdvier miljard zevenhonderddertig miljoen zevenhonderdeenentachtigduizendnegenhonderdeenenzestig")
  , (4052739537881, "vier biljoen tweeënvijftig miljard zevenhonderdnegenendertig miljoen vijfhonderdzevenendertigduizendachthonderdeenentachtig")
  , (6557470319842, "zes biljoen vijfhonderdzevenenvijftig miljard vierhonderdzeventig miljoen driehonderdnegentienduizendachthonderdtweeënveertig")
  , (10610209857723, "tien biljoen zeshonderdtien miljard tweehonderdnegen miljoen achthonderdzevenenvijftigduizendzevenhonderddrieëntwintig")
  , (17167680177565, "zeventien biljoen honderdzevenenzestig miljard zeshonderdtachtig miljoen honderdzevenenzeventigduizendvijfhonderdvijfenzestig")
  , (27777890035288, "zevenentwintig biljoen zevenhonderdzevenenzeventig miljard achthonderdnegentig miljoen vijfendertigduizendtweehonderdachtentachtig")
  , (44945570212853, "vierenveertig biljoen negenhonderdvijfenveertig miljard vijfhonderdzeventig miljoen tweehonderdtwaalfduizendachthonderddrieënvijftig")
  , (72723460248141, "tweeënzeventig biljoen zevenhonderddrieëntwintig miljard vierhonderdzestig miljoen tweehonderdachtenveertigduizendhonderdeenenveertig")
  , (117669030460994, "honderdzeventien biljoen zeshonderdnegenenzestig miljard dertig miljoen vierhonderdzestigduizendnegenhonderdvierennegentig")
  , (190392490709135, "honderdnegentig biljoen driehonderdtweeënnegentig miljard vierhonderdnegentig miljoen zevenhonderdnegenduizendhonderdvijfendertig")
  , (308061521170129, "driehonderdacht biljoen eenenzestig miljard vijfhonderdeenentwintig miljoen honderdzeventigduizendhonderdnegenentwintig")
  , (498454011879264, "vierhonderdachtennegentig biljoen vierhonderdvierenvijftig miljard elf miljoen achthonderdnegenenzeventigduizendtweehonderdvierenzestig")
  , (806515533049393, "achthonderdzes biljoen vijfhonderdvijftien miljard vijfhonderddrieëndertig miljoen negenenveertigduizenddriehonderddrieënnegentig")
  , (1304969544928657, "een biljard driehonderdvier biljoen negenhonderdnegenenzestig miljard vijfhonderdvierenveertig miljoen negenhonderdachtentwintigduizendzeshonderdzevenenvijftig")
  , (2111485077978050, "twee biljard honderdelf biljoen vierhonderdvijfentachtig miljard zevenenzeventig miljoen negenhonderdachtenzeventigduizendvijftig")
  , (3416454622906707, "drie biljard vierhonderdzestien biljoen vierhonderdvierenvijftig miljard zeshonderdtweeëntwintig miljoen negenhonderdzesduizendzevenhonderdzeven")
  , (5527939700884757, "vijf biljard vijfhonderdzevenentwintig biljoen negenhonderdnegenendertig miljard zevenhonderd miljoen achthonderdvierentachtigduizendzevenhonderdzevenenvijftig")
  , (8944394323791464, "acht biljard negenhonderdvierenveertig biljoen driehonderdvierennegentig miljard driehonderddrieëntwintig miljoen zevenhonderdeenennegentigduizendvierhonderdvierenzestig")
  , (14472334024676221, "veertien biljard vierhonderdtweeënzeventig biljoen driehonderdvierendertig miljard vierentwintig miljoen zeshonderdzesenzeventigduizendtweehonderdeenentwintig")
  , (23416728348467685, "drieëntwintig biljard vierhonderdzestien biljoen zevenhonderdachtentwintig miljard driehonderdachtenveertig miljoen vierhonderdzevenenzestigduizendzeshonderdvijfentachtig")
  , (37889062373143906, "zevenendertig biljard achthonderdnegenentachtig biljoen tweeënzestig miljard driehonderddrieënzeventig miljoen honderddrieënveertigduizendnegenhonderdzes")
  , (61305790721611591, "eenenzestig biljard driehonderdvijf biljoen zevenhonderdnegentig miljard zevenhonderdeenentwintig miljoen zeshonderdelfduizendvijfhonderdeenennegentig")
  , (99194853094755497, "negenennegentig biljard honderdvierennegentig biljoen achthonderddrieënvijftig miljard vierennegentig miljoen zevenhonderdvijfenvijftigduizendvierhonderdzevenennegentig")
  , (160500643816367088, "honderdzestig biljard vijfhonderd biljoen zeshonderddrieënveertig miljard achthonderdzestien miljoen driehonderdzevenenzestigduizendachtentachtig")
  , (259695496911122585, "tweehonderdnegenenvijftig biljard zeshonderdvijfennegentig biljoen vierhonderdzesennegentig miljard negenhonderdelf miljoen honderdtweeëntwintigduizendvijfhonderdvijfentachtig")
  , (420196140727489673, "vierhonderdtwintig biljard honderdzesennegentig biljoen honderdveertig miljard zevenhonderdzevenentwintig miljoen vierhonderdnegenentachtigduizendzeshonderddrieënzeventig")
  , (679891637638612258, "zeshonderdnegenenzeventig biljard achthonderdeenennegentig biljoen zeshonderdzevenendertig miljard zeshonderdachtendertig miljoen zeshonderdtwaalfduizendtweehonderdachtenvijftig")
  , (1100087778366101931, "een triljoen honderd biljard zevenentachtig biljoen zevenhonderdachtenzeventig miljard driehonderdzesenzestig miljoen honderdéénduizendnegenhonderdeenendertig")
  , (1779979416004714189, "een triljoen zevenhonderdnegenenzeventig biljard negenhonderdnegenenzeventig biljoen vierhonderdzestien miljard vier miljoen zevenhonderdveertienduizendhonderdnegenentachtig")
  , (2880067194370816120, "twee triljoen achthonderdtachtig biljard zevenenzestig biljoen honderdvierennegentig miljard driehonderdzeventig miljoen achthonderdzestienduizendhonderdtwintig")
  , (4660046610375530309, "vier triljoen zeshonderdzestig biljard zesenveertig biljoen zeshonderdtien miljard driehonderdvijfenzeventig miljoen vijfhonderddertigduizenddriehonderdnegen")
  , (7540113804746346429, "zeven triljoen vijfhonderdveertig biljard honderddertien biljoen achthonderdvier miljard zevenhonderdzesenveertig miljoen driehonderdzesenveertigduizendvierhonderdnegenentwintig")
  , (12200160415121876738, "twaalf triljoen tweehonderd biljard honderdzestig biljoen vierhonderdvijftien miljard honderdeenentwintig miljoen achthonderdzesenzeventigduizendzevenhonderdachtendertig")
  , (19740274219868223167, "negentien triljoen zevenhonderdveertig biljard tweehonderdvierenzeventig biljoen tweehonderdnegentien miljard achthonderdachtenzestig miljoen tweehonderddrieëntwintigduizendhonderdzevenenzestig")
  , (31940434634990099905, "eenendertig triljoen negenhonderdveertig biljard vierhonderdvierendertig biljoen zeshonderdvierendertig miljard negenhonderdnegentig miljoen negenennegentigduizendnegenhonderdvijf")
  , (51680708854858323072, "eenenvijftig triljoen zeshonderdtachtig biljard zevenhonderdacht biljoen achthonderdvierenvijftig miljard achthonderdachtenvijftig miljoen driehonderddrieëntwintigduizendtweeënzeventig")
  , (83621143489848422977, "drieëntachtig triljoen zeshonderdeenentwintig biljard honderddrieënveertig biljoen vierhonderdnegenentachtig miljard achthonderdachtenveertig miljoen vierhonderdtweeëntwintigduizendnegenhonderdzevenenzeventig")
  , (135301852344706746049, "honderdvijfendertig triljoen driehonderdéén biljard achthonderdtweeënvijftig biljoen driehonderdvierenveertig miljard zevenhonderdzes miljoen zevenhonderdzesenveertigduizendnegenenveertig")
  , (218922995834555169026, "tweehonderdachttien triljoen negenhonderdtweeëntwintig biljard negenhonderdvijfennegentig biljoen achthonderdvierendertig miljard vijfhonderdvijfenvijftig miljoen honderdnegenenzestigduizendzesentwintig")
  , (354224848179261915075, "driehonderdvierenvijftig triljoen tweehonderdvierentwintig biljard achthonderdachtenveertig biljoen honderdnegenenzeventig miljard tweehonderdeenenzestig miljoen negenhonderdvijftienduizendvijfenzeventig")
  , (573147844013817084101, "vijfhonderddrieënzeventig triljoen honderdzevenenveertig biljard achthonderdvierenveertig biljoen dertien miljard achthonderdzeventien miljoen vierentachtigduizendhonderdéén")
  , (927372692193078999176, "negenhonderdzevenentwintig triljoen driehonderdtweeënzeventig biljard zeshonderdtweeënnegentig biljoen honderddrieënnegentig miljard achtenzeventig miljoen negenhonderdnegenennegentigduizendhonderdzesenzeventig")
  , (1500520536206896083277, "een triljard vijfhonderd triljoen vijfhonderdtwintig biljard vijfhonderdzesendertig biljoen tweehonderdzes miljard achthonderdzesennegentig miljoen drieëntachtigduizendtweehonderdzevenenzeventig")
  , (2427893228399975082453, "twee triljard vierhonderdzevenentwintig triljoen achthonderddrieënnegentig biljard tweehonderdachtentwintig biljoen driehonderdnegenennegentig miljard negenhonderdvijfenzeventig miljoen tweeëntachtigduizendvierhonderddrieënvijftig")
  , (3928413764606871165730, "drie triljard negenhonderdachtentwintig triljoen vierhonderddertien biljard zevenhonderdvierenzestig biljoen zeshonderdzes miljard achthonderdeenenzeventig miljoen honderdvijfenzestigduizendzevenhonderddertig")
  , (6356306993006846248183, "zes triljard driehonderdzesenvijftig triljoen driehonderdzes biljard negenhonderddrieënnegentig biljoen zes miljard achthonderdzesenveertig miljoen tweehonderdachtenveertigduizendhonderddrieëntachtig")
  , (10284720757613717413913, "tien triljard tweehonderdvierentachtig triljoen zevenhonderdtwintig biljard zevenhonderdzevenenvijftig biljoen zeshonderddertien miljard zevenhonderdzeventien miljoen vierhonderddertienduizendnegenhonderddertien")
  , (16641027750620563662096, "zestien triljard zeshonderdeenenveertig triljoen zevenentwintig biljard zevenhonderdvijftig biljoen zeshonderdtwintig miljard vijfhonderddrieënzestig miljoen zeshonderdtweeënzestigduizendzesennegentig")
  , (26925748508234281076009, "zesentwintig triljard negenhonderdvijfentwintig triljoen zevenhonderdachtenveertig biljard vijfhonderdacht biljoen tweehonderdvierendertig miljard tweehonderdeenentachtig miljoen zesenzeventigduizendnegen")
  , (43566776258854844738105, "drieënveertig triljard vijfhonderdzesenzestig triljoen zevenhonderdzesenzeventig biljard tweehonderdachtenvijftig biljoen achthonderdvierenvijftig miljard achthonderdvierenveertig miljoen zevenhonderdachtendertigduizendhonderdvijf")
  , (70492524767089125814114, "zeventig triljard vierhonderdtweeënnegentig triljoen vijfhonderdvierentwintig biljard zevenhonderdzevenenzestig biljoen negenentachtig miljard honderdvijfentwintig miljoen achthonderdveertienduizendhonderdveertien")
  , (114059301025943970552219, "honderdveertien triljard negenenvijftig triljoen driehonderdéén biljard vijfentwintig biljoen negenhonderddrieënveertig miljard negenhonderdzeventig miljoen vijfhonderdtweeënvijftigduizendtweehonderdnegentien")
  , (1000, "duizend")
  , (10000, "tienduizend")
  , (100000, "honderdduizend")
  , (1000000, "een miljoen")
  , (10000000, "tien miljoen")
  , (100000000, "honderd miljoen")
  , (1000000000, "een miljard")
  , (10000000000, "tien miljard")
  , (100000000000, "honderd miljard")
  , (1000000000000, "een biljoen")
  , (10000000000000, "tien biljoen")
  , (100000000000000, "honderd biljoen")
  , (1000000000000000, "een biljard")
  , (10000000000000000, "tien biljard")
  , (100000000000000000, "honderd biljard")
  , (1000000000000000000, "een triljoen")
  , (10000000000000000000, "tien triljoen")
  , (100000000000000000000, "honderd triljoen")
  , (1000000000000000000000, "een triljard")
  , (10000000000000000000000, "tien triljard")
  , (100000000000000000000000, "honderd triljard")
  , (1000000000000000000000000, "een quadriljoen")
  ]

minusCardinals :: [(Integer, Text)]
minusCardinals = [
    (0, "nul")
  , (-1, "min één")
  , (-2, "min twee")
  , (-3, "min drie")
  , (-4, "min vier")
  , (-5, "min vijf")
  , (-6, "min zes")
  , (-7, "min zeven")
  , (-8, "min acht")
  , (-9, "min negen")
  , (-10, "min tien")
  , (-11, "min elf")
  , (-12, "min twaalf")
  , (-13, "min dertien")
  , (-14, "min veertien")
  , (-15, "min vijftien")
  , (-16, "min zestien")
  , (-17, "min zeventien")
  , (-18, "min achttien")
  , (-19, "min negentien")
  , (-20, "min twintig")
  , (-21, "min eenentwintig")
  , (-22, "min tweeëntwintig")
  , (-23, "min drieëntwintig")
  , (-24, "min vierentwintig")
  , (-25, "min vijfentwintig")
  , (-26, "min zesentwintig")
  , (-27, "min zevenentwintig")
  , (-28, "min achtentwintig")
  , (-29, "min negenentwintig")
  , (-30, "min dertig")
  , (-31, "min eenendertig")
  , (-32, "min tweeëndertig")
  , (-33, "min drieëndertig")
  , (-34, "min vierendertig")
  , (-35, "min vijfendertig")
  , (-36, "min zesendertig")
  , (-37, "min zevenendertig")
  , (-38, "min achtendertig")
  , (-39, "min negenendertig")
  , (-40, "min veertig")
  , (-41, "min eenenveertig")
  , (-42, "min tweeënveertig")
  , (-43, "min drieënveertig")
  , (-44, "min vierenveertig")
  , (-45, "min vijfenveertig")
  , (-46, "min zesenveertig")
  , (-47, "min zevenenveertig")
  , (-48, "min achtenveertig")
  , (-49, "min negenenveertig")
  , (-50, "min vijftig")
  , (-51, "min eenenvijftig")
  , (-52, "min tweeënvijftig")
  , (-53, "min drieënvijftig")
  , (-54, "min vierenvijftig")
  , (-55, "min vijfenvijftig")
  , (-56, "min zesenvijftig")
  , (-57, "min zevenenvijftig")
  , (-58, "min achtenvijftig")
  , (-59, "min negenenvijftig")
  , (-60, "min zestig")
  , (-61, "min eenenzestig")
  , (-62, "min tweeënzestig")
  , (-63, "min drieënzestig")
  , (-64, "min vierenzestig")
  , (-65, "min vijfenzestig")
  , (-66, "min zesenzestig")
  , (-67, "min zevenenzestig")
  , (-68, "min achtenzestig")
  , (-69, "min negenenzestig")
  , (-70, "min zeventig")
  , (-71, "min eenenzeventig")
  , (-72, "min tweeënzeventig")
  , (-73, "min drieënzeventig")
  , (-74, "min vierenzeventig")
  , (-75, "min vijfenzeventig")
  , (-76, "min zesenzeventig")
  , (-77, "min zevenenzeventig")
  , (-78, "min achtenzeventig")
  , (-79, "min negenenzeventig")
  , (-80, "min tachtig")
  , (-81, "min eenentachtig")
  , (-82, "min tweeëntachtig")
  , (-83, "min drieëntachtig")
  , (-84, "min vierentachtig")
  , (-85, "min vijfentachtig")
  , (-86, "min zesentachtig")
  , (-87, "min zevenentachtig")
  , (-88, "min achtentachtig")
  , (-89, "min negenentachtig")
  , (-90, "min negentig")
  , (-91, "min eenennegentig")
  , (-92, "min tweeënnegentig")
  , (-93, "min drieënnegentig")
  , (-94, "min vierennegentig")
  , (-95, "min vijfennegentig")
  , (-96, "min zesennegentig")
  , (-97, "min zevenennegentig")
  , (-98, "min achtennegentig")
  , (-99, "min negenennegentig")
  , (-100, "min honderd")
  , (-101, "min honderdéén")
  , (-102, "min honderdtwee")
  , (-103, "min honderddrie")
  , (-104, "min honderdvier")
  , (-105, "min honderdvijf")
  , (-106, "min honderdzes")
  , (-107, "min honderdzeven")
  , (-108, "min honderdacht")
  , (-109, "min honderdnegen")
  , (-110, "min honderdtien")
  , (-111, "min honderdelf")
  , (-112, "min honderdtwaalf")
  , (-113, "min honderddertien")
  , (-114, "min honderdveertien")
  , (-115, "min honderdvijftien")
  , (-116, "min honderdzestien")
  , (-117, "min honderdzeventien")
  , (-118, "min honderdachttien")
  , (-119, "min honderdnegentien")
  , (-120, "min honderdtwintig")
  , (-121, "min honderdeenentwintig")
  , (-122, "min honderdtweeëntwintig")
  , (-123, "min honderddrieëntwintig")
  , (-124, "min honderdvierentwintig")
  , (-125, "min honderdvijfentwintig")
  , (-126, "min honderdzesentwintig")
  , (-127, "min honderdzevenentwintig")
  , (-128, "min honderdachtentwintig")
  , (-129, "min honderdnegenentwintig")
  , (-130, "min honderddertig")
  , (-131, "min honderdeenendertig")
  , (-132, "min honderdtweeëndertig")
  , (-133, "min honderddrieëndertig")
  , (-134, "min honderdvierendertig")
  , (-135, "min honderdvijfendertig")
  , (-136, "min honderdzesendertig")
  , (-137, "min honderdzevenendertig")
  , (-138, "min honderdachtendertig")
  , (-139, "min honderdnegenendertig")
  , (-140, "min honderdveertig")
  , (-141, "min honderdeenenveertig")
  , (-142, "min honderdtweeënveertig")
  , (-143, "min honderddrieënveertig")
  , (-144, "min honderdvierenveertig")
  , (-145, "min honderdvijfenveertig")
  , (-146, "min honderdzesenveertig")
  , (-147, "min honderdzevenenveertig")
  , (-148, "min honderdachtenveertig")
  , (-149, "min honderdnegenenveertig")
  , (-150, "min honderdvijftig")
  , (-151, "min honderdeenenvijftig")
  , (-152, "min honderdtweeënvijftig")
  , (-153, "min honderddrieënvijftig")
  , (-154, "min honderdvierenvijftig")
  , (-155, "min honderdvijfenvijftig")
  , (-156, "min honderdzesenvijftig")
  , (-157, "min honderdzevenenvijftig")
  , (-158, "min honderdachtenvijftig")
  , (-159, "min honderdnegenenvijftig")
  , (-160, "min honderdzestig")
  , (-161, "min honderdeenenzestig")
  , (-162, "min honderdtweeënzestig")
  , (-163, "min honderddrieënzestig")
  , (-164, "min honderdvierenzestig")
  , (-165, "min honderdvijfenzestig")
  , (-166, "min honderdzesenzestig")
  , (-167, "min honderdzevenenzestig")
  , (-168, "min honderdachtenzestig")
  , (-169, "min honderdnegenenzestig")
  , (-170, "min honderdzeventig")
  , (-171, "min honderdeenenzeventig")
  , (-172, "min honderdtweeënzeventig")
  , (-173, "min honderddrieënzeventig")
  , (-174, "min honderdvierenzeventig")
  , (-175, "min honderdvijfenzeventig")
  , (-176, "min honderdzesenzeventig")
  , (-177, "min honderdzevenenzeventig")
  , (-178, "min honderdachtenzeventig")
  , (-179, "min honderdnegenenzeventig")
  , (-180, "min honderdtachtig")
  , (-181, "min honderdeenentachtig")
  , (-182, "min honderdtweeëntachtig")
  , (-183, "min honderddrieëntachtig")
  , (-184, "min honderdvierentachtig")
  , (-185, "min honderdvijfentachtig")
  , (-186, "min honderdzesentachtig")
  , (-187, "min honderdzevenentachtig")
  , (-188, "min honderdachtentachtig")
  , (-189, "min honderdnegenentachtig")
  , (-190, "min honderdnegentig")
  , (-191, "min honderdeenennegentig")
  , (-192, "min honderdtweeënnegentig")
  , (-193, "min honderddrieënnegentig")
  , (-194, "min honderdvierennegentig")
  , (-195, "min honderdvijfennegentig")
  , (-196, "min honderdzesennegentig")
  , (-197, "min honderdzevenennegentig")
  , (-198, "min honderdachtennegentig")
  , (-199, "min honderdnegenennegentig")
  , (-200, "min tweehonderd")
  ]


ordinals :: [(Integer, Text)]
ordinals = [
    (0, "nulde")
  , (1, "eerste")
  , (2, "tweede")
  , (3, "derde")
  , (4, "vierde")
  , (5, "vijfde")
  , (6, "zesde")
  , (7, "zevende")
  , (8, "achtste")
  , (9, "negende")
  , (10, "tiende")
  , (11, "elfde")
  , (12, "twaalfde")
  , (13, "dertiende")
  , (14, "veertiende")
  , (15, "vijftiende")
  , (16, "zestiende")
  , (17, "zeventiende")
  , (18, "achttiende")
  , (19, "negentiende")
  , (20, "twintigste")
  , (21, "eenentwintigste")
  , (22, "tweeëntwintigste")
  , (23, "drieëntwintigste")
  , (24, "vierentwintigste")
  , (25, "vijfentwintigste")
  , (26, "zesentwintigste")
  , (27, "zevenentwintigste")
  , (28, "achtentwintigste")
  , (29, "negenentwintigste")
  , (30, "dertigste")
  , (31, "eenendertigste")
  , (32, "tweeëndertigste")
  , (33, "drieëndertigste")
  , (34, "vierendertigste")
  , (35, "vijfendertigste")
  , (36, "zesendertigste")
  , (37, "zevenendertigste")
  , (38, "achtendertigste")
  , (39, "negenendertigste")
  , (40, "veertigste")
  , (41, "eenenveertigste")
  , (42, "tweeënveertigste")
  , (43, "drieënveertigste")
  , (44, "vierenveertigste")
  , (45, "vijfenveertigste")
  , (46, "zesenveertigste")
  , (47, "zevenenveertigste")
  , (48, "achtenveertigste")
  , (49, "negenenveertigste")
  , (50, "vijftigste")
  , (51, "eenenvijftigste")
  , (52, "tweeënvijftigste")
  , (53, "drieënvijftigste")
  , (54, "vierenvijftigste")
  , (55, "vijfenvijftigste")
  , (56, "zesenvijftigste")
  , (57, "zevenenvijftigste")
  , (58, "achtenvijftigste")
  , (59, "negenenvijftigste")
  , (60, "zestigste")
  , (61, "eenenzestigste")
  , (62, "tweeënzestigste")
  , (63, "drieënzestigste")
  , (64, "vierenzestigste")
  , (65, "vijfenzestigste")
  , (66, "zesenzestigste")
  , (67, "zevenenzestigste")
  , (68, "achtenzestigste")
  , (69, "negenenzestigste")
  , (70, "zeventigste")
  , (71, "eenenzeventigste")
  , (72, "tweeënzeventigste")
  , (73, "drieënzeventigste")
  , (74, "vierenzeventigste")
  , (75, "vijfenzeventigste")
  , (76, "zesenzeventigste")
  , (77, "zevenenzeventigste")
  , (78, "achtenzeventigste")
  , (79, "negenenzeventigste")
  , (80, "tachtigste")
  , (81, "eenentachtigste")
  , (82, "tweeëntachtigste")
  , (83, "drieëntachtigste")
  , (84, "vierentachtigste")
  , (85, "vijfentachtigste")
  , (86, "zesentachtigste")
  , (87, "zevenentachtigste")
  , (88, "achtentachtigste")
  , (89, "negenentachtigste")
  , (90, "negentigste")
  , (91, "eenennegentigste")
  , (92, "tweeënnegentigste")
  , (93, "drieënnegentigste")
  , (94, "vierennegentigste")
  , (95, "vijfennegentigste")
  , (96, "zesennegentigste")
  , (97, "zevenennegentigste")
  , (98, "achtennegentigste")
  , (99, "negenennegentigste")
  , (100, "honderdste")
  , (101, "honderdeerste")
  , (102, "honderdtweede")
  , (103, "honderdderde")
  , (104, "honderdvierde")
  , (105, "honderdvijfde")
  , (106, "honderdzesde")
  , (107, "honderdzevende")
  , (108, "honderdachtste")
  , (109, "honderdnegende")
  , (110, "honderdtiende")
  , (111, "honderdelfde")
  , (112, "honderdtwaalfde")
  , (113, "honderddertiende")
  , (114, "honderdveertiende")
  , (115, "honderdvijftiende")
  , (116, "honderdzestiende")
  , (117, "honderdzeventiende")
  , (118, "honderdachttiende")
  , (119, "honderdnegentiende")
  , (120, "honderdtwintigste")
  , (121, "honderdeenentwintigste")
  , (122, "honderdtweeëntwintigste")
  , (123, "honderddrieëntwintigste")
  , (124, "honderdvierentwintigste")
  , (125, "honderdvijfentwintigste")
  , (126, "honderdzesentwintigste")
  , (127, "honderdzevenentwintigste")
  , (128, "honderdachtentwintigste")
  , (129, "honderdnegenentwintigste")
  , (130, "honderddertigste")
  , (131, "honderdeenendertigste")
  , (132, "honderdtweeëndertigste")
  , (133, "honderddrieëndertigste")
  , (134, "honderdvierendertigste")
  , (135, "honderdvijfendertigste")
  , (136, "honderdzesendertigste")
  , (137, "honderdzevenendertigste")
  , (138, "honderdachtendertigste")
  , (139, "honderdnegenendertigste")
  , (140, "honderdveertigste")
  , (141, "honderdeenenveertigste")
  , (142, "honderdtweeënveertigste")
  , (143, "honderddrieënveertigste")
  , (144, "honderdvierenveertigste")
  , (145, "honderdvijfenveertigste")
  , (146, "honderdzesenveertigste")
  , (147, "honderdzevenenveertigste")
  , (148, "honderdachtenveertigste")
  , (149, "honderdnegenenveertigste")
  , (150, "honderdvijftigste")
  , (151, "honderdeenenvijftigste")
  , (152, "honderdtweeënvijftigste")
  , (153, "honderddrieënvijftigste")
  , (154, "honderdvierenvijftigste")
  , (155, "honderdvijfenvijftigste")
  , (156, "honderdzesenvijftigste")
  , (157, "honderdzevenenvijftigste")
  , (158, "honderdachtenvijftigste")
  , (159, "honderdnegenenvijftigste")
  , (160, "honderdzestigste")
  , (161, "honderdeenenzestigste")
  , (162, "honderdtweeënzestigste")
  , (163, "honderddrieënzestigste")
  , (164, "honderdvierenzestigste")
  , (165, "honderdvijfenzestigste")
  , (166, "honderdzesenzestigste")
  , (167, "honderdzevenenzestigste")
  , (168, "honderdachtenzestigste")
  , (169, "honderdnegenenzestigste")
  , (170, "honderdzeventigste")
  , (171, "honderdeenenzeventigste")
  , (172, "honderdtweeënzeventigste")
  , (173, "honderddrieënzeventigste")
  , (174, "honderdvierenzeventigste")
  , (175, "honderdvijfenzeventigste")
  , (176, "honderdzesenzeventigste")
  , (177, "honderdzevenenzeventigste")
  , (178, "honderdachtenzeventigste")
  , (179, "honderdnegenenzeventigste")
  , (180, "honderdtachtigste")
  , (181, "honderdeenentachtigste")
  , (182, "honderdtweeëntachtigste")
  , (183, "honderddrieëntachtigste")
  , (184, "honderdvierentachtigste")
  , (185, "honderdvijfentachtigste")
  , (186, "honderdzesentachtigste")
  , (187, "honderdzevenentachtigste")
  , (188, "honderdachtentachtigste")
  , (189, "honderdnegenentachtigste")
  , (190, "honderdnegentigste")
  , (191, "honderdeenennegentigste")
  , (192, "honderdtweeënnegentigste")
  , (193, "honderddrieënnegentigste")
  , (194, "honderdvierennegentigste")
  , (195, "honderdvijfennegentigste")
  , (196, "honderdzesennegentigste")
  , (197, "honderdzevenennegentigste")
  , (198, "honderdachtennegentigste")
  , (199, "honderdnegenennegentigste")
  , (200, "tweehonderdste")
  , (233, "tweehonderddrieëndertigste")
  , (377, "driehonderdzevenenzeventigste")
  , (610, "zeshonderdtiende")
  , (987, "negenhonderdzevenentachtigste")
  , (1597, "duizendvijfhonderdzevenennegentigste")
  , (2584, "tweeduizendvijfhonderdvierentachtigste")
  , (4181, "vierduizendhonderdeenentachtigste")
  , (6765, "zesduizendzevenhonderdvijfenzestigste")
  , (10946, "tienduizendnegenhonderdzesenveertigste")
  , (17711, "zeventienduizendzevenhonderdelfde")
  , (28657, "achtentwintigduizendzeshonderdzevenenvijftigste")
  , (46368, "zesenveertigduizenddriehonderdachtenzestigste")
  , (75025, "vijfenzeventigduizendvijfentwintigste")
  , (121393, "honderdeenentwintigduizenddriehonderddrieënnegentigste")
  , (196418, "honderdzesennegentigduizendvierhonderdachttiende")
  , (317811, "driehonderdzeventienduizendachthonderdelfde")
  , (514229, "vijfhonderdveertienduizendtweehonderdnegenentwintigste")
  , (832040, "achthonderdtweeëndertigduizendveertigste")
  , (1346269, "een miljoen driehonderdzesenveertigduizendtweehonderdnegenenzestigste")
  , (2178309, "twee miljoen honderdachtenzeventigduizenddriehonderdnegende")
  , (3524578, "drie miljoen vijfhonderdvierentwintigduizendvijfhonderdachtenzeventigste")
  , (5702887, "vijf miljoen zevenhonderdtweeduizendachthonderdzevenentachtigste")
  , (9227465, "negen miljoen tweehonderdzevenentwintigduizendvierhonderdvijfenzestigste")
  , (14930352, "veertien miljoen negenhonderddertigduizenddriehonderdtweeënvijftigste")
  , (24157817, "vierentwintig miljoen honderdzevenenvijftigduizendachthonderdzeventiende")
  , (39088169, "negenendertig miljoen achtentachtigduizendhonderdnegenenzestigste")
  , (63245986, "drieënzestig miljoen tweehonderdvijfenveertigduizendnegenhonderdzesentachtigste")
  , (102334155, "honderdtwee miljoen driehonderdvierendertigduizendhonderdvijfenvijftigste")
  , (165580141, "honderdvijfenzestig miljoen vijfhonderdtachtigduizendhonderdeenenveertigste")
  , (267914296, "tweehonderdzevenenzestig miljoen negenhonderdveertienduizendtweehonderdzesennegentigste")
  , (433494437, "vierhonderddrieëndertig miljoen vierhonderdvierennegentigduizendvierhonderdzevenendertigste")
  , (701408733, "zevenhonderdéén miljoen vierhonderdachtduizendzevenhonderddrieëndertigste")
  , (1134903170, "een miljard honderdvierendertig miljoen negenhonderddrieduizendhonderdzeventigste")
  , (1836311903, "een miljard achthonderdzesendertig miljoen driehonderdelfduizendnegenhonderdderde")
  , (2971215073, "twee miljard negenhonderdeenenzeventig miljoen tweehonderdvijftienduizenddrieënzeventigste")
  , (4807526976, "vier miljard achthonderdzeven miljoen vijfhonderdzesentwintigduizendnegenhonderdzesenzeventigste")
  , (7778742049, "zeven miljard zevenhonderdachtenzeventig miljoen zevenhonderdtweeënveertigduizendnegenenveertigste")
  , (12586269025, "twaalf miljard vijfhonderdzesentachtig miljoen tweehonderdnegenenzestigduizendvijfentwintigste")
  , (20365011074, "twintig miljard driehonderdvijfenzestig miljoen elfduizendvierenzeventigste")
  , (32951280099, "tweeëndertig miljard negenhonderdeenenvijftig miljoen tweehonderdtachtigduizendnegenennegentigste")
  , (53316291173, "drieënvijftig miljard driehonderdzestien miljoen tweehonderdeenennegentigduizendhonderddrieënzeventigste")
  , (86267571272, "zesentachtig miljard tweehonderdzevenenzestig miljoen vijfhonderdeenenzeventigduizendtweehonderdtweeënzeventigste")
  , (139583862445, "honderdnegenendertig miljard vijfhonderddrieëntachtig miljoen achthonderdtweeënzestigduizendvierhonderdvijfenveertigste")
  , (225851433717, "tweehonderdvijfentwintig miljard achthonderdeenenvijftig miljoen vierhonderddrieëndertigduizendzevenhonderdzeventiende")
  , (365435296162, "driehonderdvijfenzestig miljard vierhonderdvijfendertig miljoen tweehonderdzesennegentigduizendhonderdtweeënzestigste")
  , (591286729879, "vijfhonderdeenennegentig miljard tweehonderdzesentachtig miljoen zevenhonderdnegenentwintigduizendachthonderdnegenenzeventigste")
  , (956722026041, "negenhonderdzesenvijftig miljard zevenhonderdtweeëntwintig miljoen zesentwintigduizendeenenveertigste")
  , (1548008755920, "een biljoen vijfhonderdachtenveertig miljard acht miljoen zevenhonderdvijfenvijftigduizendnegenhonderdtwintigste")
  , (2504730781961, "twee biljoen vijfhonderdvier miljard zevenhonderddertig miljoen zevenhonderdeenentachtigduizendnegenhonderdeenenzestigste")
  , (4052739537881, "vier biljoen tweeënvijftig miljard zevenhonderdnegenendertig miljoen vijfhonderdzevenendertigduizendachthonderdeenentachtigste")
  , (6557470319842, "zes biljoen vijfhonderdzevenenvijftig miljard vierhonderdzeventig miljoen driehonderdnegentienduizendachthonderdtweeënveertigste")
  , (10610209857723, "tien biljoen zeshonderdtien miljard tweehonderdnegen miljoen achthonderdzevenenvijftigduizendzevenhonderddrieëntwintigste")
  , (17167680177565, "zeventien biljoen honderdzevenenzestig miljard zeshonderdtachtig miljoen honderdzevenenzeventigduizendvijfhonderdvijfenzestigste")
  , (27777890035288, "zevenentwintig biljoen zevenhonderdzevenenzeventig miljard achthonderdnegentig miljoen vijfendertigduizendtweehonderdachtentachtigste")
  , (44945570212853, "vierenveertig biljoen negenhonderdvijfenveertig miljard vijfhonderdzeventig miljoen tweehonderdtwaalfduizendachthonderddrieënvijftigste")
  , (72723460248141, "tweeënzeventig biljoen zevenhonderddrieëntwintig miljard vierhonderdzestig miljoen tweehonderdachtenveertigduizendhonderdeenenveertigste")
  , (117669030460994, "honderdzeventien biljoen zeshonderdnegenenzestig miljard dertig miljoen vierhonderdzestigduizendnegenhonderdvierennegentigste")
  , (190392490709135, "honderdnegentig biljoen driehonderdtweeënnegentig miljard vierhonderdnegentig miljoen zevenhonderdnegenduizendhonderdvijfendertigste")
  , (308061521170129, "driehonderdacht biljoen eenenzestig miljard vijfhonderdeenentwintig miljoen honderdzeventigduizendhonderdnegenentwintigste")
  , (498454011879264, "vierhonderdachtennegentig biljoen vierhonderdvierenvijftig miljard elf miljoen achthonderdnegenenzeventigduizendtweehonderdvierenzestigste")
  , (806515533049393, "achthonderdzes biljoen vijfhonderdvijftien miljard vijfhonderddrieëndertig miljoen negenenveertigduizenddriehonderddrieënnegentigste")
  , (1304969544928657, "een biljard driehonderdvier biljoen negenhonderdnegenenzestig miljard vijfhonderdvierenveertig miljoen negenhonderdachtentwintigduizendzeshonderdzevenenvijftigste")
  , (2111485077978050, "twee biljard honderdelf biljoen vierhonderdvijfentachtig miljard zevenenzeventig miljoen negenhonderdachtenzeventigduizendvijftigste")
  , (3416454622906707, "drie biljard vierhonderdzestien biljoen vierhonderdvierenvijftig miljard zeshonderdtweeëntwintig miljoen negenhonderdzesduizendzevenhonderdzevende")
  , (5527939700884757, "vijf biljard vijfhonderdzevenentwintig biljoen negenhonderdnegenendertig miljard zevenhonderd miljoen achthonderdvierentachtigduizendzevenhonderdzevenenvijftigste")
  , (8944394323791464, "acht biljard negenhonderdvierenveertig biljoen driehonderdvierennegentig miljard driehonderddrieëntwintig miljoen zevenhonderdeenennegentigduizendvierhonderdvierenzestigste")
  , (14472334024676221, "veertien biljard vierhonderdtweeënzeventig biljoen driehonderdvierendertig miljard vierentwintig miljoen zeshonderdzesenzeventigduizendtweehonderdeenentwintigste")
  , (23416728348467685, "drieëntwintig biljard vierhonderdzestien biljoen zevenhonderdachtentwintig miljard driehonderdachtenveertig miljoen vierhonderdzevenenzestigduizendzeshonderdvijfentachtigste")
  , (37889062373143906, "zevenendertig biljard achthonderdnegenentachtig biljoen tweeënzestig miljard driehonderddrieënzeventig miljoen honderddrieënveertigduizendnegenhonderdzesde")
  , (61305790721611591, "eenenzestig biljard driehonderdvijf biljoen zevenhonderdnegentig miljard zevenhonderdeenentwintig miljoen zeshonderdelfduizendvijfhonderdeenennegentigste")
  , (99194853094755497, "negenennegentig biljard honderdvierennegentig biljoen achthonderddrieënvijftig miljard vierennegentig miljoen zevenhonderdvijfenvijftigduizendvierhonderdzevenennegentigste")
  , (160500643816367088, "honderdzestig biljard vijfhonderd biljoen zeshonderddrieënveertig miljard achthonderdzestien miljoen driehonderdzevenenzestigduizendachtentachtigste")
  , (259695496911122585, "tweehonderdnegenenvijftig biljard zeshonderdvijfennegentig biljoen vierhonderdzesennegentig miljard negenhonderdelf miljoen honderdtweeëntwintigduizendvijfhonderdvijfentachtigste")
  , (420196140727489673, "vierhonderdtwintig biljard honderdzesennegentig biljoen honderdveertig miljard zevenhonderdzevenentwintig miljoen vierhonderdnegenentachtigduizendzeshonderddrieënzeventigste")
  , (679891637638612258, "zeshonderdnegenenzeventig biljard achthonderdeenennegentig biljoen zeshonderdzevenendertig miljard zeshonderdachtendertig miljoen zeshonderdtwaalfduizendtweehonderdachtenvijftigste")
  , (1100087778366101931, "een triljoen honderd biljard zevenentachtig biljoen zevenhonderdachtenzeventig miljard driehonderdzesenzestig miljoen honderdéénduizendnegenhonderdeenendertigste")
  , (1779979416004714189, "een triljoen zevenhonderdnegenenzeventig biljard negenhonderdnegenenzeventig biljoen vierhonderdzestien miljard vier miljoen zevenhonderdveertienduizendhonderdnegenentachtigste")
  , (2880067194370816120, "twee triljoen achthonderdtachtig biljard zevenenzestig biljoen honderdvierennegentig miljard driehonderdzeventig miljoen achthonderdzestienduizendhonderdtwintigste")
  , (4660046610375530309, "vier triljoen zeshonderdzestig biljard zesenveertig biljoen zeshonderdtien miljard driehonderdvijfenzeventig miljoen vijfhonderddertigduizenddriehonderdnegende")
  , (7540113804746346429, "zeven triljoen vijfhonderdveertig biljard honderddertien biljoen achthonderdvier miljard zevenhonderdzesenveertig miljoen driehonderdzesenveertigduizendvierhonderdnegenentwintigste")
  , (12200160415121876738, "twaalf triljoen tweehonderd biljard honderdzestig biljoen vierhonderdvijftien miljard honderdeenentwintig miljoen achthonderdzesenzeventigduizendzevenhonderdachtendertigste")
  , (19740274219868223167, "negentien triljoen zevenhonderdveertig biljard tweehonderdvierenzeventig biljoen tweehonderdnegentien miljard achthonderdachtenzestig miljoen tweehonderddrieëntwintigduizendhonderdzevenenzestigste")
  , (31940434634990099905, "eenendertig triljoen negenhonderdveertig biljard vierhonderdvierendertig biljoen zeshonderdvierendertig miljard negenhonderdnegentig miljoen negenennegentigduizendnegenhonderdvijfde")
  , (51680708854858323072, "eenenvijftig triljoen zeshonderdtachtig biljard zevenhonderdacht biljoen achthonderdvierenvijftig miljard achthonderdachtenvijftig miljoen driehonderddrieëntwintigduizendtweeënzeventigste")
  , (83621143489848422977, "drieëntachtig triljoen zeshonderdeenentwintig biljard honderddrieënveertig biljoen vierhonderdnegenentachtig miljard achthonderdachtenveertig miljoen vierhonderdtweeëntwintigduizendnegenhonderdzevenenzeventigste")
  , (135301852344706746049, "honderdvijfendertig triljoen driehonderdéén biljard achthonderdtweeënvijftig biljoen driehonderdvierenveertig miljard zevenhonderdzes miljoen zevenhonderdzesenveertigduizendnegenenveertigste")
  , (218922995834555169026, "tweehonderdachttien triljoen negenhonderdtweeëntwintig biljard negenhonderdvijfennegentig biljoen achthonderdvierendertig miljard vijfhonderdvijfenvijftig miljoen honderdnegenenzestigduizendzesentwintigste")
  , (354224848179261915075, "driehonderdvierenvijftig triljoen tweehonderdvierentwintig biljard achthonderdachtenveertig biljoen honderdnegenenzeventig miljard tweehonderdeenenzestig miljoen negenhonderdvijftienduizendvijfenzeventigste")
  , (573147844013817084101, "vijfhonderddrieënzeventig triljoen honderdzevenenveertig biljard achthonderdvierenveertig biljoen dertien miljard achthonderdzeventien miljoen vierentachtigduizendhonderdeerste")
  , (927372692193078999176, "negenhonderdzevenentwintig triljoen driehonderdtweeënzeventig biljard zeshonderdtweeënnegentig biljoen honderddrieënnegentig miljard achtenzeventig miljoen negenhonderdnegenennegentigduizendhonderdzesenzeventigste")
  , (1500520536206896083277, "een triljard vijfhonderd triljoen vijfhonderdtwintig biljard vijfhonderdzesendertig biljoen tweehonderdzes miljard achthonderdzesennegentig miljoen drieëntachtigduizendtweehonderdzevenenzeventigste")
  , (2427893228399975082453, "twee triljard vierhonderdzevenentwintig triljoen achthonderddrieënnegentig biljard tweehonderdachtentwintig biljoen driehonderdnegenennegentig miljard negenhonderdvijfenzeventig miljoen tweeëntachtigduizendvierhonderddrieënvijftigste")
  , (3928413764606871165730, "drie triljard negenhonderdachtentwintig triljoen vierhonderddertien biljard zevenhonderdvierenzestig biljoen zeshonderdzes miljard achthonderdeenenzeventig miljoen honderdvijfenzestigduizendzevenhonderddertigste")
  , (6356306993006846248183, "zes triljard driehonderdzesenvijftig triljoen driehonderdzes biljard negenhonderddrieënnegentig biljoen zes miljard achthonderdzesenveertig miljoen tweehonderdachtenveertigduizendhonderddrieëntachtigste")
  , (10284720757613717413913, "tien triljard tweehonderdvierentachtig triljoen zevenhonderdtwintig biljard zevenhonderdzevenenvijftig biljoen zeshonderddertien miljard zevenhonderdzeventien miljoen vierhonderddertienduizendnegenhonderddertiende")
  , (16641027750620563662096, "zestien triljard zeshonderdeenenveertig triljoen zevenentwintig biljard zevenhonderdvijftig biljoen zeshonderdtwintig miljard vijfhonderddrieënzestig miljoen zeshonderdtweeënzestigduizendzesennegentigste")
  , (26925748508234281076009, "zesentwintig triljard negenhonderdvijfentwintig triljoen zevenhonderdachtenveertig biljard vijfhonderdacht biljoen tweehonderdvierendertig miljard tweehonderdeenentachtig miljoen zesenzeventigduizendnegende")
  , (43566776258854844738105, "drieënveertig triljard vijfhonderdzesenzestig triljoen zevenhonderdzesenzeventig biljard tweehonderdachtenvijftig biljoen achthonderdvierenvijftig miljard achthonderdvierenveertig miljoen zevenhonderdachtendertigduizendhonderdvijfde")
  , (70492524767089125814114, "zeventig triljard vierhonderdtweeënnegentig triljoen vijfhonderdvierentwintig biljard zevenhonderdzevenenzestig biljoen negenentachtig miljard honderdvijfentwintig miljoen achthonderdveertienduizendhonderdveertiende")
  , (114059301025943970552219, "honderdveertien triljard negenenvijftig triljoen driehonderdéén biljard vijfentwintig biljoen negenhonderddrieënveertig miljard negenhonderdzeventig miljoen vijfhonderdtweeënvijftigduizendtweehonderdnegentiende")
  , (1000, "duizendste")
  , (10000, "tienduizendste")
  , (100000, "honderdduizendste")
  , (1000000, "een miljoenste")
  , (10000000, "tien miljoenste")
  , (100000000, "honderd miljoenste")
  , (1000000000, "een miljardste")
  , (10000000000, "tien miljardste")
  , (100000000000, "honderd miljardste")
  , (1000000000000, "een biljoenste")
  , (10000000000000, "tien biljoenste")
  , (100000000000000, "honderd biljoenste")
  , (1000000000000000, "een biljardste")
  , (10000000000000000, "tien biljardste")
  , (100000000000000000, "honderd biljardste")
  , (1000000000000000000, "een triljoenste")
  , (10000000000000000000, "tien triljoenste")
  , (100000000000000000000, "honderd triljoenste")
  , (1000000000000000000000, "een triljardste")
  , (10000000000000000000000, "tien triljardste")
  , (100000000000000000000000, "honderd triljardste")
  , (1000000000000000000000000, "een quadriljoenste")
  ]

shortOrdinals :: [(Integer, Text)]
shortOrdinals = [
    (0, "0e")
  , (1, "1e")
  , (2, "2e")
  , (3, "3e")
  , (4, "4e")
  , (5, "5e")
  , (6, "6e")
  , (7, "7e")
  , (8, "8e")
  , (9, "9e")
  , (10, "10e")
  , (11, "11e")
  , (12, "12e")
  , (13, "13e")
  , (14, "14e")
  , (15, "15e")
  , (16, "16e")
  , (17, "17e")
  , (18, "18e")
  , (19, "19e")
  , (20, "20e")
  , (21, "21e")
  , (22, "22e")
  , (23, "23e")
  , (24, "24e")
  , (25, "25e")
  , (26, "26e")
  , (27, "27e")
  , (28, "28e")
  , (29, "29e")
  , (30, "30e")
  , (31, "31e")
  , (32, "32e")
  , (33, "33e")
  , (34, "34e")
  , (35, "35e")
  , (36, "36e")
  , (37, "37e")
  , (38, "38e")
  , (39, "39e")
  , (40, "40e")
  , (41, "41e")
  , (42, "42e")
  , (43, "43e")
  , (44, "44e")
  , (45, "45e")
  , (46, "46e")
  , (47, "47e")
  , (48, "48e")
  , (49, "49e")
  , (50, "50e")
  , (51, "51e")
  , (52, "52e")
  , (53, "53e")
  , (54, "54e")
  , (55, "55e")
  , (56, "56e")
  , (57, "57e")
  , (58, "58e")
  , (59, "59e")
  , (60, "60e")
  , (61, "61e")
  , (62, "62e")
  , (63, "63e")
  , (64, "64e")
  , (65, "65e")
  , (66, "66e")
  , (67, "67e")
  , (68, "68e")
  , (69, "69e")
  , (70, "70e")
  , (71, "71e")
  , (72, "72e")
  , (73, "73e")
  , (74, "74e")
  , (75, "75e")
  , (76, "76e")
  , (77, "77e")
  , (78, "78e")
  , (79, "79e")
  , (80, "80e")
  , (81, "81e")
  , (82, "82e")
  , (83, "83e")
  , (84, "84e")
  , (85, "85e")
  , (86, "86e")
  , (87, "87e")
  , (88, "88e")
  , (89, "89e")
  , (90, "90e")
  , (91, "91e")
  , (92, "92e")
  , (93, "93e")
  , (94, "94e")
  , (95, "95e")
  , (96, "96e")
  , (97, "97e")
  , (98, "98e")
  , (99, "99e")
  , (100, "100e")
  , (101, "101e")
  , (102, "102e")
  , (103, "103e")
  , (104, "104e")
  , (105, "105e")
  , (106, "106e")
  , (107, "107e")
  , (108, "108e")
  , (109, "109e")
  , (110, "110e")
  , (111, "111e")
  , (112, "112e")
  , (113, "113e")
  , (114, "114e")
  , (115, "115e")
  , (116, "116e")
  , (117, "117e")
  , (118, "118e")
  , (119, "119e")
  , (120, "120e")
  , (121, "121e")
  , (122, "122e")
  , (123, "123e")
  , (124, "124e")
  , (125, "125e")
  , (126, "126e")
  , (127, "127e")
  , (128, "128e")
  , (129, "129e")
  , (130, "130e")
  , (131, "131e")
  , (132, "132e")
  , (133, "133e")
  , (134, "134e")
  , (135, "135e")
  , (136, "136e")
  , (137, "137e")
  , (138, "138e")
  , (139, "139e")
  , (140, "140e")
  , (141, "141e")
  , (142, "142e")
  , (143, "143e")
  , (144, "144e")
  , (145, "145e")
  , (146, "146e")
  , (147, "147e")
  , (148, "148e")
  , (149, "149e")
  , (150, "150e")
  , (151, "151e")
  , (152, "152e")
  , (153, "153e")
  , (154, "154e")
  , (155, "155e")
  , (156, "156e")
  , (157, "157e")
  , (158, "158e")
  , (159, "159e")
  , (160, "160e")
  , (161, "161e")
  , (162, "162e")
  , (163, "163e")
  , (164, "164e")
  , (165, "165e")
  , (166, "166e")
  , (167, "167e")
  , (168, "168e")
  , (169, "169e")
  , (170, "170e")
  , (171, "171e")
  , (172, "172e")
  , (173, "173e")
  , (174, "174e")
  , (175, "175e")
  , (176, "176e")
  , (177, "177e")
  , (178, "178e")
  , (179, "179e")
  , (180, "180e")
  , (181, "181e")
  , (182, "182e")
  , (183, "183e")
  , (184, "184e")
  , (185, "185e")
  , (186, "186e")
  , (187, "187e")
  , (188, "188e")
  , (189, "189e")
  , (190, "190e")
  , (191, "191e")
  , (192, "192e")
  , (193, "193e")
  , (194, "194e")
  , (195, "195e")
  , (196, "196e")
  , (197, "197e")
  , (198, "198e")
  , (199, "199e")
  , (200, "200e")
  , (233, "233e")
  , (377, "377e")
  , (610, "610e")
  , (987, "987e")
  , (1597, "1597e")
  , (2584, "2584e")
  , (4181, "4181e")
  , (6765, "6765e")
  , (10946, "10946e")
  , (17711, "17711e")
  , (28657, "28657e")
  , (46368, "46368e")
  , (75025, "75025e")
  , (121393, "121393e")
  , (196418, "196418e")
  , (317811, "317811e")
  , (514229, "514229e")
  , (832040, "832040e")
  , (1346269, "1346269e")
  , (2178309, "2178309e")
  , (3524578, "3524578e")
  , (5702887, "5702887e")
  , (9227465, "9227465e")
  , (14930352, "14930352e")
  , (24157817, "24157817e")
  , (39088169, "39088169e")
  , (63245986, "63245986e")
  , (102334155, "102334155e")
  , (165580141, "165580141e")
  , (267914296, "267914296e")
  , (433494437, "433494437e")
  , (701408733, "701408733e")
  , (1134903170, "1134903170e")
  , (1836311903, "1836311903e")
  , (2971215073, "2971215073e")
  , (4807526976, "4807526976e")
  , (7778742049, "7778742049e")
  , (12586269025, "12586269025e")
  , (20365011074, "20365011074e")
  , (32951280099, "32951280099e")
  , (53316291173, "53316291173e")
  , (86267571272, "86267571272e")
  , (139583862445, "139583862445e")
  , (225851433717, "225851433717e")
  , (365435296162, "365435296162e")
  , (591286729879, "591286729879e")
  , (956722026041, "956722026041e")
  , (1548008755920, "1548008755920e")
  , (2504730781961, "2504730781961e")
  , (4052739537881, "4052739537881e")
  , (6557470319842, "6557470319842e")
  , (10610209857723, "10610209857723e")
  , (17167680177565, "17167680177565e")
  , (27777890035288, "27777890035288e")
  , (44945570212853, "44945570212853e")
  , (72723460248141, "72723460248141e")
  , (117669030460994, "117669030460994e")
  , (190392490709135, "190392490709135e")
  , (308061521170129, "308061521170129e")
  , (498454011879264, "498454011879264e")
  , (806515533049393, "806515533049393e")
  , (1304969544928657, "1304969544928657e")
  , (2111485077978050, "2111485077978050e")
  , (3416454622906707, "3416454622906707e")
  , (5527939700884757, "5527939700884757e")
  , (8944394323791464, "8944394323791464e")
  , (14472334024676221, "14472334024676221e")
  , (23416728348467685, "23416728348467685e")
  , (37889062373143906, "37889062373143906e")
  , (61305790721611591, "61305790721611591e")
  , (99194853094755497, "99194853094755497e")
  , (160500643816367088, "160500643816367088e")
  , (259695496911122585, "259695496911122585e")
  , (420196140727489673, "420196140727489673e")
  , (679891637638612258, "679891637638612258e")
  , (1100087778366101931, "1100087778366101931e")
  , (1779979416004714189, "1779979416004714189e")
  , (2880067194370816120, "2880067194370816120e")
  , (4660046610375530309, "4660046610375530309e")
  , (7540113804746346429, "7540113804746346429e")
  , (12200160415121876738, "12200160415121876738e")
  , (19740274219868223167, "19740274219868223167e")
  , (31940434634990099905, "31940434634990099905e")
  , (51680708854858323072, "51680708854858323072e")
  , (83621143489848422977, "83621143489848422977e")
  , (135301852344706746049, "135301852344706746049e")
  , (218922995834555169026, "218922995834555169026e")
  , (354224848179261915075, "354224848179261915075e")
  , (573147844013817084101, "573147844013817084101e")
  , (927372692193078999176, "927372692193078999176e")
  , (1500520536206896083277, "1500520536206896083277e")
  , (2427893228399975082453, "2427893228399975082453e")
  , (3928413764606871165730, "3928413764606871165730e")
  , (6356306993006846248183, "6356306993006846248183e")
  , (10284720757613717413913, "10284720757613717413913e")
  , (16641027750620563662096, "16641027750620563662096e")
  , (26925748508234281076009, "26925748508234281076009e")
  , (43566776258854844738105, "43566776258854844738105e")
  , (70492524767089125814114, "70492524767089125814114e")
  , (114059301025943970552219, "114059301025943970552219e")
  , (1000, "1000e")
  , (10000, "10000e")
  , (100000, "100000e")
  , (1000000, "1000000e")
  , (10000000, "10000000e")
  , (100000000, "100000000e")
  , (1000000000, "1000000000e")
  , (10000000000, "10000000000e")
  , (100000000000, "100000000000e")
  , (1000000000000, "1000000000000e")
  , (10000000000000, "10000000000000e")
  , (100000000000000, "100000000000000e")
  , (1000000000000000, "1000000000000000e")
  , (10000000000000000, "10000000000000000e")
  , (100000000000000000, "100000000000000000e")
  , (1000000000000000000, "1000000000000000000e")
  , (10000000000000000000, "10000000000000000000e")
  , (100000000000000000000, "100000000000000000000e")
  , (1000000000000000000000, "1000000000000000000000e")
  , (10000000000000000000000, "10000000000000000000000e")
  , (100000000000000000000000, "100000000000000000000000e")
  , (1000000000000000000000000, "1000000000000000000000000e")
  ]

clockTime :: [(TimeOfDay, Text)]
clockTime = [
    (TimeOfDay 0 0 0,"twaalf uur 's nachts")
  , (TimeOfDay 0 1 0,"\233\233n minuut na twaalf 's nachts")
  , (TimeOfDay 0 2 0,"twee minuten na twaalf 's nachts")
  , (TimeOfDay 0 3 0,"drie minuten na twaalf 's nachts")
  , (TimeOfDay 0 4 0,"vier minuten na twaalf 's nachts")
  , (TimeOfDay 0 5 0,"vijf minuten na twaalf 's nachts")
  , (TimeOfDay 0 6 0,"zes minuten na twaalf 's nachts")
  , (TimeOfDay 0 7 0,"zeven minuten na twaalf 's nachts")
  , (TimeOfDay 0 8 0,"acht minuten na twaalf 's nachts")
  , (TimeOfDay 0 9 0,"negen minuten na twaalf 's nachts")
  , (TimeOfDay 0 10 0,"tien minuten na twaalf 's nachts")
  , (TimeOfDay 0 11 0,"elf minuten na twaalf 's nachts")
  , (TimeOfDay 0 12 0,"twaalf minuten na twaalf 's nachts")
  , (TimeOfDay 0 13 0,"dertien minuten na twaalf 's nachts")
  , (TimeOfDay 0 14 0,"veertien minuten na twaalf 's nachts")
  , (TimeOfDay 0 15 0,"kwart na twaalf 's nachts")
  , (TimeOfDay 0 16 0,"veertien minuten voor half \233\233n 's nachts")
  , (TimeOfDay 0 17 0,"dertien minuten voor half \233\233n 's nachts")
  , (TimeOfDay 0 18 0,"twaalf minuten voor half \233\233n 's nachts")
  , (TimeOfDay 0 19 0,"elf minuten voor half \233\233n 's nachts")
  , (TimeOfDay 0 20 0,"tien minuten voor half \233\233n 's nachts")
  , (TimeOfDay 0 21 0,"negen minuten voor half \233\233n 's nachts")
  , (TimeOfDay 0 22 0,"acht minuten voor half \233\233n 's nachts")
  , (TimeOfDay 0 23 0,"zeven minuten voor half \233\233n 's nachts")
  , (TimeOfDay 0 24 0,"zes minuten voor half \233\233n 's nachts")
  , (TimeOfDay 0 25 0,"vijf minuten voor half \233\233n 's nachts")
  , (TimeOfDay 0 26 0,"vier minuten voor half \233\233n 's nachts")
  , (TimeOfDay 0 27 0,"drie minuten voor half \233\233n 's nachts")
  , (TimeOfDay 0 28 0,"twee minuten voor half \233\233n 's nachts")
  , (TimeOfDay 0 29 0,"\233\233n minuut voor half \233\233n 's nachts")
  , (TimeOfDay 0 30 0,"half \233\233n 's nachts")
  , (TimeOfDay 0 31 0,"\233\233n minuut na half \233\233n 's nachts")
  , (TimeOfDay 0 32 0,"twee minuten na half \233\233n 's nachts")
  , (TimeOfDay 0 33 0,"drie minuten na half \233\233n 's nachts")
  , (TimeOfDay 0 34 0,"vier minuten na half \233\233n 's nachts")
  , (TimeOfDay 0 35 0,"vijf minuten na half \233\233n 's nachts")
  , (TimeOfDay 0 36 0,"zes minuten na half \233\233n 's nachts")
  , (TimeOfDay 0 37 0,"zeven minuten na half \233\233n 's nachts")
  , (TimeOfDay 0 38 0,"acht minuten na half \233\233n 's nachts")
  , (TimeOfDay 0 39 0,"negen minuten na half \233\233n 's nachts")
  , (TimeOfDay 0 40 0,"tien minuten na half \233\233n 's nachts")
  , (TimeOfDay 0 41 0,"elf minuten na half \233\233n 's nachts")
  , (TimeOfDay 0 42 0,"twaalf minuten na half \233\233n 's nachts")
  , (TimeOfDay 0 43 0,"dertien minuten na half \233\233n 's nachts")
  , (TimeOfDay 0 44 0,"veertien minuten na half \233\233n 's nachts")
  , (TimeOfDay 0 45 0,"kwart voor \233\233n 's nachts")
  , (TimeOfDay 0 46 0,"veertien minuten voor \233\233n 's nachts")
  , (TimeOfDay 0 47 0,"dertien minuten voor \233\233n 's nachts")
  , (TimeOfDay 0 48 0,"twaalf minuten voor \233\233n 's nachts")
  , (TimeOfDay 0 49 0,"elf minuten voor \233\233n 's nachts")
  , (TimeOfDay 0 50 0,"tien minuten voor \233\233n 's nachts")
  , (TimeOfDay 0 51 0,"negen minuten voor \233\233n 's nachts")
  , (TimeOfDay 0 52 0,"acht minuten voor \233\233n 's nachts")
  , (TimeOfDay 0 53 0,"zeven minuten voor \233\233n 's nachts")
  , (TimeOfDay 0 54 0,"zes minuten voor \233\233n 's nachts")
  , (TimeOfDay 0 55 0,"vijf minuten voor \233\233n 's nachts")
  , (TimeOfDay 0 56 0,"vier minuten voor \233\233n 's nachts")
  , (TimeOfDay 0 57 0,"drie minuten voor \233\233n 's nachts")
  , (TimeOfDay 0 58 0,"twee minuten voor \233\233n 's nachts")
  , (TimeOfDay 0 59 0,"\233\233n minuut voor \233\233n 's nachts")
  , (TimeOfDay 1 0 0,"\233\233n uur 's nachts")
  , (TimeOfDay 1 1 0,"\233\233n minuut na \233\233n 's nachts")
  , (TimeOfDay 1 2 0,"twee minuten na \233\233n 's nachts")
  , (TimeOfDay 1 3 0,"drie minuten na \233\233n 's nachts")
  , (TimeOfDay 1 4 0,"vier minuten na \233\233n 's nachts")
  , (TimeOfDay 1 5 0,"vijf minuten na \233\233n 's nachts")
  , (TimeOfDay 1 6 0,"zes minuten na \233\233n 's nachts")
  , (TimeOfDay 1 7 0,"zeven minuten na \233\233n 's nachts")
  , (TimeOfDay 1 8 0,"acht minuten na \233\233n 's nachts")
  , (TimeOfDay 1 9 0,"negen minuten na \233\233n 's nachts")
  , (TimeOfDay 1 10 0,"tien minuten na \233\233n 's nachts")
  , (TimeOfDay 1 11 0,"elf minuten na \233\233n 's nachts")
  , (TimeOfDay 1 12 0,"twaalf minuten na \233\233n 's nachts")
  , (TimeOfDay 1 13 0,"dertien minuten na \233\233n 's nachts")
  , (TimeOfDay 1 14 0,"veertien minuten na \233\233n 's nachts")
  , (TimeOfDay 1 15 0,"kwart na \233\233n 's nachts")
  , (TimeOfDay 1 16 0,"veertien minuten voor half twee 's nachts")
  , (TimeOfDay 1 17 0,"dertien minuten voor half twee 's nachts")
  , (TimeOfDay 1 18 0,"twaalf minuten voor half twee 's nachts")
  , (TimeOfDay 1 19 0,"elf minuten voor half twee 's nachts")
  , (TimeOfDay 1 20 0,"tien minuten voor half twee 's nachts")
  , (TimeOfDay 1 21 0,"negen minuten voor half twee 's nachts")
  , (TimeOfDay 1 22 0,"acht minuten voor half twee 's nachts")
  , (TimeOfDay 1 23 0,"zeven minuten voor half twee 's nachts")
  , (TimeOfDay 1 24 0,"zes minuten voor half twee 's nachts")
  , (TimeOfDay 1 25 0,"vijf minuten voor half twee 's nachts")
  , (TimeOfDay 1 26 0,"vier minuten voor half twee 's nachts")
  , (TimeOfDay 1 27 0,"drie minuten voor half twee 's nachts")
  , (TimeOfDay 1 28 0,"twee minuten voor half twee 's nachts")
  , (TimeOfDay 1 29 0,"\233\233n minuut voor half twee 's nachts")
  , (TimeOfDay 1 30 0,"half twee 's nachts")
  , (TimeOfDay 1 31 0,"\233\233n minuut na half twee 's nachts")
  , (TimeOfDay 1 32 0,"twee minuten na half twee 's nachts")
  , (TimeOfDay 1 33 0,"drie minuten na half twee 's nachts")
  , (TimeOfDay 1 34 0,"vier minuten na half twee 's nachts")
  , (TimeOfDay 1 35 0,"vijf minuten na half twee 's nachts")
  , (TimeOfDay 1 36 0,"zes minuten na half twee 's nachts")
  , (TimeOfDay 1 37 0,"zeven minuten na half twee 's nachts")
  , (TimeOfDay 1 38 0,"acht minuten na half twee 's nachts")
  , (TimeOfDay 1 39 0,"negen minuten na half twee 's nachts")
  , (TimeOfDay 1 40 0,"tien minuten na half twee 's nachts")
  , (TimeOfDay 1 41 0,"elf minuten na half twee 's nachts")
  , (TimeOfDay 1 42 0,"twaalf minuten na half twee 's nachts")
  , (TimeOfDay 1 43 0,"dertien minuten na half twee 's nachts")
  , (TimeOfDay 1 44 0,"veertien minuten na half twee 's nachts")
  , (TimeOfDay 1 45 0,"kwart voor twee 's nachts")
  , (TimeOfDay 1 46 0,"veertien minuten voor twee 's nachts")
  , (TimeOfDay 1 47 0,"dertien minuten voor twee 's nachts")
  , (TimeOfDay 1 48 0,"twaalf minuten voor twee 's nachts")
  , (TimeOfDay 1 49 0,"elf minuten voor twee 's nachts")
  , (TimeOfDay 1 50 0,"tien minuten voor twee 's nachts")
  , (TimeOfDay 1 51 0,"negen minuten voor twee 's nachts")
  , (TimeOfDay 1 52 0,"acht minuten voor twee 's nachts")
  , (TimeOfDay 1 53 0,"zeven minuten voor twee 's nachts")
  , (TimeOfDay 1 54 0,"zes minuten voor twee 's nachts")
  , (TimeOfDay 1 55 0,"vijf minuten voor twee 's nachts")
  , (TimeOfDay 1 56 0,"vier minuten voor twee 's nachts")
  , (TimeOfDay 1 57 0,"drie minuten voor twee 's nachts")
  , (TimeOfDay 1 58 0,"twee minuten voor twee 's nachts")
  , (TimeOfDay 1 59 0,"\233\233n minuut voor twee 's nachts")
  , (TimeOfDay 2 0 0,"twee uur 's nachts")
  , (TimeOfDay 2 1 0,"\233\233n minuut na twee 's nachts")
  , (TimeOfDay 2 2 0,"twee minuten na twee 's nachts")
  , (TimeOfDay 2 3 0,"drie minuten na twee 's nachts")
  , (TimeOfDay 2 4 0,"vier minuten na twee 's nachts")
  , (TimeOfDay 2 5 0,"vijf minuten na twee 's nachts")
  , (TimeOfDay 2 6 0,"zes minuten na twee 's nachts")
  , (TimeOfDay 2 7 0,"zeven minuten na twee 's nachts")
  , (TimeOfDay 2 8 0,"acht minuten na twee 's nachts")
  , (TimeOfDay 2 9 0,"negen minuten na twee 's nachts")
  , (TimeOfDay 2 10 0,"tien minuten na twee 's nachts")
  , (TimeOfDay 2 11 0,"elf minuten na twee 's nachts")
  , (TimeOfDay 2 12 0,"twaalf minuten na twee 's nachts")
  , (TimeOfDay 2 13 0,"dertien minuten na twee 's nachts")
  , (TimeOfDay 2 14 0,"veertien minuten na twee 's nachts")
  , (TimeOfDay 2 15 0,"kwart na twee 's nachts")
  , (TimeOfDay 2 16 0,"veertien minuten voor half drie 's nachts")
  , (TimeOfDay 2 17 0,"dertien minuten voor half drie 's nachts")
  , (TimeOfDay 2 18 0,"twaalf minuten voor half drie 's nachts")
  , (TimeOfDay 2 19 0,"elf minuten voor half drie 's nachts")
  , (TimeOfDay 2 20 0,"tien minuten voor half drie 's nachts")
  , (TimeOfDay 2 21 0,"negen minuten voor half drie 's nachts")
  , (TimeOfDay 2 22 0,"acht minuten voor half drie 's nachts")
  , (TimeOfDay 2 23 0,"zeven minuten voor half drie 's nachts")
  , (TimeOfDay 2 24 0,"zes minuten voor half drie 's nachts")
  , (TimeOfDay 2 25 0,"vijf minuten voor half drie 's nachts")
  , (TimeOfDay 2 26 0,"vier minuten voor half drie 's nachts")
  , (TimeOfDay 2 27 0,"drie minuten voor half drie 's nachts")
  , (TimeOfDay 2 28 0,"twee minuten voor half drie 's nachts")
  , (TimeOfDay 2 29 0,"\233\233n minuut voor half drie 's nachts")
  , (TimeOfDay 2 30 0,"half drie 's nachts")
  , (TimeOfDay 2 31 0,"\233\233n minuut na half drie 's nachts")
  , (TimeOfDay 2 32 0,"twee minuten na half drie 's nachts")
  , (TimeOfDay 2 33 0,"drie minuten na half drie 's nachts")
  , (TimeOfDay 2 34 0,"vier minuten na half drie 's nachts")
  , (TimeOfDay 2 35 0,"vijf minuten na half drie 's nachts")
  , (TimeOfDay 2 36 0,"zes minuten na half drie 's nachts")
  , (TimeOfDay 2 37 0,"zeven minuten na half drie 's nachts")
  , (TimeOfDay 2 38 0,"acht minuten na half drie 's nachts")
  , (TimeOfDay 2 39 0,"negen minuten na half drie 's nachts")
  , (TimeOfDay 2 40 0,"tien minuten na half drie 's nachts")
  , (TimeOfDay 2 41 0,"elf minuten na half drie 's nachts")
  , (TimeOfDay 2 42 0,"twaalf minuten na half drie 's nachts")
  , (TimeOfDay 2 43 0,"dertien minuten na half drie 's nachts")
  , (TimeOfDay 2 44 0,"veertien minuten na half drie 's nachts")
  , (TimeOfDay 2 45 0,"kwart voor drie 's nachts")
  , (TimeOfDay 2 46 0,"veertien minuten voor drie 's nachts")
  , (TimeOfDay 2 47 0,"dertien minuten voor drie 's nachts")
  , (TimeOfDay 2 48 0,"twaalf minuten voor drie 's nachts")
  , (TimeOfDay 2 49 0,"elf minuten voor drie 's nachts")
  , (TimeOfDay 2 50 0,"tien minuten voor drie 's nachts")
  , (TimeOfDay 2 51 0,"negen minuten voor drie 's nachts")
  , (TimeOfDay 2 52 0,"acht minuten voor drie 's nachts")
  , (TimeOfDay 2 53 0,"zeven minuten voor drie 's nachts")
  , (TimeOfDay 2 54 0,"zes minuten voor drie 's nachts")
  , (TimeOfDay 2 55 0,"vijf minuten voor drie 's nachts")
  , (TimeOfDay 2 56 0,"vier minuten voor drie 's nachts")
  , (TimeOfDay 2 57 0,"drie minuten voor drie 's nachts")
  , (TimeOfDay 2 58 0,"twee minuten voor drie 's nachts")
  , (TimeOfDay 2 59 0,"\233\233n minuut voor drie 's nachts")
  , (TimeOfDay 3 0 0,"drie uur 's nachts")
  , (TimeOfDay 3 1 0,"\233\233n minuut na drie 's nachts")
  , (TimeOfDay 3 2 0,"twee minuten na drie 's nachts")
  , (TimeOfDay 3 3 0,"drie minuten na drie 's nachts")
  , (TimeOfDay 3 4 0,"vier minuten na drie 's nachts")
  , (TimeOfDay 3 5 0,"vijf minuten na drie 's nachts")
  , (TimeOfDay 3 6 0,"zes minuten na drie 's nachts")
  , (TimeOfDay 3 7 0,"zeven minuten na drie 's nachts")
  , (TimeOfDay 3 8 0,"acht minuten na drie 's nachts")
  , (TimeOfDay 3 9 0,"negen minuten na drie 's nachts")
  , (TimeOfDay 3 10 0,"tien minuten na drie 's nachts")
  , (TimeOfDay 3 11 0,"elf minuten na drie 's nachts")
  , (TimeOfDay 3 12 0,"twaalf minuten na drie 's nachts")
  , (TimeOfDay 3 13 0,"dertien minuten na drie 's nachts")
  , (TimeOfDay 3 14 0,"veertien minuten na drie 's nachts")
  , (TimeOfDay 3 15 0,"kwart na drie 's nachts")
  , (TimeOfDay 3 16 0,"veertien minuten voor half vier 's nachts")
  , (TimeOfDay 3 17 0,"dertien minuten voor half vier 's nachts")
  , (TimeOfDay 3 18 0,"twaalf minuten voor half vier 's nachts")
  , (TimeOfDay 3 19 0,"elf minuten voor half vier 's nachts")
  , (TimeOfDay 3 20 0,"tien minuten voor half vier 's nachts")
  , (TimeOfDay 3 21 0,"negen minuten voor half vier 's nachts")
  , (TimeOfDay 3 22 0,"acht minuten voor half vier 's nachts")
  , (TimeOfDay 3 23 0,"zeven minuten voor half vier 's nachts")
  , (TimeOfDay 3 24 0,"zes minuten voor half vier 's nachts")
  , (TimeOfDay 3 25 0,"vijf minuten voor half vier 's nachts")
  , (TimeOfDay 3 26 0,"vier minuten voor half vier 's nachts")
  , (TimeOfDay 3 27 0,"drie minuten voor half vier 's nachts")
  , (TimeOfDay 3 28 0,"twee minuten voor half vier 's nachts")
  , (TimeOfDay 3 29 0,"\233\233n minuut voor half vier 's nachts")
  , (TimeOfDay 3 30 0,"half vier 's nachts")
  , (TimeOfDay 3 31 0,"\233\233n minuut na half vier 's nachts")
  , (TimeOfDay 3 32 0,"twee minuten na half vier 's nachts")
  , (TimeOfDay 3 33 0,"drie minuten na half vier 's nachts")
  , (TimeOfDay 3 34 0,"vier minuten na half vier 's nachts")
  , (TimeOfDay 3 35 0,"vijf minuten na half vier 's nachts")
  , (TimeOfDay 3 36 0,"zes minuten na half vier 's nachts")
  , (TimeOfDay 3 37 0,"zeven minuten na half vier 's nachts")
  , (TimeOfDay 3 38 0,"acht minuten na half vier 's nachts")
  , (TimeOfDay 3 39 0,"negen minuten na half vier 's nachts")
  , (TimeOfDay 3 40 0,"tien minuten na half vier 's nachts")
  , (TimeOfDay 3 41 0,"elf minuten na half vier 's nachts")
  , (TimeOfDay 3 42 0,"twaalf minuten na half vier 's nachts")
  , (TimeOfDay 3 43 0,"dertien minuten na half vier 's nachts")
  , (TimeOfDay 3 44 0,"veertien minuten na half vier 's nachts")
  , (TimeOfDay 3 45 0,"kwart voor vier 's nachts")
  , (TimeOfDay 3 46 0,"veertien minuten voor vier 's nachts")
  , (TimeOfDay 3 47 0,"dertien minuten voor vier 's nachts")
  , (TimeOfDay 3 48 0,"twaalf minuten voor vier 's nachts")
  , (TimeOfDay 3 49 0,"elf minuten voor vier 's nachts")
  , (TimeOfDay 3 50 0,"tien minuten voor vier 's nachts")
  , (TimeOfDay 3 51 0,"negen minuten voor vier 's nachts")
  , (TimeOfDay 3 52 0,"acht minuten voor vier 's nachts")
  , (TimeOfDay 3 53 0,"zeven minuten voor vier 's nachts")
  , (TimeOfDay 3 54 0,"zes minuten voor vier 's nachts")
  , (TimeOfDay 3 55 0,"vijf minuten voor vier 's nachts")
  , (TimeOfDay 3 56 0,"vier minuten voor vier 's nachts")
  , (TimeOfDay 3 57 0,"drie minuten voor vier 's nachts")
  , (TimeOfDay 3 58 0,"twee minuten voor vier 's nachts")
  , (TimeOfDay 3 59 0,"\233\233n minuut voor vier 's nachts")
  , (TimeOfDay 4 0 0,"vier uur 's nachts")
  , (TimeOfDay 4 1 0,"\233\233n minuut na vier 's nachts")
  , (TimeOfDay 4 2 0,"twee minuten na vier 's nachts")
  , (TimeOfDay 4 3 0,"drie minuten na vier 's nachts")
  , (TimeOfDay 4 4 0,"vier minuten na vier 's nachts")
  , (TimeOfDay 4 5 0,"vijf minuten na vier 's nachts")
  , (TimeOfDay 4 6 0,"zes minuten na vier 's nachts")
  , (TimeOfDay 4 7 0,"zeven minuten na vier 's nachts")
  , (TimeOfDay 4 8 0,"acht minuten na vier 's nachts")
  , (TimeOfDay 4 9 0,"negen minuten na vier 's nachts")
  , (TimeOfDay 4 10 0,"tien minuten na vier 's nachts")
  , (TimeOfDay 4 11 0,"elf minuten na vier 's nachts")
  , (TimeOfDay 4 12 0,"twaalf minuten na vier 's nachts")
  , (TimeOfDay 4 13 0,"dertien minuten na vier 's nachts")
  , (TimeOfDay 4 14 0,"veertien minuten na vier 's nachts")
  , (TimeOfDay 4 15 0,"kwart na vier 's nachts")
  , (TimeOfDay 4 16 0,"veertien minuten voor half vijf 's nachts")
  , (TimeOfDay 4 17 0,"dertien minuten voor half vijf 's nachts")
  , (TimeOfDay 4 18 0,"twaalf minuten voor half vijf 's nachts")
  , (TimeOfDay 4 19 0,"elf minuten voor half vijf 's nachts")
  , (TimeOfDay 4 20 0,"tien minuten voor half vijf 's nachts")
  , (TimeOfDay 4 21 0,"negen minuten voor half vijf 's nachts")
  , (TimeOfDay 4 22 0,"acht minuten voor half vijf 's nachts")
  , (TimeOfDay 4 23 0,"zeven minuten voor half vijf 's nachts")
  , (TimeOfDay 4 24 0,"zes minuten voor half vijf 's nachts")
  , (TimeOfDay 4 25 0,"vijf minuten voor half vijf 's nachts")
  , (TimeOfDay 4 26 0,"vier minuten voor half vijf 's nachts")
  , (TimeOfDay 4 27 0,"drie minuten voor half vijf 's nachts")
  , (TimeOfDay 4 28 0,"twee minuten voor half vijf 's nachts")
  , (TimeOfDay 4 29 0,"\233\233n minuut voor half vijf 's nachts")
  , (TimeOfDay 4 30 0,"half vijf 's nachts")
  , (TimeOfDay 4 31 0,"\233\233n minuut na half vijf 's nachts")
  , (TimeOfDay 4 32 0,"twee minuten na half vijf 's nachts")
  , (TimeOfDay 4 33 0,"drie minuten na half vijf 's nachts")
  , (TimeOfDay 4 34 0,"vier minuten na half vijf 's nachts")
  , (TimeOfDay 4 35 0,"vijf minuten na half vijf 's nachts")
  , (TimeOfDay 4 36 0,"zes minuten na half vijf 's nachts")
  , (TimeOfDay 4 37 0,"zeven minuten na half vijf 's nachts")
  , (TimeOfDay 4 38 0,"acht minuten na half vijf 's nachts")
  , (TimeOfDay 4 39 0,"negen minuten na half vijf 's nachts")
  , (TimeOfDay 4 40 0,"tien minuten na half vijf 's nachts")
  , (TimeOfDay 4 41 0,"elf minuten na half vijf 's nachts")
  , (TimeOfDay 4 42 0,"twaalf minuten na half vijf 's nachts")
  , (TimeOfDay 4 43 0,"dertien minuten na half vijf 's nachts")
  , (TimeOfDay 4 44 0,"veertien minuten na half vijf 's nachts")
  , (TimeOfDay 4 45 0,"kwart voor vijf 's nachts")
  , (TimeOfDay 4 46 0,"veertien minuten voor vijf 's nachts")
  , (TimeOfDay 4 47 0,"dertien minuten voor vijf 's nachts")
  , (TimeOfDay 4 48 0,"twaalf minuten voor vijf 's nachts")
  , (TimeOfDay 4 49 0,"elf minuten voor vijf 's nachts")
  , (TimeOfDay 4 50 0,"tien minuten voor vijf 's nachts")
  , (TimeOfDay 4 51 0,"negen minuten voor vijf 's nachts")
  , (TimeOfDay 4 52 0,"acht minuten voor vijf 's nachts")
  , (TimeOfDay 4 53 0,"zeven minuten voor vijf 's nachts")
  , (TimeOfDay 4 54 0,"zes minuten voor vijf 's nachts")
  , (TimeOfDay 4 55 0,"vijf minuten voor vijf 's nachts")
  , (TimeOfDay 4 56 0,"vier minuten voor vijf 's nachts")
  , (TimeOfDay 4 57 0,"drie minuten voor vijf 's nachts")
  , (TimeOfDay 4 58 0,"twee minuten voor vijf 's nachts")
  , (TimeOfDay 4 59 0,"\233\233n minuut voor vijf 's nachts")
  , (TimeOfDay 5 0 0,"vijf uur 's nachts")
  , (TimeOfDay 5 1 0,"\233\233n minuut na vijf 's nachts")
  , (TimeOfDay 5 2 0,"twee minuten na vijf 's nachts")
  , (TimeOfDay 5 3 0,"drie minuten na vijf 's nachts")
  , (TimeOfDay 5 4 0,"vier minuten na vijf 's nachts")
  , (TimeOfDay 5 5 0,"vijf minuten na vijf 's nachts")
  , (TimeOfDay 5 6 0,"zes minuten na vijf 's nachts")
  , (TimeOfDay 5 7 0,"zeven minuten na vijf 's nachts")
  , (TimeOfDay 5 8 0,"acht minuten na vijf 's nachts")
  , (TimeOfDay 5 9 0,"negen minuten na vijf 's nachts")
  , (TimeOfDay 5 10 0,"tien minuten na vijf 's nachts")
  , (TimeOfDay 5 11 0,"elf minuten na vijf 's nachts")
  , (TimeOfDay 5 12 0,"twaalf minuten na vijf 's nachts")
  , (TimeOfDay 5 13 0,"dertien minuten na vijf 's nachts")
  , (TimeOfDay 5 14 0,"veertien minuten na vijf 's nachts")
  , (TimeOfDay 5 15 0,"kwart na vijf 's nachts")
  , (TimeOfDay 5 16 0,"veertien minuten voor half zes 's nachts")
  , (TimeOfDay 5 17 0,"dertien minuten voor half zes 's nachts")
  , (TimeOfDay 5 18 0,"twaalf minuten voor half zes 's nachts")
  , (TimeOfDay 5 19 0,"elf minuten voor half zes 's nachts")
  , (TimeOfDay 5 20 0,"tien minuten voor half zes 's nachts")
  , (TimeOfDay 5 21 0,"negen minuten voor half zes 's nachts")
  , (TimeOfDay 5 22 0,"acht minuten voor half zes 's nachts")
  , (TimeOfDay 5 23 0,"zeven minuten voor half zes 's nachts")
  , (TimeOfDay 5 24 0,"zes minuten voor half zes 's nachts")
  , (TimeOfDay 5 25 0,"vijf minuten voor half zes 's nachts")
  , (TimeOfDay 5 26 0,"vier minuten voor half zes 's nachts")
  , (TimeOfDay 5 27 0,"drie minuten voor half zes 's nachts")
  , (TimeOfDay 5 28 0,"twee minuten voor half zes 's nachts")
  , (TimeOfDay 5 29 0,"\233\233n minuut voor half zes 's nachts")
  , (TimeOfDay 5 30 0,"half zes 's nachts")
  , (TimeOfDay 5 31 0,"\233\233n minuut na half zes 's nachts")
  , (TimeOfDay 5 32 0,"twee minuten na half zes 's nachts")
  , (TimeOfDay 5 33 0,"drie minuten na half zes 's nachts")
  , (TimeOfDay 5 34 0,"vier minuten na half zes 's nachts")
  , (TimeOfDay 5 35 0,"vijf minuten na half zes 's nachts")
  , (TimeOfDay 5 36 0,"zes minuten na half zes 's nachts")
  , (TimeOfDay 5 37 0,"zeven minuten na half zes 's nachts")
  , (TimeOfDay 5 38 0,"acht minuten na half zes 's nachts")
  , (TimeOfDay 5 39 0,"negen minuten na half zes 's nachts")
  , (TimeOfDay 5 40 0,"tien minuten na half zes 's nachts")
  , (TimeOfDay 5 41 0,"elf minuten na half zes 's nachts")
  , (TimeOfDay 5 42 0,"twaalf minuten na half zes 's nachts")
  , (TimeOfDay 5 43 0,"dertien minuten na half zes 's nachts")
  , (TimeOfDay 5 44 0,"veertien minuten na half zes 's nachts")
  , (TimeOfDay 5 45 0,"kwart voor zes 's nachts")
  , (TimeOfDay 5 46 0,"veertien minuten voor zes 's nachts")
  , (TimeOfDay 5 47 0,"dertien minuten voor zes 's nachts")
  , (TimeOfDay 5 48 0,"twaalf minuten voor zes 's nachts")
  , (TimeOfDay 5 49 0,"elf minuten voor zes 's nachts")
  , (TimeOfDay 5 50 0,"tien minuten voor zes 's nachts")
  , (TimeOfDay 5 51 0,"negen minuten voor zes 's nachts")
  , (TimeOfDay 5 52 0,"acht minuten voor zes 's nachts")
  , (TimeOfDay 5 53 0,"zeven minuten voor zes 's nachts")
  , (TimeOfDay 5 54 0,"zes minuten voor zes 's nachts")
  , (TimeOfDay 5 55 0,"vijf minuten voor zes 's nachts")
  , (TimeOfDay 5 56 0,"vier minuten voor zes 's nachts")
  , (TimeOfDay 5 57 0,"drie minuten voor zes 's nachts")
  , (TimeOfDay 5 58 0,"twee minuten voor zes 's nachts")
  , (TimeOfDay 5 59 0,"\233\233n minuut voor zes 's nachts")
  , (TimeOfDay 6 0 0,"zes uur 's ochtends")
  , (TimeOfDay 6 1 0,"\233\233n minuut na zes 's ochtends")
  , (TimeOfDay 6 2 0,"twee minuten na zes 's ochtends")
  , (TimeOfDay 6 3 0,"drie minuten na zes 's ochtends")
  , (TimeOfDay 6 4 0,"vier minuten na zes 's ochtends")
  , (TimeOfDay 6 5 0,"vijf minuten na zes 's ochtends")
  , (TimeOfDay 6 6 0,"zes minuten na zes 's ochtends")
  , (TimeOfDay 6 7 0,"zeven minuten na zes 's ochtends")
  , (TimeOfDay 6 8 0,"acht minuten na zes 's ochtends")
  , (TimeOfDay 6 9 0,"negen minuten na zes 's ochtends")
  , (TimeOfDay 6 10 0,"tien minuten na zes 's ochtends")
  , (TimeOfDay 6 11 0,"elf minuten na zes 's ochtends")
  , (TimeOfDay 6 12 0,"twaalf minuten na zes 's ochtends")
  , (TimeOfDay 6 13 0,"dertien minuten na zes 's ochtends")
  , (TimeOfDay 6 14 0,"veertien minuten na zes 's ochtends")
  , (TimeOfDay 6 15 0,"kwart na zes 's ochtends")
  , (TimeOfDay 6 16 0,"veertien minuten voor half zeven 's ochtends")
  , (TimeOfDay 6 17 0,"dertien minuten voor half zeven 's ochtends")
  , (TimeOfDay 6 18 0,"twaalf minuten voor half zeven 's ochtends")
  , (TimeOfDay 6 19 0,"elf minuten voor half zeven 's ochtends")
  , (TimeOfDay 6 20 0,"tien minuten voor half zeven 's ochtends")
  , (TimeOfDay 6 21 0,"negen minuten voor half zeven 's ochtends")
  , (TimeOfDay 6 22 0,"acht minuten voor half zeven 's ochtends")
  , (TimeOfDay 6 23 0,"zeven minuten voor half zeven 's ochtends")
  , (TimeOfDay 6 24 0,"zes minuten voor half zeven 's ochtends")
  , (TimeOfDay 6 25 0,"vijf minuten voor half zeven 's ochtends")
  , (TimeOfDay 6 26 0,"vier minuten voor half zeven 's ochtends")
  , (TimeOfDay 6 27 0,"drie minuten voor half zeven 's ochtends")
  , (TimeOfDay 6 28 0,"twee minuten voor half zeven 's ochtends")
  , (TimeOfDay 6 29 0,"\233\233n minuut voor half zeven 's ochtends")
  , (TimeOfDay 6 30 0,"half zeven 's ochtends")
  , (TimeOfDay 6 31 0,"\233\233n minuut na half zeven 's ochtends")
  , (TimeOfDay 6 32 0,"twee minuten na half zeven 's ochtends")
  , (TimeOfDay 6 33 0,"drie minuten na half zeven 's ochtends")
  , (TimeOfDay 6 34 0,"vier minuten na half zeven 's ochtends")
  , (TimeOfDay 6 35 0,"vijf minuten na half zeven 's ochtends")
  , (TimeOfDay 6 36 0,"zes minuten na half zeven 's ochtends")
  , (TimeOfDay 6 37 0,"zeven minuten na half zeven 's ochtends")
  , (TimeOfDay 6 38 0,"acht minuten na half zeven 's ochtends")
  , (TimeOfDay 6 39 0,"negen minuten na half zeven 's ochtends")
  , (TimeOfDay 6 40 0,"tien minuten na half zeven 's ochtends")
  , (TimeOfDay 6 41 0,"elf minuten na half zeven 's ochtends")
  , (TimeOfDay 6 42 0,"twaalf minuten na half zeven 's ochtends")
  , (TimeOfDay 6 43 0,"dertien minuten na half zeven 's ochtends")
  , (TimeOfDay 6 44 0,"veertien minuten na half zeven 's ochtends")
  , (TimeOfDay 6 45 0,"kwart voor zeven 's ochtends")
  , (TimeOfDay 6 46 0,"veertien minuten voor zeven 's ochtends")
  , (TimeOfDay 6 47 0,"dertien minuten voor zeven 's ochtends")
  , (TimeOfDay 6 48 0,"twaalf minuten voor zeven 's ochtends")
  , (TimeOfDay 6 49 0,"elf minuten voor zeven 's ochtends")
  , (TimeOfDay 6 50 0,"tien minuten voor zeven 's ochtends")
  , (TimeOfDay 6 51 0,"negen minuten voor zeven 's ochtends")
  , (TimeOfDay 6 52 0,"acht minuten voor zeven 's ochtends")
  , (TimeOfDay 6 53 0,"zeven minuten voor zeven 's ochtends")
  , (TimeOfDay 6 54 0,"zes minuten voor zeven 's ochtends")
  , (TimeOfDay 6 55 0,"vijf minuten voor zeven 's ochtends")
  , (TimeOfDay 6 56 0,"vier minuten voor zeven 's ochtends")
  , (TimeOfDay 6 57 0,"drie minuten voor zeven 's ochtends")
  , (TimeOfDay 6 58 0,"twee minuten voor zeven 's ochtends")
  , (TimeOfDay 6 59 0,"\233\233n minuut voor zeven 's ochtends")
  , (TimeOfDay 7 0 0,"zeven uur 's ochtends")
  , (TimeOfDay 7 1 0,"\233\233n minuut na zeven 's ochtends")
  , (TimeOfDay 7 2 0,"twee minuten na zeven 's ochtends")
  , (TimeOfDay 7 3 0,"drie minuten na zeven 's ochtends")
  , (TimeOfDay 7 4 0,"vier minuten na zeven 's ochtends")
  , (TimeOfDay 7 5 0,"vijf minuten na zeven 's ochtends")
  , (TimeOfDay 7 6 0,"zes minuten na zeven 's ochtends")
  , (TimeOfDay 7 7 0,"zeven minuten na zeven 's ochtends")
  , (TimeOfDay 7 8 0,"acht minuten na zeven 's ochtends")
  , (TimeOfDay 7 9 0,"negen minuten na zeven 's ochtends")
  , (TimeOfDay 7 10 0,"tien minuten na zeven 's ochtends")
  , (TimeOfDay 7 11 0,"elf minuten na zeven 's ochtends")
  , (TimeOfDay 7 12 0,"twaalf minuten na zeven 's ochtends")
  , (TimeOfDay 7 13 0,"dertien minuten na zeven 's ochtends")
  , (TimeOfDay 7 14 0,"veertien minuten na zeven 's ochtends")
  , (TimeOfDay 7 15 0,"kwart na zeven 's ochtends")
  , (TimeOfDay 7 16 0,"veertien minuten voor half acht 's ochtends")
  , (TimeOfDay 7 17 0,"dertien minuten voor half acht 's ochtends")
  , (TimeOfDay 7 18 0,"twaalf minuten voor half acht 's ochtends")
  , (TimeOfDay 7 19 0,"elf minuten voor half acht 's ochtends")
  , (TimeOfDay 7 20 0,"tien minuten voor half acht 's ochtends")
  , (TimeOfDay 7 21 0,"negen minuten voor half acht 's ochtends")
  , (TimeOfDay 7 22 0,"acht minuten voor half acht 's ochtends")
  , (TimeOfDay 7 23 0,"zeven minuten voor half acht 's ochtends")
  , (TimeOfDay 7 24 0,"zes minuten voor half acht 's ochtends")
  , (TimeOfDay 7 25 0,"vijf minuten voor half acht 's ochtends")
  , (TimeOfDay 7 26 0,"vier minuten voor half acht 's ochtends")
  , (TimeOfDay 7 27 0,"drie minuten voor half acht 's ochtends")
  , (TimeOfDay 7 28 0,"twee minuten voor half acht 's ochtends")
  , (TimeOfDay 7 29 0,"\233\233n minuut voor half acht 's ochtends")
  , (TimeOfDay 7 30 0,"half acht 's ochtends")
  , (TimeOfDay 7 31 0,"\233\233n minuut na half acht 's ochtends")
  , (TimeOfDay 7 32 0,"twee minuten na half acht 's ochtends")
  , (TimeOfDay 7 33 0,"drie minuten na half acht 's ochtends")
  , (TimeOfDay 7 34 0,"vier minuten na half acht 's ochtends")
  , (TimeOfDay 7 35 0,"vijf minuten na half acht 's ochtends")
  , (TimeOfDay 7 36 0,"zes minuten na half acht 's ochtends")
  , (TimeOfDay 7 37 0,"zeven minuten na half acht 's ochtends")
  , (TimeOfDay 7 38 0,"acht minuten na half acht 's ochtends")
  , (TimeOfDay 7 39 0,"negen minuten na half acht 's ochtends")
  , (TimeOfDay 7 40 0,"tien minuten na half acht 's ochtends")
  , (TimeOfDay 7 41 0,"elf minuten na half acht 's ochtends")
  , (TimeOfDay 7 42 0,"twaalf minuten na half acht 's ochtends")
  , (TimeOfDay 7 43 0,"dertien minuten na half acht 's ochtends")
  , (TimeOfDay 7 44 0,"veertien minuten na half acht 's ochtends")
  , (TimeOfDay 7 45 0,"kwart voor acht 's ochtends")
  , (TimeOfDay 7 46 0,"veertien minuten voor acht 's ochtends")
  , (TimeOfDay 7 47 0,"dertien minuten voor acht 's ochtends")
  , (TimeOfDay 7 48 0,"twaalf minuten voor acht 's ochtends")
  , (TimeOfDay 7 49 0,"elf minuten voor acht 's ochtends")
  , (TimeOfDay 7 50 0,"tien minuten voor acht 's ochtends")
  , (TimeOfDay 7 51 0,"negen minuten voor acht 's ochtends")
  , (TimeOfDay 7 52 0,"acht minuten voor acht 's ochtends")
  , (TimeOfDay 7 53 0,"zeven minuten voor acht 's ochtends")
  , (TimeOfDay 7 54 0,"zes minuten voor acht 's ochtends")
  , (TimeOfDay 7 55 0,"vijf minuten voor acht 's ochtends")
  , (TimeOfDay 7 56 0,"vier minuten voor acht 's ochtends")
  , (TimeOfDay 7 57 0,"drie minuten voor acht 's ochtends")
  , (TimeOfDay 7 58 0,"twee minuten voor acht 's ochtends")
  , (TimeOfDay 7 59 0,"\233\233n minuut voor acht 's ochtends")
  , (TimeOfDay 8 0 0,"acht uur 's ochtends")
  , (TimeOfDay 8 1 0,"\233\233n minuut na acht 's ochtends")
  , (TimeOfDay 8 2 0,"twee minuten na acht 's ochtends")
  , (TimeOfDay 8 3 0,"drie minuten na acht 's ochtends")
  , (TimeOfDay 8 4 0,"vier minuten na acht 's ochtends")
  , (TimeOfDay 8 5 0,"vijf minuten na acht 's ochtends")
  , (TimeOfDay 8 6 0,"zes minuten na acht 's ochtends")
  , (TimeOfDay 8 7 0,"zeven minuten na acht 's ochtends")
  , (TimeOfDay 8 8 0,"acht minuten na acht 's ochtends")
  , (TimeOfDay 8 9 0,"negen minuten na acht 's ochtends")
  , (TimeOfDay 8 10 0,"tien minuten na acht 's ochtends")
  , (TimeOfDay 8 11 0,"elf minuten na acht 's ochtends")
  , (TimeOfDay 8 12 0,"twaalf minuten na acht 's ochtends")
  , (TimeOfDay 8 13 0,"dertien minuten na acht 's ochtends")
  , (TimeOfDay 8 14 0,"veertien minuten na acht 's ochtends")
  , (TimeOfDay 8 15 0,"kwart na acht 's ochtends")
  , (TimeOfDay 8 16 0,"veertien minuten voor half negen 's ochtends")
  , (TimeOfDay 8 17 0,"dertien minuten voor half negen 's ochtends")
  , (TimeOfDay 8 18 0,"twaalf minuten voor half negen 's ochtends")
  , (TimeOfDay 8 19 0,"elf minuten voor half negen 's ochtends")
  , (TimeOfDay 8 20 0,"tien minuten voor half negen 's ochtends")
  , (TimeOfDay 8 21 0,"negen minuten voor half negen 's ochtends")
  , (TimeOfDay 8 22 0,"acht minuten voor half negen 's ochtends")
  , (TimeOfDay 8 23 0,"zeven minuten voor half negen 's ochtends")
  , (TimeOfDay 8 24 0,"zes minuten voor half negen 's ochtends")
  , (TimeOfDay 8 25 0,"vijf minuten voor half negen 's ochtends")
  , (TimeOfDay 8 26 0,"vier minuten voor half negen 's ochtends")
  , (TimeOfDay 8 27 0,"drie minuten voor half negen 's ochtends")
  , (TimeOfDay 8 28 0,"twee minuten voor half negen 's ochtends")
  , (TimeOfDay 8 29 0,"\233\233n minuut voor half negen 's ochtends")
  , (TimeOfDay 8 30 0,"half negen 's ochtends")
  , (TimeOfDay 8 31 0,"\233\233n minuut na half negen 's ochtends")
  , (TimeOfDay 8 32 0,"twee minuten na half negen 's ochtends")
  , (TimeOfDay 8 33 0,"drie minuten na half negen 's ochtends")
  , (TimeOfDay 8 34 0,"vier minuten na half negen 's ochtends")
  , (TimeOfDay 8 35 0,"vijf minuten na half negen 's ochtends")
  , (TimeOfDay 8 36 0,"zes minuten na half negen 's ochtends")
  , (TimeOfDay 8 37 0,"zeven minuten na half negen 's ochtends")
  , (TimeOfDay 8 38 0,"acht minuten na half negen 's ochtends")
  , (TimeOfDay 8 39 0,"negen minuten na half negen 's ochtends")
  , (TimeOfDay 8 40 0,"tien minuten na half negen 's ochtends")
  , (TimeOfDay 8 41 0,"elf minuten na half negen 's ochtends")
  , (TimeOfDay 8 42 0,"twaalf minuten na half negen 's ochtends")
  , (TimeOfDay 8 43 0,"dertien minuten na half negen 's ochtends")
  , (TimeOfDay 8 44 0,"veertien minuten na half negen 's ochtends")
  , (TimeOfDay 8 45 0,"kwart voor negen 's ochtends")
  , (TimeOfDay 8 46 0,"veertien minuten voor negen 's ochtends")
  , (TimeOfDay 8 47 0,"dertien minuten voor negen 's ochtends")
  , (TimeOfDay 8 48 0,"twaalf minuten voor negen 's ochtends")
  , (TimeOfDay 8 49 0,"elf minuten voor negen 's ochtends")
  , (TimeOfDay 8 50 0,"tien minuten voor negen 's ochtends")
  , (TimeOfDay 8 51 0,"negen minuten voor negen 's ochtends")
  , (TimeOfDay 8 52 0,"acht minuten voor negen 's ochtends")
  , (TimeOfDay 8 53 0,"zeven minuten voor negen 's ochtends")
  , (TimeOfDay 8 54 0,"zes minuten voor negen 's ochtends")
  , (TimeOfDay 8 55 0,"vijf minuten voor negen 's ochtends")
  , (TimeOfDay 8 56 0,"vier minuten voor negen 's ochtends")
  , (TimeOfDay 8 57 0,"drie minuten voor negen 's ochtends")
  , (TimeOfDay 8 58 0,"twee minuten voor negen 's ochtends")
  , (TimeOfDay 8 59 0,"\233\233n minuut voor negen 's ochtends")
  , (TimeOfDay 9 0 0,"negen uur 's ochtends")
  , (TimeOfDay 9 1 0,"\233\233n minuut na negen 's ochtends")
  , (TimeOfDay 9 2 0,"twee minuten na negen 's ochtends")
  , (TimeOfDay 9 3 0,"drie minuten na negen 's ochtends")
  , (TimeOfDay 9 4 0,"vier minuten na negen 's ochtends")
  , (TimeOfDay 9 5 0,"vijf minuten na negen 's ochtends")
  , (TimeOfDay 9 6 0,"zes minuten na negen 's ochtends")
  , (TimeOfDay 9 7 0,"zeven minuten na negen 's ochtends")
  , (TimeOfDay 9 8 0,"acht minuten na negen 's ochtends")
  , (TimeOfDay 9 9 0,"negen minuten na negen 's ochtends")
  , (TimeOfDay 9 10 0,"tien minuten na negen 's ochtends")
  , (TimeOfDay 9 11 0,"elf minuten na negen 's ochtends")
  , (TimeOfDay 9 12 0,"twaalf minuten na negen 's ochtends")
  , (TimeOfDay 9 13 0,"dertien minuten na negen 's ochtends")
  , (TimeOfDay 9 14 0,"veertien minuten na negen 's ochtends")
  , (TimeOfDay 9 15 0,"kwart na negen 's ochtends")
  , (TimeOfDay 9 16 0,"veertien minuten voor half tien 's ochtends")
  , (TimeOfDay 9 17 0,"dertien minuten voor half tien 's ochtends")
  , (TimeOfDay 9 18 0,"twaalf minuten voor half tien 's ochtends")
  , (TimeOfDay 9 19 0,"elf minuten voor half tien 's ochtends")
  , (TimeOfDay 9 20 0,"tien minuten voor half tien 's ochtends")
  , (TimeOfDay 9 21 0,"negen minuten voor half tien 's ochtends")
  , (TimeOfDay 9 22 0,"acht minuten voor half tien 's ochtends")
  , (TimeOfDay 9 23 0,"zeven minuten voor half tien 's ochtends")
  , (TimeOfDay 9 24 0,"zes minuten voor half tien 's ochtends")
  , (TimeOfDay 9 25 0,"vijf minuten voor half tien 's ochtends")
  , (TimeOfDay 9 26 0,"vier minuten voor half tien 's ochtends")
  , (TimeOfDay 9 27 0,"drie minuten voor half tien 's ochtends")
  , (TimeOfDay 9 28 0,"twee minuten voor half tien 's ochtends")
  , (TimeOfDay 9 29 0,"\233\233n minuut voor half tien 's ochtends")
  , (TimeOfDay 9 30 0,"half tien 's ochtends")
  , (TimeOfDay 9 31 0,"\233\233n minuut na half tien 's ochtends")
  , (TimeOfDay 9 32 0,"twee minuten na half tien 's ochtends")
  , (TimeOfDay 9 33 0,"drie minuten na half tien 's ochtends")
  , (TimeOfDay 9 34 0,"vier minuten na half tien 's ochtends")
  , (TimeOfDay 9 35 0,"vijf minuten na half tien 's ochtends")
  , (TimeOfDay 9 36 0,"zes minuten na half tien 's ochtends")
  , (TimeOfDay 9 37 0,"zeven minuten na half tien 's ochtends")
  , (TimeOfDay 9 38 0,"acht minuten na half tien 's ochtends")
  , (TimeOfDay 9 39 0,"negen minuten na half tien 's ochtends")
  , (TimeOfDay 9 40 0,"tien minuten na half tien 's ochtends")
  , (TimeOfDay 9 41 0,"elf minuten na half tien 's ochtends")
  , (TimeOfDay 9 42 0,"twaalf minuten na half tien 's ochtends")
  , (TimeOfDay 9 43 0,"dertien minuten na half tien 's ochtends")
  , (TimeOfDay 9 44 0,"veertien minuten na half tien 's ochtends")
  , (TimeOfDay 9 45 0,"kwart voor tien 's ochtends")
  , (TimeOfDay 9 46 0,"veertien minuten voor tien 's ochtends")
  , (TimeOfDay 9 47 0,"dertien minuten voor tien 's ochtends")
  , (TimeOfDay 9 48 0,"twaalf minuten voor tien 's ochtends")
  , (TimeOfDay 9 49 0,"elf minuten voor tien 's ochtends")
  , (TimeOfDay 9 50 0,"tien minuten voor tien 's ochtends")
  , (TimeOfDay 9 51 0,"negen minuten voor tien 's ochtends")
  , (TimeOfDay 9 52 0,"acht minuten voor tien 's ochtends")
  , (TimeOfDay 9 53 0,"zeven minuten voor tien 's ochtends")
  , (TimeOfDay 9 54 0,"zes minuten voor tien 's ochtends")
  , (TimeOfDay 9 55 0,"vijf minuten voor tien 's ochtends")
  , (TimeOfDay 9 56 0,"vier minuten voor tien 's ochtends")
  , (TimeOfDay 9 57 0,"drie minuten voor tien 's ochtends")
  , (TimeOfDay 9 58 0,"twee minuten voor tien 's ochtends")
  , (TimeOfDay 9 59 0,"\233\233n minuut voor tien 's ochtends")
  , (TimeOfDay 10 0 0,"tien uur 's ochtends")
  , (TimeOfDay 10 1 0,"\233\233n minuut na tien 's ochtends")
  , (TimeOfDay 10 2 0,"twee minuten na tien 's ochtends")
  , (TimeOfDay 10 3 0,"drie minuten na tien 's ochtends")
  , (TimeOfDay 10 4 0,"vier minuten na tien 's ochtends")
  , (TimeOfDay 10 5 0,"vijf minuten na tien 's ochtends")
  , (TimeOfDay 10 6 0,"zes minuten na tien 's ochtends")
  , (TimeOfDay 10 7 0,"zeven minuten na tien 's ochtends")
  , (TimeOfDay 10 8 0,"acht minuten na tien 's ochtends")
  , (TimeOfDay 10 9 0,"negen minuten na tien 's ochtends")
  , (TimeOfDay 10 10 0,"tien minuten na tien 's ochtends")
  , (TimeOfDay 10 11 0,"elf minuten na tien 's ochtends")
  , (TimeOfDay 10 12 0,"twaalf minuten na tien 's ochtends")
  , (TimeOfDay 10 13 0,"dertien minuten na tien 's ochtends")
  , (TimeOfDay 10 14 0,"veertien minuten na tien 's ochtends")
  , (TimeOfDay 10 15 0,"kwart na tien 's ochtends")
  , (TimeOfDay 10 16 0,"veertien minuten voor half elf 's ochtends")
  , (TimeOfDay 10 17 0,"dertien minuten voor half elf 's ochtends")
  , (TimeOfDay 10 18 0,"twaalf minuten voor half elf 's ochtends")
  , (TimeOfDay 10 19 0,"elf minuten voor half elf 's ochtends")
  , (TimeOfDay 10 20 0,"tien minuten voor half elf 's ochtends")
  , (TimeOfDay 10 21 0,"negen minuten voor half elf 's ochtends")
  , (TimeOfDay 10 22 0,"acht minuten voor half elf 's ochtends")
  , (TimeOfDay 10 23 0,"zeven minuten voor half elf 's ochtends")
  , (TimeOfDay 10 24 0,"zes minuten voor half elf 's ochtends")
  , (TimeOfDay 10 25 0,"vijf minuten voor half elf 's ochtends")
  , (TimeOfDay 10 26 0,"vier minuten voor half elf 's ochtends")
  , (TimeOfDay 10 27 0,"drie minuten voor half elf 's ochtends")
  , (TimeOfDay 10 28 0,"twee minuten voor half elf 's ochtends")
  , (TimeOfDay 10 29 0,"\233\233n minuut voor half elf 's ochtends")
  , (TimeOfDay 10 30 0,"half elf 's ochtends")
  , (TimeOfDay 10 31 0,"\233\233n minuut na half elf 's ochtends")
  , (TimeOfDay 10 32 0,"twee minuten na half elf 's ochtends")
  , (TimeOfDay 10 33 0,"drie minuten na half elf 's ochtends")
  , (TimeOfDay 10 34 0,"vier minuten na half elf 's ochtends")
  , (TimeOfDay 10 35 0,"vijf minuten na half elf 's ochtends")
  , (TimeOfDay 10 36 0,"zes minuten na half elf 's ochtends")
  , (TimeOfDay 10 37 0,"zeven minuten na half elf 's ochtends")
  , (TimeOfDay 10 38 0,"acht minuten na half elf 's ochtends")
  , (TimeOfDay 10 39 0,"negen minuten na half elf 's ochtends")
  , (TimeOfDay 10 40 0,"tien minuten na half elf 's ochtends")
  , (TimeOfDay 10 41 0,"elf minuten na half elf 's ochtends")
  , (TimeOfDay 10 42 0,"twaalf minuten na half elf 's ochtends")
  , (TimeOfDay 10 43 0,"dertien minuten na half elf 's ochtends")
  , (TimeOfDay 10 44 0,"veertien minuten na half elf 's ochtends")
  , (TimeOfDay 10 45 0,"kwart voor elf 's ochtends")
  , (TimeOfDay 10 46 0,"veertien minuten voor elf 's ochtends")
  , (TimeOfDay 10 47 0,"dertien minuten voor elf 's ochtends")
  , (TimeOfDay 10 48 0,"twaalf minuten voor elf 's ochtends")
  , (TimeOfDay 10 49 0,"elf minuten voor elf 's ochtends")
  , (TimeOfDay 10 50 0,"tien minuten voor elf 's ochtends")
  , (TimeOfDay 10 51 0,"negen minuten voor elf 's ochtends")
  , (TimeOfDay 10 52 0,"acht minuten voor elf 's ochtends")
  , (TimeOfDay 10 53 0,"zeven minuten voor elf 's ochtends")
  , (TimeOfDay 10 54 0,"zes minuten voor elf 's ochtends")
  , (TimeOfDay 10 55 0,"vijf minuten voor elf 's ochtends")
  , (TimeOfDay 10 56 0,"vier minuten voor elf 's ochtends")
  , (TimeOfDay 10 57 0,"drie minuten voor elf 's ochtends")
  , (TimeOfDay 10 58 0,"twee minuten voor elf 's ochtends")
  , (TimeOfDay 10 59 0,"\233\233n minuut voor elf 's ochtends")
  , (TimeOfDay 11 0 0,"elf uur 's ochtends")
  , (TimeOfDay 11 1 0,"\233\233n minuut na elf 's ochtends")
  , (TimeOfDay 11 2 0,"twee minuten na elf 's ochtends")
  , (TimeOfDay 11 3 0,"drie minuten na elf 's ochtends")
  , (TimeOfDay 11 4 0,"vier minuten na elf 's ochtends")
  , (TimeOfDay 11 5 0,"vijf minuten na elf 's ochtends")
  , (TimeOfDay 11 6 0,"zes minuten na elf 's ochtends")
  , (TimeOfDay 11 7 0,"zeven minuten na elf 's ochtends")
  , (TimeOfDay 11 8 0,"acht minuten na elf 's ochtends")
  , (TimeOfDay 11 9 0,"negen minuten na elf 's ochtends")
  , (TimeOfDay 11 10 0,"tien minuten na elf 's ochtends")
  , (TimeOfDay 11 11 0,"elf minuten na elf 's ochtends")
  , (TimeOfDay 11 12 0,"twaalf minuten na elf 's ochtends")
  , (TimeOfDay 11 13 0,"dertien minuten na elf 's ochtends")
  , (TimeOfDay 11 14 0,"veertien minuten na elf 's ochtends")
  , (TimeOfDay 11 15 0,"kwart na elf 's ochtends")
  , (TimeOfDay 11 16 0,"veertien minuten voor half twaalf 's ochtends")
  , (TimeOfDay 11 17 0,"dertien minuten voor half twaalf 's ochtends")
  , (TimeOfDay 11 18 0,"twaalf minuten voor half twaalf 's ochtends")
  , (TimeOfDay 11 19 0,"elf minuten voor half twaalf 's ochtends")
  , (TimeOfDay 11 20 0,"tien minuten voor half twaalf 's ochtends")
  , (TimeOfDay 11 21 0,"negen minuten voor half twaalf 's ochtends")
  , (TimeOfDay 11 22 0,"acht minuten voor half twaalf 's ochtends")
  , (TimeOfDay 11 23 0,"zeven minuten voor half twaalf 's ochtends")
  , (TimeOfDay 11 24 0,"zes minuten voor half twaalf 's ochtends")
  , (TimeOfDay 11 25 0,"vijf minuten voor half twaalf 's ochtends")
  , (TimeOfDay 11 26 0,"vier minuten voor half twaalf 's ochtends")
  , (TimeOfDay 11 27 0,"drie minuten voor half twaalf 's ochtends")
  , (TimeOfDay 11 28 0,"twee minuten voor half twaalf 's ochtends")
  , (TimeOfDay 11 29 0,"\233\233n minuut voor half twaalf 's ochtends")
  , (TimeOfDay 11 30 0,"half twaalf 's ochtends")
  , (TimeOfDay 11 31 0,"\233\233n minuut na half twaalf 's ochtends")
  , (TimeOfDay 11 32 0,"twee minuten na half twaalf 's ochtends")
  , (TimeOfDay 11 33 0,"drie minuten na half twaalf 's ochtends")
  , (TimeOfDay 11 34 0,"vier minuten na half twaalf 's ochtends")
  , (TimeOfDay 11 35 0,"vijf minuten na half twaalf 's ochtends")
  , (TimeOfDay 11 36 0,"zes minuten na half twaalf 's ochtends")
  , (TimeOfDay 11 37 0,"zeven minuten na half twaalf 's ochtends")
  , (TimeOfDay 11 38 0,"acht minuten na half twaalf 's ochtends")
  , (TimeOfDay 11 39 0,"negen minuten na half twaalf 's ochtends")
  , (TimeOfDay 11 40 0,"tien minuten na half twaalf 's ochtends")
  , (TimeOfDay 11 41 0,"elf minuten na half twaalf 's ochtends")
  , (TimeOfDay 11 42 0,"twaalf minuten na half twaalf 's ochtends")
  , (TimeOfDay 11 43 0,"dertien minuten na half twaalf 's ochtends")
  , (TimeOfDay 11 44 0,"veertien minuten na half twaalf 's ochtends")
  , (TimeOfDay 11 45 0,"kwart voor twaalf 's ochtends")
  , (TimeOfDay 11 46 0,"veertien minuten voor twaalf 's ochtends")
  , (TimeOfDay 11 47 0,"dertien minuten voor twaalf 's ochtends")
  , (TimeOfDay 11 48 0,"twaalf minuten voor twaalf 's ochtends")
  , (TimeOfDay 11 49 0,"elf minuten voor twaalf 's ochtends")
  , (TimeOfDay 11 50 0,"tien minuten voor twaalf 's ochtends")
  , (TimeOfDay 11 51 0,"negen minuten voor twaalf 's ochtends")
  , (TimeOfDay 11 52 0,"acht minuten voor twaalf 's ochtends")
  , (TimeOfDay 11 53 0,"zeven minuten voor twaalf 's ochtends")
  , (TimeOfDay 11 54 0,"zes minuten voor twaalf 's ochtends")
  , (TimeOfDay 11 55 0,"vijf minuten voor twaalf 's ochtends")
  , (TimeOfDay 11 56 0,"vier minuten voor twaalf 's ochtends")
  , (TimeOfDay 11 57 0,"drie minuten voor twaalf 's ochtends")
  , (TimeOfDay 11 58 0,"twee minuten voor twaalf 's ochtends")
  , (TimeOfDay 11 59 0,"\233\233n minuut voor twaalf 's ochtends")
  , (TimeOfDay 12 0 0,"twaalf uur 's middags")
  , (TimeOfDay 12 1 0,"\233\233n minuut na twaalf 's middags")
  , (TimeOfDay 12 2 0,"twee minuten na twaalf 's middags")
  , (TimeOfDay 12 3 0,"drie minuten na twaalf 's middags")
  , (TimeOfDay 12 4 0,"vier minuten na twaalf 's middags")
  , (TimeOfDay 12 5 0,"vijf minuten na twaalf 's middags")
  , (TimeOfDay 12 6 0,"zes minuten na twaalf 's middags")
  , (TimeOfDay 12 7 0,"zeven minuten na twaalf 's middags")
  , (TimeOfDay 12 8 0,"acht minuten na twaalf 's middags")
  , (TimeOfDay 12 9 0,"negen minuten na twaalf 's middags")
  , (TimeOfDay 12 10 0,"tien minuten na twaalf 's middags")
  , (TimeOfDay 12 11 0,"elf minuten na twaalf 's middags")
  , (TimeOfDay 12 12 0,"twaalf minuten na twaalf 's middags")
  , (TimeOfDay 12 13 0,"dertien minuten na twaalf 's middags")
  , (TimeOfDay 12 14 0,"veertien minuten na twaalf 's middags")
  , (TimeOfDay 12 15 0,"kwart na twaalf 's middags")
  , (TimeOfDay 12 16 0,"veertien minuten voor half \233\233n 's middags")
  , (TimeOfDay 12 17 0,"dertien minuten voor half \233\233n 's middags")
  , (TimeOfDay 12 18 0,"twaalf minuten voor half \233\233n 's middags")
  , (TimeOfDay 12 19 0,"elf minuten voor half \233\233n 's middags")
  , (TimeOfDay 12 20 0,"tien minuten voor half \233\233n 's middags")
  , (TimeOfDay 12 21 0,"negen minuten voor half \233\233n 's middags")
  , (TimeOfDay 12 22 0,"acht minuten voor half \233\233n 's middags")
  , (TimeOfDay 12 23 0,"zeven minuten voor half \233\233n 's middags")
  , (TimeOfDay 12 24 0,"zes minuten voor half \233\233n 's middags")
  , (TimeOfDay 12 25 0,"vijf minuten voor half \233\233n 's middags")
  , (TimeOfDay 12 26 0,"vier minuten voor half \233\233n 's middags")
  , (TimeOfDay 12 27 0,"drie minuten voor half \233\233n 's middags")
  , (TimeOfDay 12 28 0,"twee minuten voor half \233\233n 's middags")
  , (TimeOfDay 12 29 0,"\233\233n minuut voor half \233\233n 's middags")
  , (TimeOfDay 12 30 0,"half \233\233n 's middags")
  , (TimeOfDay 12 31 0,"\233\233n minuut na half \233\233n 's middags")
  , (TimeOfDay 12 32 0,"twee minuten na half \233\233n 's middags")
  , (TimeOfDay 12 33 0,"drie minuten na half \233\233n 's middags")
  , (TimeOfDay 12 34 0,"vier minuten na half \233\233n 's middags")
  , (TimeOfDay 12 35 0,"vijf minuten na half \233\233n 's middags")
  , (TimeOfDay 12 36 0,"zes minuten na half \233\233n 's middags")
  , (TimeOfDay 12 37 0,"zeven minuten na half \233\233n 's middags")
  , (TimeOfDay 12 38 0,"acht minuten na half \233\233n 's middags")
  , (TimeOfDay 12 39 0,"negen minuten na half \233\233n 's middags")
  , (TimeOfDay 12 40 0,"tien minuten na half \233\233n 's middags")
  , (TimeOfDay 12 41 0,"elf minuten na half \233\233n 's middags")
  , (TimeOfDay 12 42 0,"twaalf minuten na half \233\233n 's middags")
  , (TimeOfDay 12 43 0,"dertien minuten na half \233\233n 's middags")
  , (TimeOfDay 12 44 0,"veertien minuten na half \233\233n 's middags")
  , (TimeOfDay 12 45 0,"kwart voor \233\233n 's middags")
  , (TimeOfDay 12 46 0,"veertien minuten voor \233\233n 's middags")
  , (TimeOfDay 12 47 0,"dertien minuten voor \233\233n 's middags")
  , (TimeOfDay 12 48 0,"twaalf minuten voor \233\233n 's middags")
  , (TimeOfDay 12 49 0,"elf minuten voor \233\233n 's middags")
  , (TimeOfDay 12 50 0,"tien minuten voor \233\233n 's middags")
  , (TimeOfDay 12 51 0,"negen minuten voor \233\233n 's middags")
  , (TimeOfDay 12 52 0,"acht minuten voor \233\233n 's middags")
  , (TimeOfDay 12 53 0,"zeven minuten voor \233\233n 's middags")
  , (TimeOfDay 12 54 0,"zes minuten voor \233\233n 's middags")
  , (TimeOfDay 12 55 0,"vijf minuten voor \233\233n 's middags")
  , (TimeOfDay 12 56 0,"vier minuten voor \233\233n 's middags")
  , (TimeOfDay 12 57 0,"drie minuten voor \233\233n 's middags")
  , (TimeOfDay 12 58 0,"twee minuten voor \233\233n 's middags")
  , (TimeOfDay 12 59 0,"\233\233n minuut voor \233\233n 's middags")
  , (TimeOfDay 13 0 0,"\233\233n uur 's middags")
  , (TimeOfDay 13 1 0,"\233\233n minuut na \233\233n 's middags")
  , (TimeOfDay 13 2 0,"twee minuten na \233\233n 's middags")
  , (TimeOfDay 13 3 0,"drie minuten na \233\233n 's middags")
  , (TimeOfDay 13 4 0,"vier minuten na \233\233n 's middags")
  , (TimeOfDay 13 5 0,"vijf minuten na \233\233n 's middags")
  , (TimeOfDay 13 6 0,"zes minuten na \233\233n 's middags")
  , (TimeOfDay 13 7 0,"zeven minuten na \233\233n 's middags")
  , (TimeOfDay 13 8 0,"acht minuten na \233\233n 's middags")
  , (TimeOfDay 13 9 0,"negen minuten na \233\233n 's middags")
  , (TimeOfDay 13 10 0,"tien minuten na \233\233n 's middags")
  , (TimeOfDay 13 11 0,"elf minuten na \233\233n 's middags")
  , (TimeOfDay 13 12 0,"twaalf minuten na \233\233n 's middags")
  , (TimeOfDay 13 13 0,"dertien minuten na \233\233n 's middags")
  , (TimeOfDay 13 14 0,"veertien minuten na \233\233n 's middags")
  , (TimeOfDay 13 15 0,"kwart na \233\233n 's middags")
  , (TimeOfDay 13 16 0,"veertien minuten voor half twee 's middags")
  , (TimeOfDay 13 17 0,"dertien minuten voor half twee 's middags")
  , (TimeOfDay 13 18 0,"twaalf minuten voor half twee 's middags")
  , (TimeOfDay 13 19 0,"elf minuten voor half twee 's middags")
  , (TimeOfDay 13 20 0,"tien minuten voor half twee 's middags")
  , (TimeOfDay 13 21 0,"negen minuten voor half twee 's middags")
  , (TimeOfDay 13 22 0,"acht minuten voor half twee 's middags")
  , (TimeOfDay 13 23 0,"zeven minuten voor half twee 's middags")
  , (TimeOfDay 13 24 0,"zes minuten voor half twee 's middags")
  , (TimeOfDay 13 25 0,"vijf minuten voor half twee 's middags")
  , (TimeOfDay 13 26 0,"vier minuten voor half twee 's middags")
  , (TimeOfDay 13 27 0,"drie minuten voor half twee 's middags")
  , (TimeOfDay 13 28 0,"twee minuten voor half twee 's middags")
  , (TimeOfDay 13 29 0,"\233\233n minuut voor half twee 's middags")
  , (TimeOfDay 13 30 0,"half twee 's middags")
  , (TimeOfDay 13 31 0,"\233\233n minuut na half twee 's middags")
  , (TimeOfDay 13 32 0,"twee minuten na half twee 's middags")
  , (TimeOfDay 13 33 0,"drie minuten na half twee 's middags")
  , (TimeOfDay 13 34 0,"vier minuten na half twee 's middags")
  , (TimeOfDay 13 35 0,"vijf minuten na half twee 's middags")
  , (TimeOfDay 13 36 0,"zes minuten na half twee 's middags")
  , (TimeOfDay 13 37 0,"zeven minuten na half twee 's middags")
  , (TimeOfDay 13 38 0,"acht minuten na half twee 's middags")
  , (TimeOfDay 13 39 0,"negen minuten na half twee 's middags")
  , (TimeOfDay 13 40 0,"tien minuten na half twee 's middags")
  , (TimeOfDay 13 41 0,"elf minuten na half twee 's middags")
  , (TimeOfDay 13 42 0,"twaalf minuten na half twee 's middags")
  , (TimeOfDay 13 43 0,"dertien minuten na half twee 's middags")
  , (TimeOfDay 13 44 0,"veertien minuten na half twee 's middags")
  , (TimeOfDay 13 45 0,"kwart voor twee 's middags")
  , (TimeOfDay 13 46 0,"veertien minuten voor twee 's middags")
  , (TimeOfDay 13 47 0,"dertien minuten voor twee 's middags")
  , (TimeOfDay 13 48 0,"twaalf minuten voor twee 's middags")
  , (TimeOfDay 13 49 0,"elf minuten voor twee 's middags")
  , (TimeOfDay 13 50 0,"tien minuten voor twee 's middags")
  , (TimeOfDay 13 51 0,"negen minuten voor twee 's middags")
  , (TimeOfDay 13 52 0,"acht minuten voor twee 's middags")
  , (TimeOfDay 13 53 0,"zeven minuten voor twee 's middags")
  , (TimeOfDay 13 54 0,"zes minuten voor twee 's middags")
  , (TimeOfDay 13 55 0,"vijf minuten voor twee 's middags")
  , (TimeOfDay 13 56 0,"vier minuten voor twee 's middags")
  , (TimeOfDay 13 57 0,"drie minuten voor twee 's middags")
  , (TimeOfDay 13 58 0,"twee minuten voor twee 's middags")
  , (TimeOfDay 13 59 0,"\233\233n minuut voor twee 's middags")
  , (TimeOfDay 14 0 0,"twee uur 's middags")
  , (TimeOfDay 14 1 0,"\233\233n minuut na twee 's middags")
  , (TimeOfDay 14 2 0,"twee minuten na twee 's middags")
  , (TimeOfDay 14 3 0,"drie minuten na twee 's middags")
  , (TimeOfDay 14 4 0,"vier minuten na twee 's middags")
  , (TimeOfDay 14 5 0,"vijf minuten na twee 's middags")
  , (TimeOfDay 14 6 0,"zes minuten na twee 's middags")
  , (TimeOfDay 14 7 0,"zeven minuten na twee 's middags")
  , (TimeOfDay 14 8 0,"acht minuten na twee 's middags")
  , (TimeOfDay 14 9 0,"negen minuten na twee 's middags")
  , (TimeOfDay 14 10 0,"tien minuten na twee 's middags")
  , (TimeOfDay 14 11 0,"elf minuten na twee 's middags")
  , (TimeOfDay 14 12 0,"twaalf minuten na twee 's middags")
  , (TimeOfDay 14 13 0,"dertien minuten na twee 's middags")
  , (TimeOfDay 14 14 0,"veertien minuten na twee 's middags")
  , (TimeOfDay 14 15 0,"kwart na twee 's middags")
  , (TimeOfDay 14 16 0,"veertien minuten voor half drie 's middags")
  , (TimeOfDay 14 17 0,"dertien minuten voor half drie 's middags")
  , (TimeOfDay 14 18 0,"twaalf minuten voor half drie 's middags")
  , (TimeOfDay 14 19 0,"elf minuten voor half drie 's middags")
  , (TimeOfDay 14 20 0,"tien minuten voor half drie 's middags")
  , (TimeOfDay 14 21 0,"negen minuten voor half drie 's middags")
  , (TimeOfDay 14 22 0,"acht minuten voor half drie 's middags")
  , (TimeOfDay 14 23 0,"zeven minuten voor half drie 's middags")
  , (TimeOfDay 14 24 0,"zes minuten voor half drie 's middags")
  , (TimeOfDay 14 25 0,"vijf minuten voor half drie 's middags")
  , (TimeOfDay 14 26 0,"vier minuten voor half drie 's middags")
  , (TimeOfDay 14 27 0,"drie minuten voor half drie 's middags")
  , (TimeOfDay 14 28 0,"twee minuten voor half drie 's middags")
  , (TimeOfDay 14 29 0,"\233\233n minuut voor half drie 's middags")
  , (TimeOfDay 14 30 0,"half drie 's middags")
  , (TimeOfDay 14 31 0,"\233\233n minuut na half drie 's middags")
  , (TimeOfDay 14 32 0,"twee minuten na half drie 's middags")
  , (TimeOfDay 14 33 0,"drie minuten na half drie 's middags")
  , (TimeOfDay 14 34 0,"vier minuten na half drie 's middags")
  , (TimeOfDay 14 35 0,"vijf minuten na half drie 's middags")
  , (TimeOfDay 14 36 0,"zes minuten na half drie 's middags")
  , (TimeOfDay 14 37 0,"zeven minuten na half drie 's middags")
  , (TimeOfDay 14 38 0,"acht minuten na half drie 's middags")
  , (TimeOfDay 14 39 0,"negen minuten na half drie 's middags")
  , (TimeOfDay 14 40 0,"tien minuten na half drie 's middags")
  , (TimeOfDay 14 41 0,"elf minuten na half drie 's middags")
  , (TimeOfDay 14 42 0,"twaalf minuten na half drie 's middags")
  , (TimeOfDay 14 43 0,"dertien minuten na half drie 's middags")
  , (TimeOfDay 14 44 0,"veertien minuten na half drie 's middags")
  , (TimeOfDay 14 45 0,"kwart voor drie 's middags")
  , (TimeOfDay 14 46 0,"veertien minuten voor drie 's middags")
  , (TimeOfDay 14 47 0,"dertien minuten voor drie 's middags")
  , (TimeOfDay 14 48 0,"twaalf minuten voor drie 's middags")
  , (TimeOfDay 14 49 0,"elf minuten voor drie 's middags")
  , (TimeOfDay 14 50 0,"tien minuten voor drie 's middags")
  , (TimeOfDay 14 51 0,"negen minuten voor drie 's middags")
  , (TimeOfDay 14 52 0,"acht minuten voor drie 's middags")
  , (TimeOfDay 14 53 0,"zeven minuten voor drie 's middags")
  , (TimeOfDay 14 54 0,"zes minuten voor drie 's middags")
  , (TimeOfDay 14 55 0,"vijf minuten voor drie 's middags")
  , (TimeOfDay 14 56 0,"vier minuten voor drie 's middags")
  , (TimeOfDay 14 57 0,"drie minuten voor drie 's middags")
  , (TimeOfDay 14 58 0,"twee minuten voor drie 's middags")
  , (TimeOfDay 14 59 0,"\233\233n minuut voor drie 's middags")
  , (TimeOfDay 15 0 0,"drie uur 's middags")
  , (TimeOfDay 15 1 0,"\233\233n minuut na drie 's middags")
  , (TimeOfDay 15 2 0,"twee minuten na drie 's middags")
  , (TimeOfDay 15 3 0,"drie minuten na drie 's middags")
  , (TimeOfDay 15 4 0,"vier minuten na drie 's middags")
  , (TimeOfDay 15 5 0,"vijf minuten na drie 's middags")
  , (TimeOfDay 15 6 0,"zes minuten na drie 's middags")
  , (TimeOfDay 15 7 0,"zeven minuten na drie 's middags")
  , (TimeOfDay 15 8 0,"acht minuten na drie 's middags")
  , (TimeOfDay 15 9 0,"negen minuten na drie 's middags")
  , (TimeOfDay 15 10 0,"tien minuten na drie 's middags")
  , (TimeOfDay 15 11 0,"elf minuten na drie 's middags")
  , (TimeOfDay 15 12 0,"twaalf minuten na drie 's middags")
  , (TimeOfDay 15 13 0,"dertien minuten na drie 's middags")
  , (TimeOfDay 15 14 0,"veertien minuten na drie 's middags")
  , (TimeOfDay 15 15 0,"kwart na drie 's middags")
  , (TimeOfDay 15 16 0,"veertien minuten voor half vier 's middags")
  , (TimeOfDay 15 17 0,"dertien minuten voor half vier 's middags")
  , (TimeOfDay 15 18 0,"twaalf minuten voor half vier 's middags")
  , (TimeOfDay 15 19 0,"elf minuten voor half vier 's middags")
  , (TimeOfDay 15 20 0,"tien minuten voor half vier 's middags")
  , (TimeOfDay 15 21 0,"negen minuten voor half vier 's middags")
  , (TimeOfDay 15 22 0,"acht minuten voor half vier 's middags")
  , (TimeOfDay 15 23 0,"zeven minuten voor half vier 's middags")
  , (TimeOfDay 15 24 0,"zes minuten voor half vier 's middags")
  , (TimeOfDay 15 25 0,"vijf minuten voor half vier 's middags")
  , (TimeOfDay 15 26 0,"vier minuten voor half vier 's middags")
  , (TimeOfDay 15 27 0,"drie minuten voor half vier 's middags")
  , (TimeOfDay 15 28 0,"twee minuten voor half vier 's middags")
  , (TimeOfDay 15 29 0,"\233\233n minuut voor half vier 's middags")
  , (TimeOfDay 15 30 0,"half vier 's middags")
  , (TimeOfDay 15 31 0,"\233\233n minuut na half vier 's middags")
  , (TimeOfDay 15 32 0,"twee minuten na half vier 's middags")
  , (TimeOfDay 15 33 0,"drie minuten na half vier 's middags")
  , (TimeOfDay 15 34 0,"vier minuten na half vier 's middags")
  , (TimeOfDay 15 35 0,"vijf minuten na half vier 's middags")
  , (TimeOfDay 15 36 0,"zes minuten na half vier 's middags")
  , (TimeOfDay 15 37 0,"zeven minuten na half vier 's middags")
  , (TimeOfDay 15 38 0,"acht minuten na half vier 's middags")
  , (TimeOfDay 15 39 0,"negen minuten na half vier 's middags")
  , (TimeOfDay 15 40 0,"tien minuten na half vier 's middags")
  , (TimeOfDay 15 41 0,"elf minuten na half vier 's middags")
  , (TimeOfDay 15 42 0,"twaalf minuten na half vier 's middags")
  , (TimeOfDay 15 43 0,"dertien minuten na half vier 's middags")
  , (TimeOfDay 15 44 0,"veertien minuten na half vier 's middags")
  , (TimeOfDay 15 45 0,"kwart voor vier 's middags")
  , (TimeOfDay 15 46 0,"veertien minuten voor vier 's middags")
  , (TimeOfDay 15 47 0,"dertien minuten voor vier 's middags")
  , (TimeOfDay 15 48 0,"twaalf minuten voor vier 's middags")
  , (TimeOfDay 15 49 0,"elf minuten voor vier 's middags")
  , (TimeOfDay 15 50 0,"tien minuten voor vier 's middags")
  , (TimeOfDay 15 51 0,"negen minuten voor vier 's middags")
  , (TimeOfDay 15 52 0,"acht minuten voor vier 's middags")
  , (TimeOfDay 15 53 0,"zeven minuten voor vier 's middags")
  , (TimeOfDay 15 54 0,"zes minuten voor vier 's middags")
  , (TimeOfDay 15 55 0,"vijf minuten voor vier 's middags")
  , (TimeOfDay 15 56 0,"vier minuten voor vier 's middags")
  , (TimeOfDay 15 57 0,"drie minuten voor vier 's middags")
  , (TimeOfDay 15 58 0,"twee minuten voor vier 's middags")
  , (TimeOfDay 15 59 0,"\233\233n minuut voor vier 's middags")
  , (TimeOfDay 16 0 0,"vier uur 's middags")
  , (TimeOfDay 16 1 0,"\233\233n minuut na vier 's middags")
  , (TimeOfDay 16 2 0,"twee minuten na vier 's middags")
  , (TimeOfDay 16 3 0,"drie minuten na vier 's middags")
  , (TimeOfDay 16 4 0,"vier minuten na vier 's middags")
  , (TimeOfDay 16 5 0,"vijf minuten na vier 's middags")
  , (TimeOfDay 16 6 0,"zes minuten na vier 's middags")
  , (TimeOfDay 16 7 0,"zeven minuten na vier 's middags")
  , (TimeOfDay 16 8 0,"acht minuten na vier 's middags")
  , (TimeOfDay 16 9 0,"negen minuten na vier 's middags")
  , (TimeOfDay 16 10 0,"tien minuten na vier 's middags")
  , (TimeOfDay 16 11 0,"elf minuten na vier 's middags")
  , (TimeOfDay 16 12 0,"twaalf minuten na vier 's middags")
  , (TimeOfDay 16 13 0,"dertien minuten na vier 's middags")
  , (TimeOfDay 16 14 0,"veertien minuten na vier 's middags")
  , (TimeOfDay 16 15 0,"kwart na vier 's middags")
  , (TimeOfDay 16 16 0,"veertien minuten voor half vijf 's middags")
  , (TimeOfDay 16 17 0,"dertien minuten voor half vijf 's middags")
  , (TimeOfDay 16 18 0,"twaalf minuten voor half vijf 's middags")
  , (TimeOfDay 16 19 0,"elf minuten voor half vijf 's middags")
  , (TimeOfDay 16 20 0,"tien minuten voor half vijf 's middags")
  , (TimeOfDay 16 21 0,"negen minuten voor half vijf 's middags")
  , (TimeOfDay 16 22 0,"acht minuten voor half vijf 's middags")
  , (TimeOfDay 16 23 0,"zeven minuten voor half vijf 's middags")
  , (TimeOfDay 16 24 0,"zes minuten voor half vijf 's middags")
  , (TimeOfDay 16 25 0,"vijf minuten voor half vijf 's middags")
  , (TimeOfDay 16 26 0,"vier minuten voor half vijf 's middags")
  , (TimeOfDay 16 27 0,"drie minuten voor half vijf 's middags")
  , (TimeOfDay 16 28 0,"twee minuten voor half vijf 's middags")
  , (TimeOfDay 16 29 0,"\233\233n minuut voor half vijf 's middags")
  , (TimeOfDay 16 30 0,"half vijf 's middags")
  , (TimeOfDay 16 31 0,"\233\233n minuut na half vijf 's middags")
  , (TimeOfDay 16 32 0,"twee minuten na half vijf 's middags")
  , (TimeOfDay 16 33 0,"drie minuten na half vijf 's middags")
  , (TimeOfDay 16 34 0,"vier minuten na half vijf 's middags")
  , (TimeOfDay 16 35 0,"vijf minuten na half vijf 's middags")
  , (TimeOfDay 16 36 0,"zes minuten na half vijf 's middags")
  , (TimeOfDay 16 37 0,"zeven minuten na half vijf 's middags")
  , (TimeOfDay 16 38 0,"acht minuten na half vijf 's middags")
  , (TimeOfDay 16 39 0,"negen minuten na half vijf 's middags")
  , (TimeOfDay 16 40 0,"tien minuten na half vijf 's middags")
  , (TimeOfDay 16 41 0,"elf minuten na half vijf 's middags")
  , (TimeOfDay 16 42 0,"twaalf minuten na half vijf 's middags")
  , (TimeOfDay 16 43 0,"dertien minuten na half vijf 's middags")
  , (TimeOfDay 16 44 0,"veertien minuten na half vijf 's middags")
  , (TimeOfDay 16 45 0,"kwart voor vijf 's middags")
  , (TimeOfDay 16 46 0,"veertien minuten voor vijf 's middags")
  , (TimeOfDay 16 47 0,"dertien minuten voor vijf 's middags")
  , (TimeOfDay 16 48 0,"twaalf minuten voor vijf 's middags")
  , (TimeOfDay 16 49 0,"elf minuten voor vijf 's middags")
  , (TimeOfDay 16 50 0,"tien minuten voor vijf 's middags")
  , (TimeOfDay 16 51 0,"negen minuten voor vijf 's middags")
  , (TimeOfDay 16 52 0,"acht minuten voor vijf 's middags")
  , (TimeOfDay 16 53 0,"zeven minuten voor vijf 's middags")
  , (TimeOfDay 16 54 0,"zes minuten voor vijf 's middags")
  , (TimeOfDay 16 55 0,"vijf minuten voor vijf 's middags")
  , (TimeOfDay 16 56 0,"vier minuten voor vijf 's middags")
  , (TimeOfDay 16 57 0,"drie minuten voor vijf 's middags")
  , (TimeOfDay 16 58 0,"twee minuten voor vijf 's middags")
  , (TimeOfDay 16 59 0,"\233\233n minuut voor vijf 's middags")
  , (TimeOfDay 17 0 0,"vijf uur 's middags")
  , (TimeOfDay 17 1 0,"\233\233n minuut na vijf 's middags")
  , (TimeOfDay 17 2 0,"twee minuten na vijf 's middags")
  , (TimeOfDay 17 3 0,"drie minuten na vijf 's middags")
  , (TimeOfDay 17 4 0,"vier minuten na vijf 's middags")
  , (TimeOfDay 17 5 0,"vijf minuten na vijf 's middags")
  , (TimeOfDay 17 6 0,"zes minuten na vijf 's middags")
  , (TimeOfDay 17 7 0,"zeven minuten na vijf 's middags")
  , (TimeOfDay 17 8 0,"acht minuten na vijf 's middags")
  , (TimeOfDay 17 9 0,"negen minuten na vijf 's middags")
  , (TimeOfDay 17 10 0,"tien minuten na vijf 's middags")
  , (TimeOfDay 17 11 0,"elf minuten na vijf 's middags")
  , (TimeOfDay 17 12 0,"twaalf minuten na vijf 's middags")
  , (TimeOfDay 17 13 0,"dertien minuten na vijf 's middags")
  , (TimeOfDay 17 14 0,"veertien minuten na vijf 's middags")
  , (TimeOfDay 17 15 0,"kwart na vijf 's middags")
  , (TimeOfDay 17 16 0,"veertien minuten voor half zes 's middags")
  , (TimeOfDay 17 17 0,"dertien minuten voor half zes 's middags")
  , (TimeOfDay 17 18 0,"twaalf minuten voor half zes 's middags")
  , (TimeOfDay 17 19 0,"elf minuten voor half zes 's middags")
  , (TimeOfDay 17 20 0,"tien minuten voor half zes 's middags")
  , (TimeOfDay 17 21 0,"negen minuten voor half zes 's middags")
  , (TimeOfDay 17 22 0,"acht minuten voor half zes 's middags")
  , (TimeOfDay 17 23 0,"zeven minuten voor half zes 's middags")
  , (TimeOfDay 17 24 0,"zes minuten voor half zes 's middags")
  , (TimeOfDay 17 25 0,"vijf minuten voor half zes 's middags")
  , (TimeOfDay 17 26 0,"vier minuten voor half zes 's middags")
  , (TimeOfDay 17 27 0,"drie minuten voor half zes 's middags")
  , (TimeOfDay 17 28 0,"twee minuten voor half zes 's middags")
  , (TimeOfDay 17 29 0,"\233\233n minuut voor half zes 's middags")
  , (TimeOfDay 17 30 0,"half zes 's middags")
  , (TimeOfDay 17 31 0,"\233\233n minuut na half zes 's middags")
  , (TimeOfDay 17 32 0,"twee minuten na half zes 's middags")
  , (TimeOfDay 17 33 0,"drie minuten na half zes 's middags")
  , (TimeOfDay 17 34 0,"vier minuten na half zes 's middags")
  , (TimeOfDay 17 35 0,"vijf minuten na half zes 's middags")
  , (TimeOfDay 17 36 0,"zes minuten na half zes 's middags")
  , (TimeOfDay 17 37 0,"zeven minuten na half zes 's middags")
  , (TimeOfDay 17 38 0,"acht minuten na half zes 's middags")
  , (TimeOfDay 17 39 0,"negen minuten na half zes 's middags")
  , (TimeOfDay 17 40 0,"tien minuten na half zes 's middags")
  , (TimeOfDay 17 41 0,"elf minuten na half zes 's middags")
  , (TimeOfDay 17 42 0,"twaalf minuten na half zes 's middags")
  , (TimeOfDay 17 43 0,"dertien minuten na half zes 's middags")
  , (TimeOfDay 17 44 0,"veertien minuten na half zes 's middags")
  , (TimeOfDay 17 45 0,"kwart voor zes 's middags")
  , (TimeOfDay 17 46 0,"veertien minuten voor zes 's middags")
  , (TimeOfDay 17 47 0,"dertien minuten voor zes 's middags")
  , (TimeOfDay 17 48 0,"twaalf minuten voor zes 's middags")
  , (TimeOfDay 17 49 0,"elf minuten voor zes 's middags")
  , (TimeOfDay 17 50 0,"tien minuten voor zes 's middags")
  , (TimeOfDay 17 51 0,"negen minuten voor zes 's middags")
  , (TimeOfDay 17 52 0,"acht minuten voor zes 's middags")
  , (TimeOfDay 17 53 0,"zeven minuten voor zes 's middags")
  , (TimeOfDay 17 54 0,"zes minuten voor zes 's middags")
  , (TimeOfDay 17 55 0,"vijf minuten voor zes 's middags")
  , (TimeOfDay 17 56 0,"vier minuten voor zes 's middags")
  , (TimeOfDay 17 57 0,"drie minuten voor zes 's middags")
  , (TimeOfDay 17 58 0,"twee minuten voor zes 's middags")
  , (TimeOfDay 17 59 0,"\233\233n minuut voor zes 's middags")
  , (TimeOfDay 18 0 0,"zes uur 's avonds")
  , (TimeOfDay 18 1 0,"\233\233n minuut na zes 's avonds")
  , (TimeOfDay 18 2 0,"twee minuten na zes 's avonds")
  , (TimeOfDay 18 3 0,"drie minuten na zes 's avonds")
  , (TimeOfDay 18 4 0,"vier minuten na zes 's avonds")
  , (TimeOfDay 18 5 0,"vijf minuten na zes 's avonds")
  , (TimeOfDay 18 6 0,"zes minuten na zes 's avonds")
  , (TimeOfDay 18 7 0,"zeven minuten na zes 's avonds")
  , (TimeOfDay 18 8 0,"acht minuten na zes 's avonds")
  , (TimeOfDay 18 9 0,"negen minuten na zes 's avonds")
  , (TimeOfDay 18 10 0,"tien minuten na zes 's avonds")
  , (TimeOfDay 18 11 0,"elf minuten na zes 's avonds")
  , (TimeOfDay 18 12 0,"twaalf minuten na zes 's avonds")
  , (TimeOfDay 18 13 0,"dertien minuten na zes 's avonds")
  , (TimeOfDay 18 14 0,"veertien minuten na zes 's avonds")
  , (TimeOfDay 18 15 0,"kwart na zes 's avonds")
  , (TimeOfDay 18 16 0,"veertien minuten voor half zeven 's avonds")
  , (TimeOfDay 18 17 0,"dertien minuten voor half zeven 's avonds")
  , (TimeOfDay 18 18 0,"twaalf minuten voor half zeven 's avonds")
  , (TimeOfDay 18 19 0,"elf minuten voor half zeven 's avonds")
  , (TimeOfDay 18 20 0,"tien minuten voor half zeven 's avonds")
  , (TimeOfDay 18 21 0,"negen minuten voor half zeven 's avonds")
  , (TimeOfDay 18 22 0,"acht minuten voor half zeven 's avonds")
  , (TimeOfDay 18 23 0,"zeven minuten voor half zeven 's avonds")
  , (TimeOfDay 18 24 0,"zes minuten voor half zeven 's avonds")
  , (TimeOfDay 18 25 0,"vijf minuten voor half zeven 's avonds")
  , (TimeOfDay 18 26 0,"vier minuten voor half zeven 's avonds")
  , (TimeOfDay 18 27 0,"drie minuten voor half zeven 's avonds")
  , (TimeOfDay 18 28 0,"twee minuten voor half zeven 's avonds")
  , (TimeOfDay 18 29 0,"\233\233n minuut voor half zeven 's avonds")
  , (TimeOfDay 18 30 0,"half zeven 's avonds")
  , (TimeOfDay 18 31 0,"\233\233n minuut na half zeven 's avonds")
  , (TimeOfDay 18 32 0,"twee minuten na half zeven 's avonds")
  , (TimeOfDay 18 33 0,"drie minuten na half zeven 's avonds")
  , (TimeOfDay 18 34 0,"vier minuten na half zeven 's avonds")
  , (TimeOfDay 18 35 0,"vijf minuten na half zeven 's avonds")
  , (TimeOfDay 18 36 0,"zes minuten na half zeven 's avonds")
  , (TimeOfDay 18 37 0,"zeven minuten na half zeven 's avonds")
  , (TimeOfDay 18 38 0,"acht minuten na half zeven 's avonds")
  , (TimeOfDay 18 39 0,"negen minuten na half zeven 's avonds")
  , (TimeOfDay 18 40 0,"tien minuten na half zeven 's avonds")
  , (TimeOfDay 18 41 0,"elf minuten na half zeven 's avonds")
  , (TimeOfDay 18 42 0,"twaalf minuten na half zeven 's avonds")
  , (TimeOfDay 18 43 0,"dertien minuten na half zeven 's avonds")
  , (TimeOfDay 18 44 0,"veertien minuten na half zeven 's avonds")
  , (TimeOfDay 18 45 0,"kwart voor zeven 's avonds")
  , (TimeOfDay 18 46 0,"veertien minuten voor zeven 's avonds")
  , (TimeOfDay 18 47 0,"dertien minuten voor zeven 's avonds")
  , (TimeOfDay 18 48 0,"twaalf minuten voor zeven 's avonds")
  , (TimeOfDay 18 49 0,"elf minuten voor zeven 's avonds")
  , (TimeOfDay 18 50 0,"tien minuten voor zeven 's avonds")
  , (TimeOfDay 18 51 0,"negen minuten voor zeven 's avonds")
  , (TimeOfDay 18 52 0,"acht minuten voor zeven 's avonds")
  , (TimeOfDay 18 53 0,"zeven minuten voor zeven 's avonds")
  , (TimeOfDay 18 54 0,"zes minuten voor zeven 's avonds")
  , (TimeOfDay 18 55 0,"vijf minuten voor zeven 's avonds")
  , (TimeOfDay 18 56 0,"vier minuten voor zeven 's avonds")
  , (TimeOfDay 18 57 0,"drie minuten voor zeven 's avonds")
  , (TimeOfDay 18 58 0,"twee minuten voor zeven 's avonds")
  , (TimeOfDay 18 59 0,"\233\233n minuut voor zeven 's avonds")
  , (TimeOfDay 19 0 0,"zeven uur 's avonds")
  , (TimeOfDay 19 1 0,"\233\233n minuut na zeven 's avonds")
  , (TimeOfDay 19 2 0,"twee minuten na zeven 's avonds")
  , (TimeOfDay 19 3 0,"drie minuten na zeven 's avonds")
  , (TimeOfDay 19 4 0,"vier minuten na zeven 's avonds")
  , (TimeOfDay 19 5 0,"vijf minuten na zeven 's avonds")
  , (TimeOfDay 19 6 0,"zes minuten na zeven 's avonds")
  , (TimeOfDay 19 7 0,"zeven minuten na zeven 's avonds")
  , (TimeOfDay 19 8 0,"acht minuten na zeven 's avonds")
  , (TimeOfDay 19 9 0,"negen minuten na zeven 's avonds")
  , (TimeOfDay 19 10 0,"tien minuten na zeven 's avonds")
  , (TimeOfDay 19 11 0,"elf minuten na zeven 's avonds")
  , (TimeOfDay 19 12 0,"twaalf minuten na zeven 's avonds")
  , (TimeOfDay 19 13 0,"dertien minuten na zeven 's avonds")
  , (TimeOfDay 19 14 0,"veertien minuten na zeven 's avonds")
  , (TimeOfDay 19 15 0,"kwart na zeven 's avonds")
  , (TimeOfDay 19 16 0,"veertien minuten voor half acht 's avonds")
  , (TimeOfDay 19 17 0,"dertien minuten voor half acht 's avonds")
  , (TimeOfDay 19 18 0,"twaalf minuten voor half acht 's avonds")
  , (TimeOfDay 19 19 0,"elf minuten voor half acht 's avonds")
  , (TimeOfDay 19 20 0,"tien minuten voor half acht 's avonds")
  , (TimeOfDay 19 21 0,"negen minuten voor half acht 's avonds")
  , (TimeOfDay 19 22 0,"acht minuten voor half acht 's avonds")
  , (TimeOfDay 19 23 0,"zeven minuten voor half acht 's avonds")
  , (TimeOfDay 19 24 0,"zes minuten voor half acht 's avonds")
  , (TimeOfDay 19 25 0,"vijf minuten voor half acht 's avonds")
  , (TimeOfDay 19 26 0,"vier minuten voor half acht 's avonds")
  , (TimeOfDay 19 27 0,"drie minuten voor half acht 's avonds")
  , (TimeOfDay 19 28 0,"twee minuten voor half acht 's avonds")
  , (TimeOfDay 19 29 0,"\233\233n minuut voor half acht 's avonds")
  , (TimeOfDay 19 30 0,"half acht 's avonds")
  , (TimeOfDay 19 31 0,"\233\233n minuut na half acht 's avonds")
  , (TimeOfDay 19 32 0,"twee minuten na half acht 's avonds")
  , (TimeOfDay 19 33 0,"drie minuten na half acht 's avonds")
  , (TimeOfDay 19 34 0,"vier minuten na half acht 's avonds")
  , (TimeOfDay 19 35 0,"vijf minuten na half acht 's avonds")
  , (TimeOfDay 19 36 0,"zes minuten na half acht 's avonds")
  , (TimeOfDay 19 37 0,"zeven minuten na half acht 's avonds")
  , (TimeOfDay 19 38 0,"acht minuten na half acht 's avonds")
  , (TimeOfDay 19 39 0,"negen minuten na half acht 's avonds")
  , (TimeOfDay 19 40 0,"tien minuten na half acht 's avonds")
  , (TimeOfDay 19 41 0,"elf minuten na half acht 's avonds")
  , (TimeOfDay 19 42 0,"twaalf minuten na half acht 's avonds")
  , (TimeOfDay 19 43 0,"dertien minuten na half acht 's avonds")
  , (TimeOfDay 19 44 0,"veertien minuten na half acht 's avonds")
  , (TimeOfDay 19 45 0,"kwart voor acht 's avonds")
  , (TimeOfDay 19 46 0,"veertien minuten voor acht 's avonds")
  , (TimeOfDay 19 47 0,"dertien minuten voor acht 's avonds")
  , (TimeOfDay 19 48 0,"twaalf minuten voor acht 's avonds")
  , (TimeOfDay 19 49 0,"elf minuten voor acht 's avonds")
  , (TimeOfDay 19 50 0,"tien minuten voor acht 's avonds")
  , (TimeOfDay 19 51 0,"negen minuten voor acht 's avonds")
  , (TimeOfDay 19 52 0,"acht minuten voor acht 's avonds")
  , (TimeOfDay 19 53 0,"zeven minuten voor acht 's avonds")
  , (TimeOfDay 19 54 0,"zes minuten voor acht 's avonds")
  , (TimeOfDay 19 55 0,"vijf minuten voor acht 's avonds")
  , (TimeOfDay 19 56 0,"vier minuten voor acht 's avonds")
  , (TimeOfDay 19 57 0,"drie minuten voor acht 's avonds")
  , (TimeOfDay 19 58 0,"twee minuten voor acht 's avonds")
  , (TimeOfDay 19 59 0,"\233\233n minuut voor acht 's avonds")
  , (TimeOfDay 20 0 0,"acht uur 's avonds")
  , (TimeOfDay 20 1 0,"\233\233n minuut na acht 's avonds")
  , (TimeOfDay 20 2 0,"twee minuten na acht 's avonds")
  , (TimeOfDay 20 3 0,"drie minuten na acht 's avonds")
  , (TimeOfDay 20 4 0,"vier minuten na acht 's avonds")
  , (TimeOfDay 20 5 0,"vijf minuten na acht 's avonds")
  , (TimeOfDay 20 6 0,"zes minuten na acht 's avonds")
  , (TimeOfDay 20 7 0,"zeven minuten na acht 's avonds")
  , (TimeOfDay 20 8 0,"acht minuten na acht 's avonds")
  , (TimeOfDay 20 9 0,"negen minuten na acht 's avonds")
  , (TimeOfDay 20 10 0,"tien minuten na acht 's avonds")
  , (TimeOfDay 20 11 0,"elf minuten na acht 's avonds")
  , (TimeOfDay 20 12 0,"twaalf minuten na acht 's avonds")
  , (TimeOfDay 20 13 0,"dertien minuten na acht 's avonds")
  , (TimeOfDay 20 14 0,"veertien minuten na acht 's avonds")
  , (TimeOfDay 20 15 0,"kwart na acht 's avonds")
  , (TimeOfDay 20 16 0,"veertien minuten voor half negen 's avonds")
  , (TimeOfDay 20 17 0,"dertien minuten voor half negen 's avonds")
  , (TimeOfDay 20 18 0,"twaalf minuten voor half negen 's avonds")
  , (TimeOfDay 20 19 0,"elf minuten voor half negen 's avonds")
  , (TimeOfDay 20 20 0,"tien minuten voor half negen 's avonds")
  , (TimeOfDay 20 21 0,"negen minuten voor half negen 's avonds")
  , (TimeOfDay 20 22 0,"acht minuten voor half negen 's avonds")
  , (TimeOfDay 20 23 0,"zeven minuten voor half negen 's avonds")
  , (TimeOfDay 20 24 0,"zes minuten voor half negen 's avonds")
  , (TimeOfDay 20 25 0,"vijf minuten voor half negen 's avonds")
  , (TimeOfDay 20 26 0,"vier minuten voor half negen 's avonds")
  , (TimeOfDay 20 27 0,"drie minuten voor half negen 's avonds")
  , (TimeOfDay 20 28 0,"twee minuten voor half negen 's avonds")
  , (TimeOfDay 20 29 0,"\233\233n minuut voor half negen 's avonds")
  , (TimeOfDay 20 30 0,"half negen 's avonds")
  , (TimeOfDay 20 31 0,"\233\233n minuut na half negen 's avonds")
  , (TimeOfDay 20 32 0,"twee minuten na half negen 's avonds")
  , (TimeOfDay 20 33 0,"drie minuten na half negen 's avonds")
  , (TimeOfDay 20 34 0,"vier minuten na half negen 's avonds")
  , (TimeOfDay 20 35 0,"vijf minuten na half negen 's avonds")
  , (TimeOfDay 20 36 0,"zes minuten na half negen 's avonds")
  , (TimeOfDay 20 37 0,"zeven minuten na half negen 's avonds")
  , (TimeOfDay 20 38 0,"acht minuten na half negen 's avonds")
  , (TimeOfDay 20 39 0,"negen minuten na half negen 's avonds")
  , (TimeOfDay 20 40 0,"tien minuten na half negen 's avonds")
  , (TimeOfDay 20 41 0,"elf minuten na half negen 's avonds")
  , (TimeOfDay 20 42 0,"twaalf minuten na half negen 's avonds")
  , (TimeOfDay 20 43 0,"dertien minuten na half negen 's avonds")
  , (TimeOfDay 20 44 0,"veertien minuten na half negen 's avonds")
  , (TimeOfDay 20 45 0,"kwart voor negen 's avonds")
  , (TimeOfDay 20 46 0,"veertien minuten voor negen 's avonds")
  , (TimeOfDay 20 47 0,"dertien minuten voor negen 's avonds")
  , (TimeOfDay 20 48 0,"twaalf minuten voor negen 's avonds")
  , (TimeOfDay 20 49 0,"elf minuten voor negen 's avonds")
  , (TimeOfDay 20 50 0,"tien minuten voor negen 's avonds")
  , (TimeOfDay 20 51 0,"negen minuten voor negen 's avonds")
  , (TimeOfDay 20 52 0,"acht minuten voor negen 's avonds")
  , (TimeOfDay 20 53 0,"zeven minuten voor negen 's avonds")
  , (TimeOfDay 20 54 0,"zes minuten voor negen 's avonds")
  , (TimeOfDay 20 55 0,"vijf minuten voor negen 's avonds")
  , (TimeOfDay 20 56 0,"vier minuten voor negen 's avonds")
  , (TimeOfDay 20 57 0,"drie minuten voor negen 's avonds")
  , (TimeOfDay 20 58 0,"twee minuten voor negen 's avonds")
  , (TimeOfDay 20 59 0,"\233\233n minuut voor negen 's avonds")
  , (TimeOfDay 21 0 0,"negen uur 's avonds")
  , (TimeOfDay 21 1 0,"\233\233n minuut na negen 's avonds")
  , (TimeOfDay 21 2 0,"twee minuten na negen 's avonds")
  , (TimeOfDay 21 3 0,"drie minuten na negen 's avonds")
  , (TimeOfDay 21 4 0,"vier minuten na negen 's avonds")
  , (TimeOfDay 21 5 0,"vijf minuten na negen 's avonds")
  , (TimeOfDay 21 6 0,"zes minuten na negen 's avonds")
  , (TimeOfDay 21 7 0,"zeven minuten na negen 's avonds")
  , (TimeOfDay 21 8 0,"acht minuten na negen 's avonds")
  , (TimeOfDay 21 9 0,"negen minuten na negen 's avonds")
  , (TimeOfDay 21 10 0,"tien minuten na negen 's avonds")
  , (TimeOfDay 21 11 0,"elf minuten na negen 's avonds")
  , (TimeOfDay 21 12 0,"twaalf minuten na negen 's avonds")
  , (TimeOfDay 21 13 0,"dertien minuten na negen 's avonds")
  , (TimeOfDay 21 14 0,"veertien minuten na negen 's avonds")
  , (TimeOfDay 21 15 0,"kwart na negen 's avonds")
  , (TimeOfDay 21 16 0,"veertien minuten voor half tien 's avonds")
  , (TimeOfDay 21 17 0,"dertien minuten voor half tien 's avonds")
  , (TimeOfDay 21 18 0,"twaalf minuten voor half tien 's avonds")
  , (TimeOfDay 21 19 0,"elf minuten voor half tien 's avonds")
  , (TimeOfDay 21 20 0,"tien minuten voor half tien 's avonds")
  , (TimeOfDay 21 21 0,"negen minuten voor half tien 's avonds")
  , (TimeOfDay 21 22 0,"acht minuten voor half tien 's avonds")
  , (TimeOfDay 21 23 0,"zeven minuten voor half tien 's avonds")
  , (TimeOfDay 21 24 0,"zes minuten voor half tien 's avonds")
  , (TimeOfDay 21 25 0,"vijf minuten voor half tien 's avonds")
  , (TimeOfDay 21 26 0,"vier minuten voor half tien 's avonds")
  , (TimeOfDay 21 27 0,"drie minuten voor half tien 's avonds")
  , (TimeOfDay 21 28 0,"twee minuten voor half tien 's avonds")
  , (TimeOfDay 21 29 0,"\233\233n minuut voor half tien 's avonds")
  , (TimeOfDay 21 30 0,"half tien 's avonds")
  , (TimeOfDay 21 31 0,"\233\233n minuut na half tien 's avonds")
  , (TimeOfDay 21 32 0,"twee minuten na half tien 's avonds")
  , (TimeOfDay 21 33 0,"drie minuten na half tien 's avonds")
  , (TimeOfDay 21 34 0,"vier minuten na half tien 's avonds")
  , (TimeOfDay 21 35 0,"vijf minuten na half tien 's avonds")
  , (TimeOfDay 21 36 0,"zes minuten na half tien 's avonds")
  , (TimeOfDay 21 37 0,"zeven minuten na half tien 's avonds")
  , (TimeOfDay 21 38 0,"acht minuten na half tien 's avonds")
  , (TimeOfDay 21 39 0,"negen minuten na half tien 's avonds")
  , (TimeOfDay 21 40 0,"tien minuten na half tien 's avonds")
  , (TimeOfDay 21 41 0,"elf minuten na half tien 's avonds")
  , (TimeOfDay 21 42 0,"twaalf minuten na half tien 's avonds")
  , (TimeOfDay 21 43 0,"dertien minuten na half tien 's avonds")
  , (TimeOfDay 21 44 0,"veertien minuten na half tien 's avonds")
  , (TimeOfDay 21 45 0,"kwart voor tien 's avonds")
  , (TimeOfDay 21 46 0,"veertien minuten voor tien 's avonds")
  , (TimeOfDay 21 47 0,"dertien minuten voor tien 's avonds")
  , (TimeOfDay 21 48 0,"twaalf minuten voor tien 's avonds")
  , (TimeOfDay 21 49 0,"elf minuten voor tien 's avonds")
  , (TimeOfDay 21 50 0,"tien minuten voor tien 's avonds")
  , (TimeOfDay 21 51 0,"negen minuten voor tien 's avonds")
  , (TimeOfDay 21 52 0,"acht minuten voor tien 's avonds")
  , (TimeOfDay 21 53 0,"zeven minuten voor tien 's avonds")
  , (TimeOfDay 21 54 0,"zes minuten voor tien 's avonds")
  , (TimeOfDay 21 55 0,"vijf minuten voor tien 's avonds")
  , (TimeOfDay 21 56 0,"vier minuten voor tien 's avonds")
  , (TimeOfDay 21 57 0,"drie minuten voor tien 's avonds")
  , (TimeOfDay 21 58 0,"twee minuten voor tien 's avonds")
  , (TimeOfDay 21 59 0,"\233\233n minuut voor tien 's avonds")
  , (TimeOfDay 22 0 0,"tien uur 's avonds")
  , (TimeOfDay 22 1 0,"\233\233n minuut na tien 's avonds")
  , (TimeOfDay 22 2 0,"twee minuten na tien 's avonds")
  , (TimeOfDay 22 3 0,"drie minuten na tien 's avonds")
  , (TimeOfDay 22 4 0,"vier minuten na tien 's avonds")
  , (TimeOfDay 22 5 0,"vijf minuten na tien 's avonds")
  , (TimeOfDay 22 6 0,"zes minuten na tien 's avonds")
  , (TimeOfDay 22 7 0,"zeven minuten na tien 's avonds")
  , (TimeOfDay 22 8 0,"acht minuten na tien 's avonds")
  , (TimeOfDay 22 9 0,"negen minuten na tien 's avonds")
  , (TimeOfDay 22 10 0,"tien minuten na tien 's avonds")
  , (TimeOfDay 22 11 0,"elf minuten na tien 's avonds")
  , (TimeOfDay 22 12 0,"twaalf minuten na tien 's avonds")
  , (TimeOfDay 22 13 0,"dertien minuten na tien 's avonds")
  , (TimeOfDay 22 14 0,"veertien minuten na tien 's avonds")
  , (TimeOfDay 22 15 0,"kwart na tien 's avonds")
  , (TimeOfDay 22 16 0,"veertien minuten voor half elf 's avonds")
  , (TimeOfDay 22 17 0,"dertien minuten voor half elf 's avonds")
  , (TimeOfDay 22 18 0,"twaalf minuten voor half elf 's avonds")
  , (TimeOfDay 22 19 0,"elf minuten voor half elf 's avonds")
  , (TimeOfDay 22 20 0,"tien minuten voor half elf 's avonds")
  , (TimeOfDay 22 21 0,"negen minuten voor half elf 's avonds")
  , (TimeOfDay 22 22 0,"acht minuten voor half elf 's avonds")
  , (TimeOfDay 22 23 0,"zeven minuten voor half elf 's avonds")
  , (TimeOfDay 22 24 0,"zes minuten voor half elf 's avonds")
  , (TimeOfDay 22 25 0,"vijf minuten voor half elf 's avonds")
  , (TimeOfDay 22 26 0,"vier minuten voor half elf 's avonds")
  , (TimeOfDay 22 27 0,"drie minuten voor half elf 's avonds")
  , (TimeOfDay 22 28 0,"twee minuten voor half elf 's avonds")
  , (TimeOfDay 22 29 0,"\233\233n minuut voor half elf 's avonds")
  , (TimeOfDay 22 30 0,"half elf 's avonds")
  , (TimeOfDay 22 31 0,"\233\233n minuut na half elf 's avonds")
  , (TimeOfDay 22 32 0,"twee minuten na half elf 's avonds")
  , (TimeOfDay 22 33 0,"drie minuten na half elf 's avonds")
  , (TimeOfDay 22 34 0,"vier minuten na half elf 's avonds")
  , (TimeOfDay 22 35 0,"vijf minuten na half elf 's avonds")
  , (TimeOfDay 22 36 0,"zes minuten na half elf 's avonds")
  , (TimeOfDay 22 37 0,"zeven minuten na half elf 's avonds")
  , (TimeOfDay 22 38 0,"acht minuten na half elf 's avonds")
  , (TimeOfDay 22 39 0,"negen minuten na half elf 's avonds")
  , (TimeOfDay 22 40 0,"tien minuten na half elf 's avonds")
  , (TimeOfDay 22 41 0,"elf minuten na half elf 's avonds")
  , (TimeOfDay 22 42 0,"twaalf minuten na half elf 's avonds")
  , (TimeOfDay 22 43 0,"dertien minuten na half elf 's avonds")
  , (TimeOfDay 22 44 0,"veertien minuten na half elf 's avonds")
  , (TimeOfDay 22 45 0,"kwart voor elf 's avonds")
  , (TimeOfDay 22 46 0,"veertien minuten voor elf 's avonds")
  , (TimeOfDay 22 47 0,"dertien minuten voor elf 's avonds")
  , (TimeOfDay 22 48 0,"twaalf minuten voor elf 's avonds")
  , (TimeOfDay 22 49 0,"elf minuten voor elf 's avonds")
  , (TimeOfDay 22 50 0,"tien minuten voor elf 's avonds")
  , (TimeOfDay 22 51 0,"negen minuten voor elf 's avonds")
  , (TimeOfDay 22 52 0,"acht minuten voor elf 's avonds")
  , (TimeOfDay 22 53 0,"zeven minuten voor elf 's avonds")
  , (TimeOfDay 22 54 0,"zes minuten voor elf 's avonds")
  , (TimeOfDay 22 55 0,"vijf minuten voor elf 's avonds")
  , (TimeOfDay 22 56 0,"vier minuten voor elf 's avonds")
  , (TimeOfDay 22 57 0,"drie minuten voor elf 's avonds")
  , (TimeOfDay 22 58 0,"twee minuten voor elf 's avonds")
  , (TimeOfDay 22 59 0,"\233\233n minuut voor elf 's avonds")
  , (TimeOfDay 23 0 0,"elf uur 's avonds")
  , (TimeOfDay 23 1 0,"\233\233n minuut na elf 's avonds")
  , (TimeOfDay 23 2 0,"twee minuten na elf 's avonds")
  , (TimeOfDay 23 3 0,"drie minuten na elf 's avonds")
  , (TimeOfDay 23 4 0,"vier minuten na elf 's avonds")
  , (TimeOfDay 23 5 0,"vijf minuten na elf 's avonds")
  , (TimeOfDay 23 6 0,"zes minuten na elf 's avonds")
  , (TimeOfDay 23 7 0,"zeven minuten na elf 's avonds")
  , (TimeOfDay 23 8 0,"acht minuten na elf 's avonds")
  , (TimeOfDay 23 9 0,"negen minuten na elf 's avonds")
  , (TimeOfDay 23 10 0,"tien minuten na elf 's avonds")
  , (TimeOfDay 23 11 0,"elf minuten na elf 's avonds")
  , (TimeOfDay 23 12 0,"twaalf minuten na elf 's avonds")
  , (TimeOfDay 23 13 0,"dertien minuten na elf 's avonds")
  , (TimeOfDay 23 14 0,"veertien minuten na elf 's avonds")
  , (TimeOfDay 23 15 0,"kwart na elf 's avonds")
  , (TimeOfDay 23 16 0,"veertien minuten voor half twaalf 's avonds")
  , (TimeOfDay 23 17 0,"dertien minuten voor half twaalf 's avonds")
  , (TimeOfDay 23 18 0,"twaalf minuten voor half twaalf 's avonds")
  , (TimeOfDay 23 19 0,"elf minuten voor half twaalf 's avonds")
  , (TimeOfDay 23 20 0,"tien minuten voor half twaalf 's avonds")
  , (TimeOfDay 23 21 0,"negen minuten voor half twaalf 's avonds")
  , (TimeOfDay 23 22 0,"acht minuten voor half twaalf 's avonds")
  , (TimeOfDay 23 23 0,"zeven minuten voor half twaalf 's avonds")
  , (TimeOfDay 23 24 0,"zes minuten voor half twaalf 's avonds")
  , (TimeOfDay 23 25 0,"vijf minuten voor half twaalf 's avonds")
  , (TimeOfDay 23 26 0,"vier minuten voor half twaalf 's avonds")
  , (TimeOfDay 23 27 0,"drie minuten voor half twaalf 's avonds")
  , (TimeOfDay 23 28 0,"twee minuten voor half twaalf 's avonds")
  , (TimeOfDay 23 29 0,"\233\233n minuut voor half twaalf 's avonds")
  , (TimeOfDay 23 30 0,"half twaalf 's avonds")
  , (TimeOfDay 23 31 0,"\233\233n minuut na half twaalf 's avonds")
  , (TimeOfDay 23 32 0,"twee minuten na half twaalf 's avonds")
  , (TimeOfDay 23 33 0,"drie minuten na half twaalf 's avonds")
  , (TimeOfDay 23 34 0,"vier minuten na half twaalf 's avonds")
  , (TimeOfDay 23 35 0,"vijf minuten na half twaalf 's avonds")
  , (TimeOfDay 23 36 0,"zes minuten na half twaalf 's avonds")
  , (TimeOfDay 23 37 0,"zeven minuten na half twaalf 's avonds")
  , (TimeOfDay 23 38 0,"acht minuten na half twaalf 's avonds")
  , (TimeOfDay 23 39 0,"negen minuten na half twaalf 's avonds")
  , (TimeOfDay 23 40 0,"tien minuten na half twaalf 's avonds")
  , (TimeOfDay 23 41 0,"elf minuten na half twaalf 's avonds")
  , (TimeOfDay 23 42 0,"twaalf minuten na half twaalf 's avonds")
  , (TimeOfDay 23 43 0,"dertien minuten na half twaalf 's avonds")
  , (TimeOfDay 23 44 0,"veertien minuten na half twaalf 's avonds")
  , (TimeOfDay 23 45 0,"kwart voor twaalf 's avonds")
  , (TimeOfDay 23 46 0,"veertien minuten voor twaalf 's avonds")
  , (TimeOfDay 23 47 0,"dertien minuten voor twaalf 's avonds")
  , (TimeOfDay 23 48 0,"twaalf minuten voor twaalf 's avonds")
  , (TimeOfDay 23 49 0,"elf minuten voor twaalf 's avonds")
  , (TimeOfDay 23 50 0,"tien minuten voor twaalf 's avonds")
  , (TimeOfDay 23 51 0,"negen minuten voor twaalf 's avonds")
  , (TimeOfDay 23 52 0,"acht minuten voor twaalf 's avonds")
  , (TimeOfDay 23 53 0,"zeven minuten voor twaalf 's avonds")
  , (TimeOfDay 23 54 0,"zes minuten voor twaalf 's avonds")
  , (TimeOfDay 23 55 0,"vijf minuten voor twaalf 's avonds")
  , (TimeOfDay 23 56 0,"vier minuten voor twaalf 's avonds")
  , (TimeOfDay 23 57 0,"drie minuten voor twaalf 's avonds")
  , (TimeOfDay 23 58 0,"twee minuten voor twaalf 's avonds")
  , (TimeOfDay 23 59 0,"\233\233n minuut voor twaalf 's avonds")
  ]
