module Text.Numerals.Languages.GermanSpec (
    spec
  ) where

import Data.Text(Text)
import Data.Time.LocalTime(TimeOfDay(TimeOfDay))

import Test.Hspec(Spec)
import Text.Numerals.Languages.German(german)
import Text.Numerals.LanguageTest(testLanguage)

spec :: Spec
spec = testLanguage "German" german (cardinals <> minusCardinals) ordinals shortOrdinals clockTime

cardinals :: [(Integer, Text)]
cardinals = [
    (0, "null")
  , (1, "eins")
  , (2, "zwei")
  , (3, "drei")
  , (4, "vier")
  , (5, "fünf")
  , (6, "sechs")
  , (7, "sieben")
  , (8, "acht")
  , (9, "neun")
  , (10, "zehn")
  , (11, "elf")
  , (12, "zwölf")
  , (13, "dreizehn")
  , (14, "vierzehn")
  , (15, "fünfzehn")
  , (16, "sechzehn")
  , (17, "siebzehn")
  , (18, "achtzehn")
  , (19, "neunzehn")
  , (20, "zwanzig")
  , (21, "einundzwanzig")
  , (22, "zweiundzwanzig")
  , (23, "dreiundzwanzig")
  , (24, "vierundzwanzig")
  , (25, "fünfundzwanzig")
  , (26, "sechsundzwanzig")
  , (27, "siebenundzwanzig")
  , (28, "achtundzwanzig")
  , (29, "neunundzwanzig")
  , (30, "dreißig")
  , (31, "einunddreißig")
  , (32, "zweiunddreißig")
  , (33, "dreiunddreißig")
  , (34, "vierunddreißig")
  , (35, "fünfunddreißig")
  , (36, "sechsunddreißig")
  , (37, "siebenunddreißig")
  , (38, "achtunddreißig")
  , (39, "neununddreißig")
  , (40, "vierzig")
  , (41, "einundvierzig")
  , (42, "zweiundvierzig")
  , (43, "dreiundvierzig")
  , (44, "vierundvierzig")
  , (45, "fünfundvierzig")
  , (46, "sechsundvierzig")
  , (47, "siebenundvierzig")
  , (48, "achtundvierzig")
  , (49, "neunundvierzig")
  , (50, "fünfzig")
  , (51, "einundfünfzig")
  , (52, "zweiundfünfzig")
  , (53, "dreiundfünfzig")
  , (54, "vierundfünfzig")
  , (55, "fünfundfünfzig")
  , (56, "sechsundfünfzig")
  , (57, "siebenundfünfzig")
  , (58, "achtundfünfzig")
  , (59, "neunundfünfzig")
  , (60, "sechzig")
  , (61, "einundsechzig")
  , (62, "zweiundsechzig")
  , (63, "dreiundsechzig")
  , (64, "vierundsechzig")
  , (65, "fünfundsechzig")
  , (66, "sechsundsechzig")
  , (67, "siebenundsechzig")
  , (68, "achtundsechzig")
  , (69, "neunundsechzig")
  , (70, "siebzig")
  , (71, "einundsiebzig")
  , (72, "zweiundsiebzig")
  , (73, "dreiundsiebzig")
  , (74, "vierundsiebzig")
  , (75, "fünfundsiebzig")
  , (76, "sechsundsiebzig")
  , (77, "siebenundsiebzig")
  , (78, "achtundsiebzig")
  , (79, "neunundsiebzig")
  , (80, "achtzig")
  , (81, "einundachtzig")
  , (82, "zweiundachtzig")
  , (83, "dreiundachtzig")
  , (84, "vierundachtzig")
  , (85, "fünfundachtzig")
  , (86, "sechsundachtzig")
  , (87, "siebenundachtzig")
  , (88, "achtundachtzig")
  , (89, "neunundachtzig")
  , (90, "neunzig")
  , (91, "einundneunzig")
  , (92, "zweiundneunzig")
  , (93, "dreiundneunzig")
  , (94, "vierundneunzig")
  , (95, "fünfundneunzig")
  , (96, "sechsundneunzig")
  , (97, "siebenundneunzig")
  , (98, "achtundneunzig")
  , (99, "neunundneunzig")
  , (100, "einhundert")
  , (101, "einhunderteins")
  , (102, "einhundertzwei")
  , (103, "einhundertdrei")
  , (104, "einhundertvier")
  , (105, "einhundertfünf")
  , (106, "einhundertsechs")
  , (107, "einhundertsieben")
  , (108, "einhundertacht")
  , (109, "einhundertneun")
  , (110, "einhundertzehn")
  , (111, "einhundertelf")
  , (112, "einhundertzwölf")
  , (113, "einhundertdreizehn")
  , (114, "einhundertvierzehn")
  , (115, "einhundertfünfzehn")
  , (116, "einhundertsechzehn")
  , (117, "einhundertsiebzehn")
  , (118, "einhundertachtzehn")
  , (119, "einhundertneunzehn")
  , (120, "einhundertzwanzig")
  , (121, "einhunderteinundzwanzig")
  , (122, "einhundertzweiundzwanzig")
  , (123, "einhundertdreiundzwanzig")
  , (124, "einhundertvierundzwanzig")
  , (125, "einhundertfünfundzwanzig")
  , (126, "einhundertsechsundzwanzig")
  , (127, "einhundertsiebenundzwanzig")
  , (128, "einhundertachtundzwanzig")
  , (129, "einhundertneunundzwanzig")
  , (130, "einhundertdreißig")
  , (131, "einhunderteinunddreißig")
  , (132, "einhundertzweiunddreißig")
  , (133, "einhundertdreiunddreißig")
  , (134, "einhundertvierunddreißig")
  , (135, "einhundertfünfunddreißig")
  , (136, "einhundertsechsunddreißig")
  , (137, "einhundertsiebenunddreißig")
  , (138, "einhundertachtunddreißig")
  , (139, "einhundertneununddreißig")
  , (140, "einhundertvierzig")
  , (141, "einhunderteinundvierzig")
  , (142, "einhundertzweiundvierzig")
  , (143, "einhundertdreiundvierzig")
  , (144, "einhundertvierundvierzig")
  , (145, "einhundertfünfundvierzig")
  , (146, "einhundertsechsundvierzig")
  , (147, "einhundertsiebenundvierzig")
  , (148, "einhundertachtundvierzig")
  , (149, "einhundertneunundvierzig")
  , (150, "einhundertfünfzig")
  , (151, "einhunderteinundfünfzig")
  , (152, "einhundertzweiundfünfzig")
  , (153, "einhundertdreiundfünfzig")
  , (154, "einhundertvierundfünfzig")
  , (155, "einhundertfünfundfünfzig")
  , (156, "einhundertsechsundfünfzig")
  , (157, "einhundertsiebenundfünfzig")
  , (158, "einhundertachtundfünfzig")
  , (159, "einhundertneunundfünfzig")
  , (160, "einhundertsechzig")
  , (161, "einhunderteinundsechzig")
  , (162, "einhundertzweiundsechzig")
  , (163, "einhundertdreiundsechzig")
  , (164, "einhundertvierundsechzig")
  , (165, "einhundertfünfundsechzig")
  , (166, "einhundertsechsundsechzig")
  , (167, "einhundertsiebenundsechzig")
  , (168, "einhundertachtundsechzig")
  , (169, "einhundertneunundsechzig")
  , (170, "einhundertsiebzig")
  , (171, "einhunderteinundsiebzig")
  , (172, "einhundertzweiundsiebzig")
  , (173, "einhundertdreiundsiebzig")
  , (174, "einhundertvierundsiebzig")
  , (175, "einhundertfünfundsiebzig")
  , (176, "einhundertsechsundsiebzig")
  , (177, "einhundertsiebenundsiebzig")
  , (178, "einhundertachtundsiebzig")
  , (179, "einhundertneunundsiebzig")
  , (180, "einhundertachtzig")
  , (181, "einhunderteinundachtzig")
  , (182, "einhundertzweiundachtzig")
  , (183, "einhundertdreiundachtzig")
  , (184, "einhundertvierundachtzig")
  , (185, "einhundertfünfundachtzig")
  , (186, "einhundertsechsundachtzig")
  , (187, "einhundertsiebenundachtzig")
  , (188, "einhundertachtundachtzig")
  , (189, "einhundertneunundachtzig")
  , (190, "einhundertneunzig")
  , (191, "einhunderteinundneunzig")
  , (192, "einhundertzweiundneunzig")
  , (193, "einhundertdreiundneunzig")
  , (194, "einhundertvierundneunzig")
  , (195, "einhundertfünfundneunzig")
  , (196, "einhundertsechsundneunzig")
  , (197, "einhundertsiebenundneunzig")
  , (198, "einhundertachtundneunzig")
  , (199, "einhundertneunundneunzig")
  , (200, "zweihundert")
  , (233, "zweihundertdreiunddreißig")
  , (377, "dreihundertsiebenundsiebzig")
  , (610, "sechshundertzehn")
  , (987, "neunhundertsiebenundachtzig")
  , (1597, "eintausendfünfhundertsiebenundneunzig")
  , (2584, "zweitausendfünfhundertvierundachtzig")
  , (4181, "viertausendeinhunderteinundachtzig")
  , (6765, "sechstausendsiebenhundertfünfundsechzig")
  , (10946, "zehntausendneunhundertsechsundvierzig")
  , (17711, "siebzehntausendsiebenhundertelf")
  , (28657, "achtundzwanzigtausendsechshundertsiebenundfünfzig")
  , (46368, "sechsundvierzigtausenddreihundertachtundsechzig")
  , (75025, "fünfundsiebzigtausendfünfundzwanzig")
  , (121393, "einhunderteinundzwanzigtausenddreihundertdreiundneunzig")
  , (196418, "einhundertsechsundneunzigtausendvierhundertachtzehn")
  , (317811, "dreihundertsiebzehntausendachthundertelf")
  , (514229, "fünfhundertvierzehntausendzweihundertneunundzwanzig")
  , (832040, "achthundertzweiunddreißigtausendvierzig")
  , (1346269, "eine Million dreihundertsechsundvierzigtausendzweihundertneunundsechzig")
  , (2178309, "zwei Millionen einhundertachtundsiebzigtausenddreihundertneun")
  , (3524578, "drei Millionen fünfhundertvierundzwanzigtausendfünfhundertachtundsiebzig")
  , (5702887, "fünf Millionen siebenhundertzweitausendachthundertsiebenundachtzig")
  , (9227465, "neun Millionen zweihundertsiebenundzwanzigtausendvierhundertfünfundsechzig")
  , (14930352, "vierzehn Millionen neunhundertdreißigtausenddreihundertzweiundfünfzig")
  , (24157817, "vierundzwanzig Millionen einhundertsiebenundfünfzigtausendachthundertsiebzehn")
  , (39088169, "neununddreißig Millionen achtundachtzigtausendeinhundertneunundsechzig")
  , (63245986, "dreiundsechzig Millionen zweihundertfünfundvierzigtausendneunhundertsechsundachtzig")
  , (102334155, "einhundertzwei Millionen dreihundertvierunddreißigtausendeinhundertfünfundfünfzig")
  , (165580141, "einhundertfünfundsechzig Millionen fünfhundertachtzigtausendeinhunderteinundvierzig")
  , (267914296, "zweihundertsiebenundsechzig Millionen neunhundertvierzehntausendzweihundertsechsundneunzig")
  , (433494437, "vierhundertdreiunddreißig Millionen vierhundertvierundneunzigtausendvierhundertsiebenunddreißig")
  , (701408733, "siebenhunderteins Millionen vierhundertachttausendsiebenhundertdreiunddreißig")
  , (1134903170, "eine Milliarde einhundertvierunddreißig Millionen neunhundertdreitausendeinhundertsiebzig")
  , (1836311903, "eine Milliarde achthundertsechsunddreißig Millionen dreihundertelftausendneunhundertdrei")
  , (2971215073, "zwei Milliarden neunhunderteinundsiebzig Millionen zweihundertfünfzehntausenddreiundsiebzig")
  , (4807526976, "vier Milliarden achthundertsieben Millionen fünfhundertsechsundzwanzigtausendneunhundertsechsundsiebzig")
  , (7778742049, "sieben Milliarden siebenhundertachtundsiebzig Millionen siebenhundertzweiundvierzigtausendneunundvierzig")
  , (12586269025, "zwölf Milliarden fünfhundertsechsundachtzig Millionen zweihundertneunundsechzigtausendfünfundzwanzig")
  , (20365011074, "zwanzig Milliarden dreihundertfünfundsechzig Millionen elftausendvierundsiebzig")
  , (32951280099, "zweiunddreißig Milliarden neunhunderteinundfünfzig Millionen zweihundertachtzigtausendneunundneunzig")
  , (53316291173, "dreiundfünfzig Milliarden dreihundertsechzehn Millionen zweihunderteinundneunzigtausendeinhundertdreiundsiebzig")
  , (86267571272, "sechsundachtzig Milliarden zweihundertsiebenundsechzig Millionen fünfhunderteinundsiebzigtausendzweihundertzweiundsiebzig")
  , (139583862445, "einhundertneununddreißig Milliarden fünfhundertdreiundachtzig Millionen achthundertzweiundsechzigtausendvierhundertfünfundvierzig")
  , (225851433717, "zweihundertfünfundzwanzig Milliarden achthunderteinundfünfzig Millionen vierhundertdreiunddreißigtausendsiebenhundertsiebzehn")
  , (365435296162, "dreihundertfünfundsechzig Milliarden vierhundertfünfunddreißig Millionen zweihundertsechsundneunzigtausendeinhundertzweiundsechzig")
  , (591286729879, "fünfhunderteinundneunzig Milliarden zweihundertsechsundachtzig Millionen siebenhundertneunundzwanzigtausendachthundertneunundsiebzig")
  , (956722026041, "neunhundertsechsundfünfzig Milliarden siebenhundertzweiundzwanzig Millionen sechsundzwanzigtausendeinundvierzig")
  , (1548008755920, "eine Billion fünfhundertachtundvierzig Milliarden acht Millionen siebenhundertfünfundfünfzigtausendneunhundertzwanzig")
  , (2504730781961, "zwei Billionen fünfhundertvier Milliarden siebenhundertdreißig Millionen siebenhunderteinundachtzigtausendneunhunderteinundsechzig")
  , (4052739537881, "vier Billionen zweiundfünfzig Milliarden siebenhundertneununddreißig Millionen fünfhundertsiebenunddreißigtausendachthunderteinundachtzig")
  , (6557470319842, "sechs Billionen fünfhundertsiebenundfünfzig Milliarden vierhundertsiebzig Millionen dreihundertneunzehntausendachthundertzweiundvierzig")
  , (10610209857723, "zehn Billionen sechshundertzehn Milliarden zweihundertneun Millionen achthundertsiebenundfünfzigtausendsiebenhundertdreiundzwanzig")
  , (17167680177565, "siebzehn Billionen einhundertsiebenundsechzig Milliarden sechshundertachtzig Millionen einhundertsiebenundsiebzigtausendfünfhundertfünfundsechzig")
  , (27777890035288, "siebenundzwanzig Billionen siebenhundertsiebenundsiebzig Milliarden achthundertneunzig Millionen fünfunddreißigtausendzweihundertachtundachtzig")
  , (44945570212853, "vierundvierzig Billionen neunhundertfünfundvierzig Milliarden fünfhundertsiebzig Millionen zweihundertzwölftausendachthundertdreiundfünfzig")
  , (72723460248141, "zweiundsiebzig Billionen siebenhundertdreiundzwanzig Milliarden vierhundertsechzig Millionen zweihundertachtundvierzigtausendeinhunderteinundvierzig")
  , (117669030460994, "einhundertsiebzehn Billionen sechshundertneunundsechzig Milliarden dreißig Millionen vierhundertsechzigtausendneunhundertvierundneunzig")
  , (190392490709135, "einhundertneunzig Billionen dreihundertzweiundneunzig Milliarden vierhundertneunzig Millionen siebenhundertneuntausendeinhundertfünfunddreißig")
  , (308061521170129, "dreihundertacht Billionen einundsechzig Milliarden fünfhunderteinundzwanzig Millionen einhundertsiebzigtausendeinhundertneunundzwanzig")
  , (498454011879264, "vierhundertachtundneunzig Billionen vierhundertvierundfünfzig Milliarden elf Millionen achthundertneunundsiebzigtausendzweihundertvierundsechzig")
  , (806515533049393, "achthundertsechs Billionen fünfhundertfünfzehn Milliarden fünfhundertdreiunddreißig Millionen neunundvierzigtausenddreihundertdreiundneunzig")
  , (1304969544928657, "eine Billiarde dreihundertvier Billionen neunhundertneunundsechzig Milliarden fünfhundertvierundvierzig Millionen neunhundertachtundzwanzigtausendsechshundertsiebenundfünfzig")
  , (2111485077978050, "zwei Billiarden einhundertelf Billionen vierhundertfünfundachtzig Milliarden siebenundsiebzig Millionen neunhundertachtundsiebzigtausendfünfzig")
  , (3416454622906707, "drei Billiarden vierhundertsechzehn Billionen vierhundertvierundfünfzig Milliarden sechshundertzweiundzwanzig Millionen neunhundertsechstausendsiebenhundertsieben")
  , (5527939700884757, "fünf Billiarden fünfhundertsiebenundzwanzig Billionen neunhundertneununddreißig Milliarden siebenhundert Millionen achthundertvierundachtzigtausendsiebenhundertsiebenundfünfzig")
  , (8944394323791464, "acht Billiarden neunhundertvierundvierzig Billionen dreihundertvierundneunzig Milliarden dreihundertdreiundzwanzig Millionen siebenhunderteinundneunzigtausendvierhundertvierundsechzig")
  , (14472334024676221, "vierzehn Billiarden vierhundertzweiundsiebzig Billionen dreihundertvierunddreißig Milliarden vierundzwanzig Millionen sechshundertsechsundsiebzigtausendzweihunderteinundzwanzig")
  , (23416728348467685, "dreiundzwanzig Billiarden vierhundertsechzehn Billionen siebenhundertachtundzwanzig Milliarden dreihundertachtundvierzig Millionen vierhundertsiebenundsechzigtausendsechshundertfünfundachtzig")
  , (37889062373143906, "siebenunddreißig Billiarden achthundertneunundachtzig Billionen zweiundsechzig Milliarden dreihundertdreiundsiebzig Millionen einhundertdreiundvierzigtausendneunhundertsechs")
  , (61305790721611591, "einundsechzig Billiarden dreihundertfünf Billionen siebenhundertneunzig Milliarden siebenhunderteinundzwanzig Millionen sechshundertelftausendfünfhunderteinundneunzig")
  , (99194853094755497, "neunundneunzig Billiarden einhundertvierundneunzig Billionen achthundertdreiundfünfzig Milliarden vierundneunzig Millionen siebenhundertfünfundfünfzigtausendvierhundertsiebenundneunzig")
  , (160500643816367088, "einhundertsechzig Billiarden fünfhundert Billionen sechshundertdreiundvierzig Milliarden achthundertsechzehn Millionen dreihundertsiebenundsechzigtausendachtundachtzig")
  , (259695496911122585, "zweihundertneunundfünfzig Billiarden sechshundertfünfundneunzig Billionen vierhundertsechsundneunzig Milliarden neunhundertelf Millionen einhundertzweiundzwanzigtausendfünfhundertfünfundachtzig")
  , (420196140727489673, "vierhundertzwanzig Billiarden einhundertsechsundneunzig Billionen einhundertvierzig Milliarden siebenhundertsiebenundzwanzig Millionen vierhundertneunundachtzigtausendsechshundertdreiundsiebzig")
  , (679891637638612258, "sechshundertneunundsiebzig Billiarden achthunderteinundneunzig Billionen sechshundertsiebenunddreißig Milliarden sechshundertachtunddreißig Millionen sechshundertzwölftausendzweihundertachtundfünfzig")
  , (1100087778366101931, "eine Trillion einhundert Billiarden siebenundachtzig Billionen siebenhundertachtundsiebzig Milliarden dreihundertsechsundsechzig Millionen einhunderteinstausendneunhunderteinunddreißig")
  , (1779979416004714189, "eine Trillion siebenhundertneunundsiebzig Billiarden neunhundertneunundsiebzig Billionen vierhundertsechzehn Milliarden vier Millionen siebenhundertvierzehntausendeinhundertneunundachtzig")
  , (2880067194370816120, "zwei Trillionen achthundertachtzig Billiarden siebenundsechzig Billionen einhundertvierundneunzig Milliarden dreihundertsiebzig Millionen achthundertsechzehntausendeinhundertzwanzig")
  , (4660046610375530309, "vier Trillionen sechshundertsechzig Billiarden sechsundvierzig Billionen sechshundertzehn Milliarden dreihundertfünfundsiebzig Millionen fünfhundertdreißigtausenddreihundertneun")
  , (7540113804746346429, "sieben Trillionen fünfhundertvierzig Billiarden einhundertdreizehn Billionen achthundertvier Milliarden siebenhundertsechsundvierzig Millionen dreihundertsechsundvierzigtausendvierhundertneunundzwanzig")
  , (12200160415121876738, "zwölf Trillionen zweihundert Billiarden einhundertsechzig Billionen vierhundertfünfzehn Milliarden einhunderteinundzwanzig Millionen achthundertsechsundsiebzigtausendsiebenhundertachtunddreißig")
  , (19740274219868223167, "neunzehn Trillionen siebenhundertvierzig Billiarden zweihundertvierundsiebzig Billionen zweihundertneunzehn Milliarden achthundertachtundsechzig Millionen zweihundertdreiundzwanzigtausendeinhundertsiebenundsechzig")
  , (31940434634990099905, "einunddreißig Trillionen neunhundertvierzig Billiarden vierhundertvierunddreißig Billionen sechshundertvierunddreißig Milliarden neunhundertneunzig Millionen neunundneunzigtausendneunhundertfünf")
  , (51680708854858323072, "einundfünfzig Trillionen sechshundertachtzig Billiarden siebenhundertacht Billionen achthundertvierundfünfzig Milliarden achthundertachtundfünfzig Millionen dreihundertdreiundzwanzigtausendzweiundsiebzig")
  , (83621143489848422977, "dreiundachtzig Trillionen sechshunderteinundzwanzig Billiarden einhundertdreiundvierzig Billionen vierhundertneunundachtzig Milliarden achthundertachtundvierzig Millionen vierhundertzweiundzwanzigtausendneunhundertsiebenundsiebzig")
  , (135301852344706746049, "einhundertfünfunddreißig Trillionen dreihunderteins Billiarden achthundertzweiundfünfzig Billionen dreihundertvierundvierzig Milliarden siebenhundertsechs Millionen siebenhundertsechsundvierzigtausendneunundvierzig")
  , (218922995834555169026, "zweihundertachtzehn Trillionen neunhundertzweiundzwanzig Billiarden neunhundertfünfundneunzig Billionen achthundertvierunddreißig Milliarden fünfhundertfünfundfünfzig Millionen einhundertneunundsechzigtausendsechsundzwanzig")
  , (354224848179261915075, "dreihundertvierundfünfzig Trillionen zweihundertvierundzwanzig Billiarden achthundertachtundvierzig Billionen einhundertneunundsiebzig Milliarden zweihunderteinundsechzig Millionen neunhundertfünfzehntausendfünfundsiebzig")
  , (573147844013817084101, "fünfhundertdreiundsiebzig Trillionen einhundertsiebenundvierzig Billiarden achthundertvierundvierzig Billionen dreizehn Milliarden achthundertsiebzehn Millionen vierundachtzigtausendeinhunderteins")
  , (927372692193078999176, "neunhundertsiebenundzwanzig Trillionen dreihundertzweiundsiebzig Billiarden sechshundertzweiundneunzig Billionen einhundertdreiundneunzig Milliarden achtundsiebzig Millionen neunhundertneunundneunzigtausendeinhundertsechsundsiebzig")
  , (1500520536206896083277, "eine Trilliarde fünfhundert Trillionen fünfhundertzwanzig Billiarden fünfhundertsechsunddreißig Billionen zweihundertsechs Milliarden achthundertsechsundneunzig Millionen dreiundachtzigtausendzweihundertsiebenundsiebzig")
  , (2427893228399975082453, "zwei Trilliarden vierhundertsiebenundzwanzig Trillionen achthundertdreiundneunzig Billiarden zweihundertachtundzwanzig Billionen dreihundertneunundneunzig Milliarden neunhundertfünfundsiebzig Millionen zweiundachtzigtausendvierhundertdreiundfünfzig")
  , (3928413764606871165730, "drei Trilliarden neunhundertachtundzwanzig Trillionen vierhundertdreizehn Billiarden siebenhundertvierundsechzig Billionen sechshundertsechs Milliarden achthunderteinundsiebzig Millionen einhundertfünfundsechzigtausendsiebenhundertdreißig")
  , (6356306993006846248183, "sechs Trilliarden dreihundertsechsundfünfzig Trillionen dreihundertsechs Billiarden neunhundertdreiundneunzig Billionen sechs Milliarden achthundertsechsundvierzig Millionen zweihundertachtundvierzigtausendeinhundertdreiundachtzig")
  , (10284720757613717413913, "zehn Trilliarden zweihundertvierundachtzig Trillionen siebenhundertzwanzig Billiarden siebenhundertsiebenundfünfzig Billionen sechshundertdreizehn Milliarden siebenhundertsiebzehn Millionen vierhundertdreizehntausendneunhundertdreizehn")
  , (16641027750620563662096, "sechzehn Trilliarden sechshunderteinundvierzig Trillionen siebenundzwanzig Billiarden siebenhundertfünfzig Billionen sechshundertzwanzig Milliarden fünfhundertdreiundsechzig Millionen sechshundertzweiundsechzigtausendsechsundneunzig")
  , (26925748508234281076009, "sechsundzwanzig Trilliarden neunhundertfünfundzwanzig Trillionen siebenhundertachtundvierzig Billiarden fünfhundertacht Billionen zweihundertvierunddreißig Milliarden zweihunderteinundachtzig Millionen sechsundsiebzigtausendneun")
  , (43566776258854844738105, "dreiundvierzig Trilliarden fünfhundertsechsundsechzig Trillionen siebenhundertsechsundsiebzig Billiarden zweihundertachtundfünfzig Billionen achthundertvierundfünfzig Milliarden achthundertvierundvierzig Millionen siebenhundertachtunddreißigtausendeinhundertfünf")
  , (70492524767089125814114, "siebzig Trilliarden vierhundertzweiundneunzig Trillionen fünfhundertvierundzwanzig Billiarden siebenhundertsiebenundsechzig Billionen neunundachtzig Milliarden einhundertfünfundzwanzig Millionen achthundertvierzehntausendeinhundertvierzehn")
  , (114059301025943970552219, "einhundertvierzehn Trilliarden neunundfünfzig Trillionen dreihunderteins Billiarden fünfundzwanzig Billionen neunhundertdreiundvierzig Milliarden neunhundertsiebzig Millionen fünfhundertzweiundfünfzigtausendzweihundertneunzehn")
  , (1000, "eintausend")
  , (10000, "zehntausend")
  , (100000, "einhunderttausend")
  , (1000000, "eine Million")
  , (10000000, "zehn Millionen")
  , (100000000, "einhundert Millionen")
  , (1000000000, "eine Milliarde")
  , (10000000000, "zehn Milliarden")
  , (100000000000, "einhundert Milliarden")
  , (1000000000000, "eine Billion")
  , (10000000000000, "zehn Billionen")
  , (100000000000000, "einhundert Billionen")
  , (1000000000000000, "eine Billiarde")
  , (10000000000000000, "zehn Billiarden")
  , (100000000000000000, "einhundert Billiarden")
  , (1000000000000000000, "eine Trillion")
  , (10000000000000000000, "zehn Trillionen")
  , (100000000000000000000, "einhundert Trillionen")
  , (1000000000000000000000, "eine Trilliarde")
  , (10000000000000000000000, "zehn Trilliarden")
  , (100000000000000000000000, "einhundert Trilliarden")
  , (1000000000000000000000000, "eine Quadrillion")
  ]

minusCardinals :: [(Integer, Text)]
minusCardinals = [
    (0, "null")
  , (-1, "minus eins")
  , (-2, "minus zwei")
  , (-3, "minus drei")
  , (-4, "minus vier")
  , (-5, "minus fünf")
  , (-6, "minus sechs")
  , (-7, "minus sieben")
  , (-8, "minus acht")
  , (-9, "minus neun")
  , (-10, "minus zehn")
  , (-11, "minus elf")
  , (-12, "minus zwölf")
  , (-13, "minus dreizehn")
  , (-14, "minus vierzehn")
  , (-15, "minus fünfzehn")
  , (-16, "minus sechzehn")
  , (-17, "minus siebzehn")
  , (-18, "minus achtzehn")
  , (-19, "minus neunzehn")
  , (-20, "minus zwanzig")
  , (-21, "minus einundzwanzig")
  , (-22, "minus zweiundzwanzig")
  , (-23, "minus dreiundzwanzig")
  , (-24, "minus vierundzwanzig")
  , (-25, "minus fünfundzwanzig")
  , (-26, "minus sechsundzwanzig")
  , (-27, "minus siebenundzwanzig")
  , (-28, "minus achtundzwanzig")
  , (-29, "minus neunundzwanzig")
  , (-30, "minus dreißig")
  , (-31, "minus einunddreißig")
  , (-32, "minus zweiunddreißig")
  , (-33, "minus dreiunddreißig")
  , (-34, "minus vierunddreißig")
  , (-35, "minus fünfunddreißig")
  , (-36, "minus sechsunddreißig")
  , (-37, "minus siebenunddreißig")
  , (-38, "minus achtunddreißig")
  , (-39, "minus neununddreißig")
  , (-40, "minus vierzig")
  , (-41, "minus einundvierzig")
  , (-42, "minus zweiundvierzig")
  , (-43, "minus dreiundvierzig")
  , (-44, "minus vierundvierzig")
  , (-45, "minus fünfundvierzig")
  , (-46, "minus sechsundvierzig")
  , (-47, "minus siebenundvierzig")
  , (-48, "minus achtundvierzig")
  , (-49, "minus neunundvierzig")
  , (-50, "minus fünfzig")
  , (-51, "minus einundfünfzig")
  , (-52, "minus zweiundfünfzig")
  , (-53, "minus dreiundfünfzig")
  , (-54, "minus vierundfünfzig")
  , (-55, "minus fünfundfünfzig")
  , (-56, "minus sechsundfünfzig")
  , (-57, "minus siebenundfünfzig")
  , (-58, "minus achtundfünfzig")
  , (-59, "minus neunundfünfzig")
  , (-60, "minus sechzig")
  , (-61, "minus einundsechzig")
  , (-62, "minus zweiundsechzig")
  , (-63, "minus dreiundsechzig")
  , (-64, "minus vierundsechzig")
  , (-65, "minus fünfundsechzig")
  , (-66, "minus sechsundsechzig")
  , (-67, "minus siebenundsechzig")
  , (-68, "minus achtundsechzig")
  , (-69, "minus neunundsechzig")
  , (-70, "minus siebzig")
  , (-71, "minus einundsiebzig")
  , (-72, "minus zweiundsiebzig")
  , (-73, "minus dreiundsiebzig")
  , (-74, "minus vierundsiebzig")
  , (-75, "minus fünfundsiebzig")
  , (-76, "minus sechsundsiebzig")
  , (-77, "minus siebenundsiebzig")
  , (-78, "minus achtundsiebzig")
  , (-79, "minus neunundsiebzig")
  , (-80, "minus achtzig")
  , (-81, "minus einundachtzig")
  , (-82, "minus zweiundachtzig")
  , (-83, "minus dreiundachtzig")
  , (-84, "minus vierundachtzig")
  , (-85, "minus fünfundachtzig")
  , (-86, "minus sechsundachtzig")
  , (-87, "minus siebenundachtzig")
  , (-88, "minus achtundachtzig")
  , (-89, "minus neunundachtzig")
  , (-90, "minus neunzig")
  , (-91, "minus einundneunzig")
  , (-92, "minus zweiundneunzig")
  , (-93, "minus dreiundneunzig")
  , (-94, "minus vierundneunzig")
  , (-95, "minus fünfundneunzig")
  , (-96, "minus sechsundneunzig")
  , (-97, "minus siebenundneunzig")
  , (-98, "minus achtundneunzig")
  , (-99, "minus neunundneunzig")
  , (-100, "minus einhundert")
  , (-101, "minus einhunderteins")
  , (-102, "minus einhundertzwei")
  , (-103, "minus einhundertdrei")
  , (-104, "minus einhundertvier")
  , (-105, "minus einhundertfünf")
  , (-106, "minus einhundertsechs")
  , (-107, "minus einhundertsieben")
  , (-108, "minus einhundertacht")
  , (-109, "minus einhundertneun")
  , (-110, "minus einhundertzehn")
  , (-111, "minus einhundertelf")
  , (-112, "minus einhundertzwölf")
  , (-113, "minus einhundertdreizehn")
  , (-114, "minus einhundertvierzehn")
  , (-115, "minus einhundertfünfzehn")
  , (-116, "minus einhundertsechzehn")
  , (-117, "minus einhundertsiebzehn")
  , (-118, "minus einhundertachtzehn")
  , (-119, "minus einhundertneunzehn")
  , (-120, "minus einhundertzwanzig")
  , (-121, "minus einhunderteinundzwanzig")
  , (-122, "minus einhundertzweiundzwanzig")
  , (-123, "minus einhundertdreiundzwanzig")
  , (-124, "minus einhundertvierundzwanzig")
  , (-125, "minus einhundertfünfundzwanzig")
  , (-126, "minus einhundertsechsundzwanzig")
  , (-127, "minus einhundertsiebenundzwanzig")
  , (-128, "minus einhundertachtundzwanzig")
  , (-129, "minus einhundertneunundzwanzig")
  , (-130, "minus einhundertdreißig")
  , (-131, "minus einhunderteinunddreißig")
  , (-132, "minus einhundertzweiunddreißig")
  , (-133, "minus einhundertdreiunddreißig")
  , (-134, "minus einhundertvierunddreißig")
  , (-135, "minus einhundertfünfunddreißig")
  , (-136, "minus einhundertsechsunddreißig")
  , (-137, "minus einhundertsiebenunddreißig")
  , (-138, "minus einhundertachtunddreißig")
  , (-139, "minus einhundertneununddreißig")
  , (-140, "minus einhundertvierzig")
  , (-141, "minus einhunderteinundvierzig")
  , (-142, "minus einhundertzweiundvierzig")
  , (-143, "minus einhundertdreiundvierzig")
  , (-144, "minus einhundertvierundvierzig")
  , (-145, "minus einhundertfünfundvierzig")
  , (-146, "minus einhundertsechsundvierzig")
  , (-147, "minus einhundertsiebenundvierzig")
  , (-148, "minus einhundertachtundvierzig")
  , (-149, "minus einhundertneunundvierzig")
  , (-150, "minus einhundertfünfzig")
  , (-151, "minus einhunderteinundfünfzig")
  , (-152, "minus einhundertzweiundfünfzig")
  , (-153, "minus einhundertdreiundfünfzig")
  , (-154, "minus einhundertvierundfünfzig")
  , (-155, "minus einhundertfünfundfünfzig")
  , (-156, "minus einhundertsechsundfünfzig")
  , (-157, "minus einhundertsiebenundfünfzig")
  , (-158, "minus einhundertachtundfünfzig")
  , (-159, "minus einhundertneunundfünfzig")
  , (-160, "minus einhundertsechzig")
  , (-161, "minus einhunderteinundsechzig")
  , (-162, "minus einhundertzweiundsechzig")
  , (-163, "minus einhundertdreiundsechzig")
  , (-164, "minus einhundertvierundsechzig")
  , (-165, "minus einhundertfünfundsechzig")
  , (-166, "minus einhundertsechsundsechzig")
  , (-167, "minus einhundertsiebenundsechzig")
  , (-168, "minus einhundertachtundsechzig")
  , (-169, "minus einhundertneunundsechzig")
  , (-170, "minus einhundertsiebzig")
  , (-171, "minus einhunderteinundsiebzig")
  , (-172, "minus einhundertzweiundsiebzig")
  , (-173, "minus einhundertdreiundsiebzig")
  , (-174, "minus einhundertvierundsiebzig")
  , (-175, "minus einhundertfünfundsiebzig")
  , (-176, "minus einhundertsechsundsiebzig")
  , (-177, "minus einhundertsiebenundsiebzig")
  , (-178, "minus einhundertachtundsiebzig")
  , (-179, "minus einhundertneunundsiebzig")
  , (-180, "minus einhundertachtzig")
  , (-181, "minus einhunderteinundachtzig")
  , (-182, "minus einhundertzweiundachtzig")
  , (-183, "minus einhundertdreiundachtzig")
  , (-184, "minus einhundertvierundachtzig")
  , (-185, "minus einhundertfünfundachtzig")
  , (-186, "minus einhundertsechsundachtzig")
  , (-187, "minus einhundertsiebenundachtzig")
  , (-188, "minus einhundertachtundachtzig")
  , (-189, "minus einhundertneunundachtzig")
  , (-190, "minus einhundertneunzig")
  , (-191, "minus einhunderteinundneunzig")
  , (-192, "minus einhundertzweiundneunzig")
  , (-193, "minus einhundertdreiundneunzig")
  , (-194, "minus einhundertvierundneunzig")
  , (-195, "minus einhundertfünfundneunzig")
  , (-196, "minus einhundertsechsundneunzig")
  , (-197, "minus einhundertsiebenundneunzig")
  , (-198, "minus einhundertachtundneunzig")
  , (-199, "minus einhundertneunundneunzig")
  , (-200, "minus zweihundert")
  ]

ordinals :: [(Integer, Text)]
ordinals = [
    (0, "nullte")
  , (1, "erste")
  , (2, "zweite")
  , (3, "dritte")
  , (4, "vierte")
  , (5, "fünfte")
  , (6, "sechste")
  , (7, "siebte")
  , (8, "achte")
  , (9, "neunte")
  , (10, "zehnte")
  , (11, "elfte")
  , (12, "zwölfte")
  , (13, "dreizehnte")
  , (14, "vierzehnte")
  , (15, "fünfzehnte")
  , (16, "sechzehnte")
  , (17, "siebzehnte")
  , (18, "achtzehnte")
  , (19, "neunzehnte")
  , (20, "zwanzigste")
  , (21, "einundzwanzigste")
  , (22, "zweiundzwanzigste")
  , (23, "dreiundzwanzigste")
  , (24, "vierundzwanzigste")
  , (25, "fünfundzwanzigste")
  , (26, "sechsundzwanzigste")
  , (27, "siebenundzwanzigste")
  , (28, "achtundzwanzigste")
  , (29, "neunundzwanzigste")
  , (30, "dreißigste")
  , (31, "einunddreißigste")
  , (32, "zweiunddreißigste")
  , (33, "dreiunddreißigste")
  , (34, "vierunddreißigste")
  , (35, "fünfunddreißigste")
  , (36, "sechsunddreißigste")
  , (37, "siebenunddreißigste")
  , (38, "achtunddreißigste")
  , (39, "neununddreißigste")
  , (40, "vierzigste")
  , (41, "einundvierzigste")
  , (42, "zweiundvierzigste")
  , (43, "dreiundvierzigste")
  , (44, "vierundvierzigste")
  , (45, "fünfundvierzigste")
  , (46, "sechsundvierzigste")
  , (47, "siebenundvierzigste")
  , (48, "achtundvierzigste")
  , (49, "neunundvierzigste")
  , (50, "fünfzigste")
  , (51, "einundfünfzigste")
  , (52, "zweiundfünfzigste")
  , (53, "dreiundfünfzigste")
  , (54, "vierundfünfzigste")
  , (55, "fünfundfünfzigste")
  , (56, "sechsundfünfzigste")
  , (57, "siebenundfünfzigste")
  , (58, "achtundfünfzigste")
  , (59, "neunundfünfzigste")
  , (60, "sechzigste")
  , (61, "einundsechzigste")
  , (62, "zweiundsechzigste")
  , (63, "dreiundsechzigste")
  , (64, "vierundsechzigste")
  , (65, "fünfundsechzigste")
  , (66, "sechsundsechzigste")
  , (67, "siebenundsechzigste")
  , (68, "achtundsechzigste")
  , (69, "neunundsechzigste")
  , (70, "siebzigste")
  , (71, "einundsiebzigste")
  , (72, "zweiundsiebzigste")
  , (73, "dreiundsiebzigste")
  , (74, "vierundsiebzigste")
  , (75, "fünfundsiebzigste")
  , (76, "sechsundsiebzigste")
  , (77, "siebenundsiebzigste")
  , (78, "achtundsiebzigste")
  , (79, "neunundsiebzigste")
  , (80, "achtzigste")
  , (81, "einundachtzigste")
  , (82, "zweiundachtzigste")
  , (83, "dreiundachtzigste")
  , (84, "vierundachtzigste")
  , (85, "fünfundachtzigste")
  , (86, "sechsundachtzigste")
  , (87, "siebenundachtzigste")
  , (88, "achtundachtzigste")
  , (89, "neunundachtzigste")
  , (90, "neunzigste")
  , (91, "einundneunzigste")
  , (92, "zweiundneunzigste")
  , (93, "dreiundneunzigste")
  , (94, "vierundneunzigste")
  , (95, "fünfundneunzigste")
  , (96, "sechsundneunzigste")
  , (97, "siebenundneunzigste")
  , (98, "achtundneunzigste")
  , (99, "neunundneunzigste")
  , (100, "hundertste")
  , (101, "einhunderterste")
  , (102, "einhundertzweite")
  , (103, "einhundertdritte")
  , (104, "einhundertvierte")
  , (105, "einhundertfünfte")
  , (106, "einhundertsechste")
  , (107, "einhundertsiebte")
  , (108, "einhundertachte")
  , (109, "einhundertneunte")
  , (110, "einhundertzehnte")
  , (111, "einhundertelfte")
  , (112, "einhundertzwölfte")
  , (113, "einhundertdreizehnte")
  , (114, "einhundertvierzehnte")
  , (115, "einhundertfünfzehnte")
  , (116, "einhundertsechzehnte")
  , (117, "einhundertsiebzehnte")
  , (118, "einhundertachtzehnte")
  , (119, "einhundertneunzehnte")
  , (120, "einhundertzwanzigste")
  , (121, "einhunderteinundzwanzigste")
  , (122, "einhundertzweiundzwanzigste")
  , (123, "einhundertdreiundzwanzigste")
  , (124, "einhundertvierundzwanzigste")
  , (125, "einhundertfünfundzwanzigste")
  , (126, "einhundertsechsundzwanzigste")
  , (127, "einhundertsiebenundzwanzigste")
  , (128, "einhundertachtundzwanzigste")
  , (129, "einhundertneunundzwanzigste")
  , (130, "einhundertdreißigste")
  , (131, "einhunderteinunddreißigste")
  , (132, "einhundertzweiunddreißigste")
  , (133, "einhundertdreiunddreißigste")
  , (134, "einhundertvierunddreißigste")
  , (135, "einhundertfünfunddreißigste")
  , (136, "einhundertsechsunddreißigste")
  , (137, "einhundertsiebenunddreißigste")
  , (138, "einhundertachtunddreißigste")
  , (139, "einhundertneununddreißigste")
  , (140, "einhundertvierzigste")
  , (141, "einhunderteinundvierzigste")
  , (142, "einhundertzweiundvierzigste")
  , (143, "einhundertdreiundvierzigste")
  , (144, "einhundertvierundvierzigste")
  , (145, "einhundertfünfundvierzigste")
  , (146, "einhundertsechsundvierzigste")
  , (147, "einhundertsiebenundvierzigste")
  , (148, "einhundertachtundvierzigste")
  , (149, "einhundertneunundvierzigste")
  , (150, "einhundertfünfzigste")
  , (151, "einhunderteinundfünfzigste")
  , (152, "einhundertzweiundfünfzigste")
  , (153, "einhundertdreiundfünfzigste")
  , (154, "einhundertvierundfünfzigste")
  , (155, "einhundertfünfundfünfzigste")
  , (156, "einhundertsechsundfünfzigste")
  , (157, "einhundertsiebenundfünfzigste")
  , (158, "einhundertachtundfünfzigste")
  , (159, "einhundertneunundfünfzigste")
  , (160, "einhundertsechzigste")
  , (161, "einhunderteinundsechzigste")
  , (162, "einhundertzweiundsechzigste")
  , (163, "einhundertdreiundsechzigste")
  , (164, "einhundertvierundsechzigste")
  , (165, "einhundertfünfundsechzigste")
  , (166, "einhundertsechsundsechzigste")
  , (167, "einhundertsiebenundsechzigste")
  , (168, "einhundertachtundsechzigste")
  , (169, "einhundertneunundsechzigste")
  , (170, "einhundertsiebzigste")
  , (171, "einhunderteinundsiebzigste")
  , (172, "einhundertzweiundsiebzigste")
  , (173, "einhundertdreiundsiebzigste")
  , (174, "einhundertvierundsiebzigste")
  , (175, "einhundertfünfundsiebzigste")
  , (176, "einhundertsechsundsiebzigste")
  , (177, "einhundertsiebenundsiebzigste")
  , (178, "einhundertachtundsiebzigste")
  , (179, "einhundertneunundsiebzigste")
  , (180, "einhundertachtzigste")
  , (181, "einhunderteinundachtzigste")
  , (182, "einhundertzweiundachtzigste")
  , (183, "einhundertdreiundachtzigste")
  , (184, "einhundertvierundachtzigste")
  , (185, "einhundertfünfundachtzigste")
  , (186, "einhundertsechsundachtzigste")
  , (187, "einhundertsiebenundachtzigste")
  , (188, "einhundertachtundachtzigste")
  , (189, "einhundertneunundachtzigste")
  , (190, "einhundertneunzigste")
  , (191, "einhunderteinundneunzigste")
  , (192, "einhundertzweiundneunzigste")
  , (193, "einhundertdreiundneunzigste")
  , (194, "einhundertvierundneunzigste")
  , (195, "einhundertfünfundneunzigste")
  , (196, "einhundertsechsundneunzigste")
  , (197, "einhundertsiebenundneunzigste")
  , (198, "einhundertachtundneunzigste")
  , (199, "einhundertneunundneunzigste")
  , (200, "zweihundertste")
  , (233, "zweihundertdreiunddreißigste")
  , (377, "dreihundertsiebenundsiebzigste")
  , (610, "sechshundertzehnte")
  , (987, "neunhundertsiebenundachtzigste")
  , (1597, "eintausendfünfhundertsiebenundneunzigste")
  , (2584, "zweitausendfünfhundertvierundachtzigste")
  , (4181, "viertausendeinhunderteinundachtzigste")
  , (6765, "sechstausendsiebenhundertfünfundsechzigste")
  , (10946, "zehntausendneunhundertsechsundvierzigste")
  , (17711, "siebzehntausendsiebenhundertelfte")
  , (28657, "achtundzwanzigtausendsechshundertsiebenundfünfzigste")
  , (46368, "sechsundvierzigtausenddreihundertachtundsechzigste")
  , (75025, "fünfundsiebzigtausendfünfundzwanzigste")
  , (121393, "einhunderteinundzwanzigtausenddreihundertdreiundneunzigste")
  , (196418, "einhundertsechsundneunzigtausendvierhundertachtzehnte")
  , (317811, "dreihundertsiebzehntausendachthundertelfte")
  , (514229, "fünfhundertvierzehntausendzweihundertneunundzwanzigste")
  , (832040, "achthundertzweiunddreißigtausendvierzigste")
  , (1346269, "eine million dreihundertsechsundvierzigtausendzweihundertneunundsechzigste")
  , (2178309, "zwei millionen einhundertachtundsiebzigtausenddreihundertneunte")
  , (3524578, "drei millionen fünfhundertvierundzwanzigtausendfünfhundertachtundsiebzigste")
  , (5702887, "fünf millionen siebenhundertzweitausendachthundertsiebenundachtzigste")
  , (9227465, "neun millionen zweihundertsiebenundzwanzigtausendvierhundertfünfundsechzigste")
  , (14930352, "vierzehn millionen neunhundertdreißigtausenddreihundertzweiundfünfzigste")
  , (24157817, "vierundzwanzig millionen einhundertsiebenundfünfzigtausendachthundertsiebzehnte")
  , (39088169, "neununddreißig millionen achtundachtzigtausendeinhundertneunundsechzigste")
  , (63245986, "dreiundsechzig millionen zweihundertfünfundvierzigtausendneunhundertsechsundachtzigste")
  , (102334155, "einhundertzwei millionen dreihundertvierunddreißigtausendeinhundertfünfundfünfzigste")
  , (165580141, "einhundertfünfundsechzig millionen fünfhundertachtzigtausendeinhunderteinundvierzigste")
  , (267914296, "zweihundertsiebenundsechzig millionen neunhundertvierzehntausendzweihundertsechsundneunzigste")
  , (433494437, "vierhundertdreiunddreißig millionen vierhundertvierundneunzigtausendvierhundertsiebenunddreißigste")
  , (701408733, "siebenhunderteins millionen vierhundertachttausendsiebenhundertdreiunddreißigste")
  , (1134903170, "eine milliarde einhundertvierunddreißig millionen neunhundertdreitausendeinhundertsiebzigste")
  , (1836311903, "eine milliarde achthundertsechsunddreißig millionen dreihundertelftausendneunhundertdritte")
  , (2971215073, "zwei milliarden neunhunderteinundsiebzig millionen zweihundertfünfzehntausenddreiundsiebzigste")
  , (4807526976, "vier milliarden achthundertsieben millionen fünfhundertsechsundzwanzigtausendneunhundertsechsundsiebzigste")
  , (7778742049, "sieben milliarden siebenhundertachtundsiebzig millionen siebenhundertzweiundvierzigtausendneunundvierzigste")
  , (12586269025, "zwölf milliarden fünfhundertsechsundachtzig millionen zweihundertneunundsechzigtausendfünfundzwanzigste")
  , (20365011074, "zwanzig milliarden dreihundertfünfundsechzig millionen elftausendvierundsiebzigste")
  , (32951280099, "zweiunddreißig milliarden neunhunderteinundfünfzig millionen zweihundertachtzigtausendneunundneunzigste")
  , (53316291173, "dreiundfünfzig milliarden dreihundertsechzehn millionen zweihunderteinundneunzigtausendeinhundertdreiundsiebzigste")
  , (86267571272, "sechsundachtzig milliarden zweihundertsiebenundsechzig millionen fünfhunderteinundsiebzigtausendzweihundertzweiundsiebzigste")
  , (139583862445, "einhundertneununddreißig milliarden fünfhundertdreiundachtzig millionen achthundertzweiundsechzigtausendvierhundertfünfundvierzigste")
  , (225851433717, "zweihundertfünfundzwanzig milliarden achthunderteinundfünfzig millionen vierhundertdreiunddreißigtausendsiebenhundertsiebzehnte")
  , (365435296162, "dreihundertfünfundsechzig milliarden vierhundertfünfunddreißig millionen zweihundertsechsundneunzigtausendeinhundertzweiundsechzigste")
  , (591286729879, "fünfhunderteinundneunzig milliarden zweihundertsechsundachtzig millionen siebenhundertneunundzwanzigtausendachthundertneunundsiebzigste")
  , (956722026041, "neunhundertsechsundfünfzig milliarden siebenhundertzweiundzwanzig millionen sechsundzwanzigtausendeinundvierzigste")
  , (1548008755920, "eine billion fünfhundertachtundvierzig milliarden acht millionen siebenhundertfünfundfünfzigtausendneunhundertzwanzigste")
  , (2504730781961, "zwei billionen fünfhundertvier milliarden siebenhundertdreißig millionen siebenhunderteinundachtzigtausendneunhunderteinundsechzigste")
  , (4052739537881, "vier billionen zweiundfünfzig milliarden siebenhundertneununddreißig millionen fünfhundertsiebenunddreißigtausendachthunderteinundachtzigste")
  , (6557470319842, "sechs billionen fünfhundertsiebenundfünfzig milliarden vierhundertsiebzig millionen dreihundertneunzehntausendachthundertzweiundvierzigste")
  , (10610209857723, "zehn billionen sechshundertzehn milliarden zweihundertneun millionen achthundertsiebenundfünfzigtausendsiebenhundertdreiundzwanzigste")
  , (17167680177565, "siebzehn billionen einhundertsiebenundsechzig milliarden sechshundertachtzig millionen einhundertsiebenundsiebzigtausendfünfhundertfünfundsechzigste")
  , (27777890035288, "siebenundzwanzig billionen siebenhundertsiebenundsiebzig milliarden achthundertneunzig millionen fünfunddreißigtausendzweihundertachtundachtzigste")
  , (44945570212853, "vierundvierzig billionen neunhundertfünfundvierzig milliarden fünfhundertsiebzig millionen zweihundertzwölftausendachthundertdreiundfünfzigste")
  , (72723460248141, "zweiundsiebzig billionen siebenhundertdreiundzwanzig milliarden vierhundertsechzig millionen zweihundertachtundvierzigtausendeinhunderteinundvierzigste")
  , (117669030460994, "einhundertsiebzehn billionen sechshundertneunundsechzig milliarden dreißig millionen vierhundertsechzigtausendneunhundertvierundneunzigste")
  , (190392490709135, "einhundertneunzig billionen dreihundertzweiundneunzig milliarden vierhundertneunzig millionen siebenhundertneuntausendeinhundertfünfunddreißigste")
  , (308061521170129, "dreihundertacht billionen einundsechzig milliarden fünfhunderteinundzwanzig millionen einhundertsiebzigtausendeinhundertneunundzwanzigste")
  , (498454011879264, "vierhundertachtundneunzig billionen vierhundertvierundfünfzig milliarden elf millionen achthundertneunundsiebzigtausendzweihundertvierundsechzigste")
  , (806515533049393, "achthundertsechs billionen fünfhundertfünfzehn milliarden fünfhundertdreiunddreißig millionen neunundvierzigtausenddreihundertdreiundneunzigste")
  , (1304969544928657, "eine billiarde dreihundertvier billionen neunhundertneunundsechzig milliarden fünfhundertvierundvierzig millionen neunhundertachtundzwanzigtausendsechshundertsiebenundfünfzigste")
  , (2111485077978050, "zwei billiarden einhundertelf billionen vierhundertfünfundachtzig milliarden siebenundsiebzig millionen neunhundertachtundsiebzigtausendfünfzigste")
  , (3416454622906707, "drei billiarden vierhundertsechzehn billionen vierhundertvierundfünfzig milliarden sechshundertzweiundzwanzig millionen neunhundertsechstausendsiebenhundertsiebte")
  , (5527939700884757, "fünf billiarden fünfhundertsiebenundzwanzig billionen neunhundertneununddreißig milliarden siebenhundert millionen achthundertvierundachtzigtausendsiebenhundertsiebenundfünfzigste")
  , (8944394323791464, "acht billiarden neunhundertvierundvierzig billionen dreihundertvierundneunzig milliarden dreihundertdreiundzwanzig millionen siebenhunderteinundneunzigtausendvierhundertvierundsechzigste")
  , (14472334024676221, "vierzehn billiarden vierhundertzweiundsiebzig billionen dreihundertvierunddreißig milliarden vierundzwanzig millionen sechshundertsechsundsiebzigtausendzweihunderteinundzwanzigste")
  , (23416728348467685, "dreiundzwanzig billiarden vierhundertsechzehn billionen siebenhundertachtundzwanzig milliarden dreihundertachtundvierzig millionen vierhundertsiebenundsechzigtausendsechshundertfünfundachtzigste")
  , (37889062373143906, "siebenunddreißig billiarden achthundertneunundachtzig billionen zweiundsechzig milliarden dreihundertdreiundsiebzig millionen einhundertdreiundvierzigtausendneunhundertsechste")
  , (61305790721611591, "einundsechzig billiarden dreihundertfünf billionen siebenhundertneunzig milliarden siebenhunderteinundzwanzig millionen sechshundertelftausendfünfhunderteinundneunzigste")
  , (99194853094755497, "neunundneunzig billiarden einhundertvierundneunzig billionen achthundertdreiundfünfzig milliarden vierundneunzig millionen siebenhundertfünfundfünfzigtausendvierhundertsiebenundneunzigste")
  , (160500643816367088, "einhundertsechzig billiarden fünfhundert billionen sechshundertdreiundvierzig milliarden achthundertsechzehn millionen dreihundertsiebenundsechzigtausendachtundachtzigste")
  , (259695496911122585, "zweihundertneunundfünfzig billiarden sechshundertfünfundneunzig billionen vierhundertsechsundneunzig milliarden neunhundertelf millionen einhundertzweiundzwanzigtausendfünfhundertfünfundachtzigste")
  , (420196140727489673, "vierhundertzwanzig billiarden einhundertsechsundneunzig billionen einhundertvierzig milliarden siebenhundertsiebenundzwanzig millionen vierhundertneunundachtzigtausendsechshundertdreiundsiebzigste")
  , (679891637638612258, "sechshundertneunundsiebzig billiarden achthunderteinundneunzig billionen sechshundertsiebenunddreißig milliarden sechshundertachtunddreißig millionen sechshundertzwölftausendzweihundertachtundfünfzigste")
  , (1100087778366101931, "eine trillion einhundert billiarden siebenundachtzig billionen siebenhundertachtundsiebzig milliarden dreihundertsechsundsechzig millionen einhunderteinstausendneunhunderteinunddreißigste")
  , (1779979416004714189, "eine trillion siebenhundertneunundsiebzig billiarden neunhundertneunundsiebzig billionen vierhundertsechzehn milliarden vier millionen siebenhundertvierzehntausendeinhundertneunundachtzigste")
  , (2880067194370816120, "zwei trillionen achthundertachtzig billiarden siebenundsechzig billionen einhundertvierundneunzig milliarden dreihundertsiebzig millionen achthundertsechzehntausendeinhundertzwanzigste")
  , (4660046610375530309, "vier trillionen sechshundertsechzig billiarden sechsundvierzig billionen sechshundertzehn milliarden dreihundertfünfundsiebzig millionen fünfhundertdreißigtausenddreihundertneunte")
  , (7540113804746346429, "sieben trillionen fünfhundertvierzig billiarden einhundertdreizehn billionen achthundertvier milliarden siebenhundertsechsundvierzig millionen dreihundertsechsundvierzigtausendvierhundertneunundzwanzigste")
  , (12200160415121876738, "zwölf trillionen zweihundert billiarden einhundertsechzig billionen vierhundertfünfzehn milliarden einhunderteinundzwanzig millionen achthundertsechsundsiebzigtausendsiebenhundertachtunddreißigste")
  , (19740274219868223167, "neunzehn trillionen siebenhundertvierzig billiarden zweihundertvierundsiebzig billionen zweihundertneunzehn milliarden achthundertachtundsechzig millionen zweihundertdreiundzwanzigtausendeinhundertsiebenundsechzigste")
  , (31940434634990099905, "einunddreißig trillionen neunhundertvierzig billiarden vierhundertvierunddreißig billionen sechshundertvierunddreißig milliarden neunhundertneunzig millionen neunundneunzigtausendneunhundertfünfte")
  , (51680708854858323072, "einundfünfzig trillionen sechshundertachtzig billiarden siebenhundertacht billionen achthundertvierundfünfzig milliarden achthundertachtundfünfzig millionen dreihundertdreiundzwanzigtausendzweiundsiebzigste")
  , (83621143489848422977, "dreiundachtzig trillionen sechshunderteinundzwanzig billiarden einhundertdreiundvierzig billionen vierhundertneunundachtzig milliarden achthundertachtundvierzig millionen vierhundertzweiundzwanzigtausendneunhundertsiebenundsiebzigste")
  , (135301852344706746049, "einhundertfünfunddreißig trillionen dreihunderteins billiarden achthundertzweiundfünfzig billionen dreihundertvierundvierzig milliarden siebenhundertsechs millionen siebenhundertsechsundvierzigtausendneunundvierzigste")
  , (218922995834555169026, "zweihundertachtzehn trillionen neunhundertzweiundzwanzig billiarden neunhundertfünfundneunzig billionen achthundertvierunddreißig milliarden fünfhundertfünfundfünfzig millionen einhundertneunundsechzigtausendsechsundzwanzigste")
  , (354224848179261915075, "dreihundertvierundfünfzig trillionen zweihundertvierundzwanzig billiarden achthundertachtundvierzig billionen einhundertneunundsiebzig milliarden zweihunderteinundsechzig millionen neunhundertfünfzehntausendfünfundsiebzigste")
  , (573147844013817084101, "fünfhundertdreiundsiebzig trillionen einhundertsiebenundvierzig billiarden achthundertvierundvierzig billionen dreizehn milliarden achthundertsiebzehn millionen vierundachtzigtausendeinhunderterste")
  , (927372692193078999176, "neunhundertsiebenundzwanzig trillionen dreihundertzweiundsiebzig billiarden sechshundertzweiundneunzig billionen einhundertdreiundneunzig milliarden achtundsiebzig millionen neunhundertneunundneunzigtausendeinhundertsechsundsiebzigste")
  , (1500520536206896083277, "eine trilliarde fünfhundert trillionen fünfhundertzwanzig billiarden fünfhundertsechsunddreißig billionen zweihundertsechs milliarden achthundertsechsundneunzig millionen dreiundachtzigtausendzweihundertsiebenundsiebzigste")
  , (2427893228399975082453, "zwei trilliarden vierhundertsiebenundzwanzig trillionen achthundertdreiundneunzig billiarden zweihundertachtundzwanzig billionen dreihundertneunundneunzig milliarden neunhundertfünfundsiebzig millionen zweiundachtzigtausendvierhundertdreiundfünfzigste")
  , (3928413764606871165730, "drei trilliarden neunhundertachtundzwanzig trillionen vierhundertdreizehn billiarden siebenhundertvierundsechzig billionen sechshundertsechs milliarden achthunderteinundsiebzig millionen einhundertfünfundsechzigtausendsiebenhundertdreißigste")
  , (6356306993006846248183, "sechs trilliarden dreihundertsechsundfünfzig trillionen dreihundertsechs billiarden neunhundertdreiundneunzig billionen sechs milliarden achthundertsechsundvierzig millionen zweihundertachtundvierzigtausendeinhundertdreiundachtzigste")
  , (10284720757613717413913, "zehn trilliarden zweihundertvierundachtzig trillionen siebenhundertzwanzig billiarden siebenhundertsiebenundfünfzig billionen sechshundertdreizehn milliarden siebenhundertsiebzehn millionen vierhundertdreizehntausendneunhundertdreizehnte")
  , (16641027750620563662096, "sechzehn trilliarden sechshunderteinundvierzig trillionen siebenundzwanzig billiarden siebenhundertfünfzig billionen sechshundertzwanzig milliarden fünfhundertdreiundsechzig millionen sechshundertzweiundsechzigtausendsechsundneunzigste")
  , (26925748508234281076009, "sechsundzwanzig trilliarden neunhundertfünfundzwanzig trillionen siebenhundertachtundvierzig billiarden fünfhundertacht billionen zweihundertvierunddreißig milliarden zweihunderteinundachtzig millionen sechsundsiebzigtausendneunte")
  , (43566776258854844738105, "dreiundvierzig trilliarden fünfhundertsechsundsechzig trillionen siebenhundertsechsundsiebzig billiarden zweihundertachtundfünfzig billionen achthundertvierundfünfzig milliarden achthundertvierundvierzig millionen siebenhundertachtunddreißigtausendeinhundertfünfte")
  , (70492524767089125814114, "siebzig trilliarden vierhundertzweiundneunzig trillionen fünfhundertvierundzwanzig billiarden siebenhundertsiebenundsechzig billionen neunundachtzig milliarden einhundertfünfundzwanzig millionen achthundertvierzehntausendeinhundertvierzehnte")
  , (114059301025943970552219, "einhundertvierzehn trilliarden neunundfünfzig trillionen dreihunderteins billiarden fünfundzwanzig billionen neunhundertdreiundvierzig milliarden neunhundertsiebzig millionen fünfhundertzweiundfünfzigtausendzweihundertneunzehnte")
  , (1000, "tausendste")
  , (10000, "zehntausendste")
  , (100000, "einhunderttausendste")
  , (1000000, "millionste")
  , (10000000, "zehnmillionste")
  , (100000000, "einhundertmillionste")
  , (1000000000, "milliardste")
  , (10000000000, "zehnmilliardste")
  , (100000000000, "einhundertmilliardste")
  , (1000000000000, "billionste")
  , (10000000000000, "zehnbillionste")
  , (100000000000000, "einhundertbillionste")
  , (1000000000000000, "billiardste")
  , (10000000000000000, "zehnbilliardste")
  , (100000000000000000, "einhundertbilliardste")
  , (1000000000000000000, "trillionste")
  , (10000000000000000000, "zehntrillionste")
  , (100000000000000000000, "einhunderttrillionste")
  , (1000000000000000000000, "trilliardste")
  , (10000000000000000000000, "zehntrilliardste")
  , (100000000000000000000000, "einhunderttrilliardste")
  , (1000000000000000000000000, "quadrillionste")
  ]

shortOrdinals :: [(Integer, Text)]
shortOrdinals = [
    (0, "0.")
  , (1, "1.")
  , (2, "2.")
  , (3, "3.")
  , (4, "4.")
  , (5, "5.")
  , (6, "6.")
  , (7, "7.")
  , (8, "8.")
  , (9, "9.")
  , (10, "10.")
  , (11, "11.")
  , (12, "12.")
  , (13, "13.")
  , (14, "14.")
  , (15, "15.")
  , (16, "16.")
  , (17, "17.")
  , (18, "18.")
  , (19, "19.")
  , (20, "20.")
  , (21, "21.")
  , (22, "22.")
  , (23, "23.")
  , (24, "24.")
  , (25, "25.")
  , (26, "26.")
  , (27, "27.")
  , (28, "28.")
  , (29, "29.")
  , (30, "30.")
  , (31, "31.")
  , (32, "32.")
  , (33, "33.")
  , (34, "34.")
  , (35, "35.")
  , (36, "36.")
  , (37, "37.")
  , (38, "38.")
  , (39, "39.")
  , (40, "40.")
  , (41, "41.")
  , (42, "42.")
  , (43, "43.")
  , (44, "44.")
  , (45, "45.")
  , (46, "46.")
  , (47, "47.")
  , (48, "48.")
  , (49, "49.")
  , (50, "50.")
  , (51, "51.")
  , (52, "52.")
  , (53, "53.")
  , (54, "54.")
  , (55, "55.")
  , (56, "56.")
  , (57, "57.")
  , (58, "58.")
  , (59, "59.")
  , (60, "60.")
  , (61, "61.")
  , (62, "62.")
  , (63, "63.")
  , (64, "64.")
  , (65, "65.")
  , (66, "66.")
  , (67, "67.")
  , (68, "68.")
  , (69, "69.")
  , (70, "70.")
  , (71, "71.")
  , (72, "72.")
  , (73, "73.")
  , (74, "74.")
  , (75, "75.")
  , (76, "76.")
  , (77, "77.")
  , (78, "78.")
  , (79, "79.")
  , (80, "80.")
  , (81, "81.")
  , (82, "82.")
  , (83, "83.")
  , (84, "84.")
  , (85, "85.")
  , (86, "86.")
  , (87, "87.")
  , (88, "88.")
  , (89, "89.")
  , (90, "90.")
  , (91, "91.")
  , (92, "92.")
  , (93, "93.")
  , (94, "94.")
  , (95, "95.")
  , (96, "96.")
  , (97, "97.")
  , (98, "98.")
  , (99, "99.")
  , (100, "100.")
  , (101, "101.")
  , (102, "102.")
  , (103, "103.")
  , (104, "104.")
  , (105, "105.")
  , (106, "106.")
  , (107, "107.")
  , (108, "108.")
  , (109, "109.")
  , (110, "110.")
  , (111, "111.")
  , (112, "112.")
  , (113, "113.")
  , (114, "114.")
  , (115, "115.")
  , (116, "116.")
  , (117, "117.")
  , (118, "118.")
  , (119, "119.")
  , (120, "120.")
  , (121, "121.")
  , (122, "122.")
  , (123, "123.")
  , (124, "124.")
  , (125, "125.")
  , (126, "126.")
  , (127, "127.")
  , (128, "128.")
  , (129, "129.")
  , (130, "130.")
  , (131, "131.")
  , (132, "132.")
  , (133, "133.")
  , (134, "134.")
  , (135, "135.")
  , (136, "136.")
  , (137, "137.")
  , (138, "138.")
  , (139, "139.")
  , (140, "140.")
  , (141, "141.")
  , (142, "142.")
  , (143, "143.")
  , (144, "144.")
  , (145, "145.")
  , (146, "146.")
  , (147, "147.")
  , (148, "148.")
  , (149, "149.")
  , (150, "150.")
  , (151, "151.")
  , (152, "152.")
  , (153, "153.")
  , (154, "154.")
  , (155, "155.")
  , (156, "156.")
  , (157, "157.")
  , (158, "158.")
  , (159, "159.")
  , (160, "160.")
  , (161, "161.")
  , (162, "162.")
  , (163, "163.")
  , (164, "164.")
  , (165, "165.")
  , (166, "166.")
  , (167, "167.")
  , (168, "168.")
  , (169, "169.")
  , (170, "170.")
  , (171, "171.")
  , (172, "172.")
  , (173, "173.")
  , (174, "174.")
  , (175, "175.")
  , (176, "176.")
  , (177, "177.")
  , (178, "178.")
  , (179, "179.")
  , (180, "180.")
  , (181, "181.")
  , (182, "182.")
  , (183, "183.")
  , (184, "184.")
  , (185, "185.")
  , (186, "186.")
  , (187, "187.")
  , (188, "188.")
  , (189, "189.")
  , (190, "190.")
  , (191, "191.")
  , (192, "192.")
  , (193, "193.")
  , (194, "194.")
  , (195, "195.")
  , (196, "196.")
  , (197, "197.")
  , (198, "198.")
  , (199, "199.")
  , (200, "200.")
  , (233, "233.")
  , (377, "377.")
  , (610, "610.")
  , (987, "987.")
  , (1597, "1597.")
  , (2584, "2584.")
  , (4181, "4181.")
  , (6765, "6765.")
  , (10946, "10946.")
  , (17711, "17711.")
  , (28657, "28657.")
  , (46368, "46368.")
  , (75025, "75025.")
  , (121393, "121393.")
  , (196418, "196418.")
  , (317811, "317811.")
  , (514229, "514229.")
  , (832040, "832040.")
  , (1346269, "1346269.")
  , (2178309, "2178309.")
  , (3524578, "3524578.")
  , (5702887, "5702887.")
  , (9227465, "9227465.")
  , (14930352, "14930352.")
  , (24157817, "24157817.")
  , (39088169, "39088169.")
  , (63245986, "63245986.")
  , (102334155, "102334155.")
  , (165580141, "165580141.")
  , (267914296, "267914296.")
  , (433494437, "433494437.")
  , (701408733, "701408733.")
  , (1134903170, "1134903170.")
  , (1836311903, "1836311903.")
  , (2971215073, "2971215073.")
  , (4807526976, "4807526976.")
  , (7778742049, "7778742049.")
  , (12586269025, "12586269025.")
  , (20365011074, "20365011074.")
  , (32951280099, "32951280099.")
  , (53316291173, "53316291173.")
  , (86267571272, "86267571272.")
  , (139583862445, "139583862445.")
  , (225851433717, "225851433717.")
  , (365435296162, "365435296162.")
  , (591286729879, "591286729879.")
  , (956722026041, "956722026041.")
  , (1548008755920, "1548008755920.")
  , (2504730781961, "2504730781961.")
  , (4052739537881, "4052739537881.")
  , (6557470319842, "6557470319842.")
  , (10610209857723, "10610209857723.")
  , (17167680177565, "17167680177565.")
  , (27777890035288, "27777890035288.")
  , (44945570212853, "44945570212853.")
  , (72723460248141, "72723460248141.")
  , (117669030460994, "117669030460994.")
  , (190392490709135, "190392490709135.")
  , (308061521170129, "308061521170129.")
  , (498454011879264, "498454011879264.")
  , (806515533049393, "806515533049393.")
  , (1304969544928657, "1304969544928657.")
  , (2111485077978050, "2111485077978050.")
  , (3416454622906707, "3416454622906707.")
  , (5527939700884757, "5527939700884757.")
  , (8944394323791464, "8944394323791464.")
  , (14472334024676221, "14472334024676221.")
  , (23416728348467685, "23416728348467685.")
  , (37889062373143906, "37889062373143906.")
  , (61305790721611591, "61305790721611591.")
  , (99194853094755497, "99194853094755497.")
  , (160500643816367088, "160500643816367088.")
  , (259695496911122585, "259695496911122585.")
  , (420196140727489673, "420196140727489673.")
  , (679891637638612258, "679891637638612258.")
  , (1100087778366101931, "1100087778366101931.")
  , (1779979416004714189, "1779979416004714189.")
  , (2880067194370816120, "2880067194370816120.")
  , (4660046610375530309, "4660046610375530309.")
  , (7540113804746346429, "7540113804746346429.")
  , (12200160415121876738, "12200160415121876738.")
  , (19740274219868223167, "19740274219868223167.")
  , (31940434634990099905, "31940434634990099905.")
  , (51680708854858323072, "51680708854858323072.")
  , (83621143489848422977, "83621143489848422977.")
  , (135301852344706746049, "135301852344706746049.")
  , (218922995834555169026, "218922995834555169026.")
  , (354224848179261915075, "354224848179261915075.")
  , (573147844013817084101, "573147844013817084101.")
  , (927372692193078999176, "927372692193078999176.")
  , (1500520536206896083277, "1500520536206896083277.")
  , (2427893228399975082453, "2427893228399975082453.")
  , (3928413764606871165730, "3928413764606871165730.")
  , (6356306993006846248183, "6356306993006846248183.")
  , (10284720757613717413913, "10284720757613717413913.")
  , (16641027750620563662096, "16641027750620563662096.")
  , (26925748508234281076009, "26925748508234281076009.")
  , (43566776258854844738105, "43566776258854844738105.")
  , (70492524767089125814114, "70492524767089125814114.")
  , (114059301025943970552219, "114059301025943970552219.")
  , (1000, "1000.")
  , (10000, "10000.")
  , (100000, "100000.")
  , (1000000, "1000000.")
  , (10000000, "10000000.")
  , (100000000, "100000000.")
  , (1000000000, "1000000000.")
  , (10000000000, "10000000000.")
  , (100000000000, "100000000000.")
  , (1000000000000, "1000000000000.")
  , (10000000000000, "10000000000000.")
  , (100000000000000, "100000000000000.")
  , (1000000000000000, "1000000000000000.")
  , (10000000000000000, "10000000000000000.")
  , (100000000000000000, "100000000000000000.")
  , (1000000000000000000, "1000000000000000000.")
  , (10000000000000000000, "10000000000000000000.")
  , (100000000000000000000, "100000000000000000000.")
  , (1000000000000000000000, "1000000000000000000000.")
  , (10000000000000000000000, "10000000000000000000000.")
  , (100000000000000000000000, "100000000000000000000000.")
  , (1000000000000000000000000, "1000000000000000000000000.")
  ]

clockTime :: [(TimeOfDay, Text)]
clockTime = [
    (TimeOfDay 0 0 0,"null Uhr")
  , (TimeOfDay 0 1 0,"null Uhr eins")
  , (TimeOfDay 0 2 0,"null Uhr zwei")
  , (TimeOfDay 0 3 0,"null Uhr drei")
  , (TimeOfDay 0 4 0,"null Uhr vier")
  , (TimeOfDay 0 5 0,"null Uhr f\252nf")
  , (TimeOfDay 0 6 0,"null Uhr sechs")
  , (TimeOfDay 0 7 0,"null Uhr sieben")
  , (TimeOfDay 0 8 0,"null Uhr acht")
  , (TimeOfDay 0 9 0,"null Uhr neun")
  , (TimeOfDay 0 10 0,"null Uhr zehn")
  , (TimeOfDay 0 11 0,"null Uhr elf")
  , (TimeOfDay 0 12 0,"null Uhr zw\246lf")
  , (TimeOfDay 0 13 0,"null Uhr dreizehn")
  , (TimeOfDay 0 14 0,"null Uhr vierzehn")
  , (TimeOfDay 0 15 0,"null Uhr f\252nfzehn")
  , (TimeOfDay 0 16 0,"null Uhr sechzehn")
  , (TimeOfDay 0 17 0,"null Uhr siebzehn")
  , (TimeOfDay 0 18 0,"null Uhr achtzehn")
  , (TimeOfDay 0 19 0,"null Uhr neunzehn")
  , (TimeOfDay 0 20 0,"null Uhr zwanzig")
  , (TimeOfDay 0 21 0,"null Uhr einundzwanzig")
  , (TimeOfDay 0 22 0,"null Uhr zweiundzwanzig")
  , (TimeOfDay 0 23 0,"null Uhr dreiundzwanzig")
  , (TimeOfDay 0 24 0,"null Uhr vierundzwanzig")
  , (TimeOfDay 0 25 0,"null Uhr f\252nfundzwanzig")
  , (TimeOfDay 0 26 0,"null Uhr sechsundzwanzig")
  , (TimeOfDay 0 27 0,"null Uhr siebenundzwanzig")
  , (TimeOfDay 0 28 0,"null Uhr achtundzwanzig")
  , (TimeOfDay 0 29 0,"null Uhr neunundzwanzig")
  , (TimeOfDay 0 30 0,"null Uhr drei\223ig")
  , (TimeOfDay 0 31 0,"null Uhr einunddrei\223ig")
  , (TimeOfDay 0 32 0,"null Uhr zweiunddrei\223ig")
  , (TimeOfDay 0 33 0,"null Uhr dreiunddrei\223ig")
  , (TimeOfDay 0 34 0,"null Uhr vierunddrei\223ig")
  , (TimeOfDay 0 35 0,"null Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 0 36 0,"null Uhr sechsunddrei\223ig")
  , (TimeOfDay 0 37 0,"null Uhr siebenunddrei\223ig")
  , (TimeOfDay 0 38 0,"null Uhr achtunddrei\223ig")
  , (TimeOfDay 0 39 0,"null Uhr neununddrei\223ig")
  , (TimeOfDay 0 40 0,"null Uhr vierzig")
  , (TimeOfDay 0 41 0,"null Uhr einundvierzig")
  , (TimeOfDay 0 42 0,"null Uhr zweiundvierzig")
  , (TimeOfDay 0 43 0,"null Uhr dreiundvierzig")
  , (TimeOfDay 0 44 0,"null Uhr vierundvierzig")
  , (TimeOfDay 0 45 0,"null Uhr f\252nfundvierzig")
  , (TimeOfDay 0 46 0,"null Uhr sechsundvierzig")
  , (TimeOfDay 0 47 0,"null Uhr siebenundvierzig")
  , (TimeOfDay 0 48 0,"null Uhr achtundvierzig")
  , (TimeOfDay 0 49 0,"null Uhr neunundvierzig")
  , (TimeOfDay 0 50 0,"null Uhr f\252nfzig")
  , (TimeOfDay 0 51 0,"null Uhr einundf\252nfzig")
  , (TimeOfDay 0 52 0,"null Uhr zweiundf\252nfzig")
  , (TimeOfDay 0 53 0,"null Uhr dreiundf\252nfzig")
  , (TimeOfDay 0 54 0,"null Uhr vierundf\252nfzig")
  , (TimeOfDay 0 55 0,"null Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 0 56 0,"null Uhr sechsundf\252nfzig")
  , (TimeOfDay 0 57 0,"null Uhr siebenundf\252nfzig")
  , (TimeOfDay 0 58 0,"null Uhr achtundf\252nfzig")
  , (TimeOfDay 0 59 0,"null Uhr neunundf\252nfzig")
  , (TimeOfDay 1 0 0,"eins Uhr")
  , (TimeOfDay 1 1 0,"eins Uhr eins")
  , (TimeOfDay 1 2 0,"eins Uhr zwei")
  , (TimeOfDay 1 3 0,"eins Uhr drei")
  , (TimeOfDay 1 4 0,"eins Uhr vier")
  , (TimeOfDay 1 5 0,"eins Uhr f\252nf")
  , (TimeOfDay 1 6 0,"eins Uhr sechs")
  , (TimeOfDay 1 7 0,"eins Uhr sieben")
  , (TimeOfDay 1 8 0,"eins Uhr acht")
  , (TimeOfDay 1 9 0,"eins Uhr neun")
  , (TimeOfDay 1 10 0,"eins Uhr zehn")
  , (TimeOfDay 1 11 0,"eins Uhr elf")
  , (TimeOfDay 1 12 0,"eins Uhr zw\246lf")
  , (TimeOfDay 1 13 0,"eins Uhr dreizehn")
  , (TimeOfDay 1 14 0,"eins Uhr vierzehn")
  , (TimeOfDay 1 15 0,"eins Uhr f\252nfzehn")
  , (TimeOfDay 1 16 0,"eins Uhr sechzehn")
  , (TimeOfDay 1 17 0,"eins Uhr siebzehn")
  , (TimeOfDay 1 18 0,"eins Uhr achtzehn")
  , (TimeOfDay 1 19 0,"eins Uhr neunzehn")
  , (TimeOfDay 1 20 0,"eins Uhr zwanzig")
  , (TimeOfDay 1 21 0,"eins Uhr einundzwanzig")
  , (TimeOfDay 1 22 0,"eins Uhr zweiundzwanzig")
  , (TimeOfDay 1 23 0,"eins Uhr dreiundzwanzig")
  , (TimeOfDay 1 24 0,"eins Uhr vierundzwanzig")
  , (TimeOfDay 1 25 0,"eins Uhr f\252nfundzwanzig")
  , (TimeOfDay 1 26 0,"eins Uhr sechsundzwanzig")
  , (TimeOfDay 1 27 0,"eins Uhr siebenundzwanzig")
  , (TimeOfDay 1 28 0,"eins Uhr achtundzwanzig")
  , (TimeOfDay 1 29 0,"eins Uhr neunundzwanzig")
  , (TimeOfDay 1 30 0,"eins Uhr drei\223ig")
  , (TimeOfDay 1 31 0,"eins Uhr einunddrei\223ig")
  , (TimeOfDay 1 32 0,"eins Uhr zweiunddrei\223ig")
  , (TimeOfDay 1 33 0,"eins Uhr dreiunddrei\223ig")
  , (TimeOfDay 1 34 0,"eins Uhr vierunddrei\223ig")
  , (TimeOfDay 1 35 0,"eins Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 1 36 0,"eins Uhr sechsunddrei\223ig")
  , (TimeOfDay 1 37 0,"eins Uhr siebenunddrei\223ig")
  , (TimeOfDay 1 38 0,"eins Uhr achtunddrei\223ig")
  , (TimeOfDay 1 39 0,"eins Uhr neununddrei\223ig")
  , (TimeOfDay 1 40 0,"eins Uhr vierzig")
  , (TimeOfDay 1 41 0,"eins Uhr einundvierzig")
  , (TimeOfDay 1 42 0,"eins Uhr zweiundvierzig")
  , (TimeOfDay 1 43 0,"eins Uhr dreiundvierzig")
  , (TimeOfDay 1 44 0,"eins Uhr vierundvierzig")
  , (TimeOfDay 1 45 0,"eins Uhr f\252nfundvierzig")
  , (TimeOfDay 1 46 0,"eins Uhr sechsundvierzig")
  , (TimeOfDay 1 47 0,"eins Uhr siebenundvierzig")
  , (TimeOfDay 1 48 0,"eins Uhr achtundvierzig")
  , (TimeOfDay 1 49 0,"eins Uhr neunundvierzig")
  , (TimeOfDay 1 50 0,"eins Uhr f\252nfzig")
  , (TimeOfDay 1 51 0,"eins Uhr einundf\252nfzig")
  , (TimeOfDay 1 52 0,"eins Uhr zweiundf\252nfzig")
  , (TimeOfDay 1 53 0,"eins Uhr dreiundf\252nfzig")
  , (TimeOfDay 1 54 0,"eins Uhr vierundf\252nfzig")
  , (TimeOfDay 1 55 0,"eins Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 1 56 0,"eins Uhr sechsundf\252nfzig")
  , (TimeOfDay 1 57 0,"eins Uhr siebenundf\252nfzig")
  , (TimeOfDay 1 58 0,"eins Uhr achtundf\252nfzig")
  , (TimeOfDay 1 59 0,"eins Uhr neunundf\252nfzig")
  , (TimeOfDay 2 0 0,"zwei Uhr")
  , (TimeOfDay 2 1 0,"zwei Uhr eins")
  , (TimeOfDay 2 2 0,"zwei Uhr zwei")
  , (TimeOfDay 2 3 0,"zwei Uhr drei")
  , (TimeOfDay 2 4 0,"zwei Uhr vier")
  , (TimeOfDay 2 5 0,"zwei Uhr f\252nf")
  , (TimeOfDay 2 6 0,"zwei Uhr sechs")
  , (TimeOfDay 2 7 0,"zwei Uhr sieben")
  , (TimeOfDay 2 8 0,"zwei Uhr acht")
  , (TimeOfDay 2 9 0,"zwei Uhr neun")
  , (TimeOfDay 2 10 0,"zwei Uhr zehn")
  , (TimeOfDay 2 11 0,"zwei Uhr elf")
  , (TimeOfDay 2 12 0,"zwei Uhr zw\246lf")
  , (TimeOfDay 2 13 0,"zwei Uhr dreizehn")
  , (TimeOfDay 2 14 0,"zwei Uhr vierzehn")
  , (TimeOfDay 2 15 0,"zwei Uhr f\252nfzehn")
  , (TimeOfDay 2 16 0,"zwei Uhr sechzehn")
  , (TimeOfDay 2 17 0,"zwei Uhr siebzehn")
  , (TimeOfDay 2 18 0,"zwei Uhr achtzehn")
  , (TimeOfDay 2 19 0,"zwei Uhr neunzehn")
  , (TimeOfDay 2 20 0,"zwei Uhr zwanzig")
  , (TimeOfDay 2 21 0,"zwei Uhr einundzwanzig")
  , (TimeOfDay 2 22 0,"zwei Uhr zweiundzwanzig")
  , (TimeOfDay 2 23 0,"zwei Uhr dreiundzwanzig")
  , (TimeOfDay 2 24 0,"zwei Uhr vierundzwanzig")
  , (TimeOfDay 2 25 0,"zwei Uhr f\252nfundzwanzig")
  , (TimeOfDay 2 26 0,"zwei Uhr sechsundzwanzig")
  , (TimeOfDay 2 27 0,"zwei Uhr siebenundzwanzig")
  , (TimeOfDay 2 28 0,"zwei Uhr achtundzwanzig")
  , (TimeOfDay 2 29 0,"zwei Uhr neunundzwanzig")
  , (TimeOfDay 2 30 0,"zwei Uhr drei\223ig")
  , (TimeOfDay 2 31 0,"zwei Uhr einunddrei\223ig")
  , (TimeOfDay 2 32 0,"zwei Uhr zweiunddrei\223ig")
  , (TimeOfDay 2 33 0,"zwei Uhr dreiunddrei\223ig")
  , (TimeOfDay 2 34 0,"zwei Uhr vierunddrei\223ig")
  , (TimeOfDay 2 35 0,"zwei Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 2 36 0,"zwei Uhr sechsunddrei\223ig")
  , (TimeOfDay 2 37 0,"zwei Uhr siebenunddrei\223ig")
  , (TimeOfDay 2 38 0,"zwei Uhr achtunddrei\223ig")
  , (TimeOfDay 2 39 0,"zwei Uhr neununddrei\223ig")
  , (TimeOfDay 2 40 0,"zwei Uhr vierzig")
  , (TimeOfDay 2 41 0,"zwei Uhr einundvierzig")
  , (TimeOfDay 2 42 0,"zwei Uhr zweiundvierzig")
  , (TimeOfDay 2 43 0,"zwei Uhr dreiundvierzig")
  , (TimeOfDay 2 44 0,"zwei Uhr vierundvierzig")
  , (TimeOfDay 2 45 0,"zwei Uhr f\252nfundvierzig")
  , (TimeOfDay 2 46 0,"zwei Uhr sechsundvierzig")
  , (TimeOfDay 2 47 0,"zwei Uhr siebenundvierzig")
  , (TimeOfDay 2 48 0,"zwei Uhr achtundvierzig")
  , (TimeOfDay 2 49 0,"zwei Uhr neunundvierzig")
  , (TimeOfDay 2 50 0,"zwei Uhr f\252nfzig")
  , (TimeOfDay 2 51 0,"zwei Uhr einundf\252nfzig")
  , (TimeOfDay 2 52 0,"zwei Uhr zweiundf\252nfzig")
  , (TimeOfDay 2 53 0,"zwei Uhr dreiundf\252nfzig")
  , (TimeOfDay 2 54 0,"zwei Uhr vierundf\252nfzig")
  , (TimeOfDay 2 55 0,"zwei Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 2 56 0,"zwei Uhr sechsundf\252nfzig")
  , (TimeOfDay 2 57 0,"zwei Uhr siebenundf\252nfzig")
  , (TimeOfDay 2 58 0,"zwei Uhr achtundf\252nfzig")
  , (TimeOfDay 2 59 0,"zwei Uhr neunundf\252nfzig")
  , (TimeOfDay 3 0 0,"drei Uhr")
  , (TimeOfDay 3 1 0,"drei Uhr eins")
  , (TimeOfDay 3 2 0,"drei Uhr zwei")
  , (TimeOfDay 3 3 0,"drei Uhr drei")
  , (TimeOfDay 3 4 0,"drei Uhr vier")
  , (TimeOfDay 3 5 0,"drei Uhr f\252nf")
  , (TimeOfDay 3 6 0,"drei Uhr sechs")
  , (TimeOfDay 3 7 0,"drei Uhr sieben")
  , (TimeOfDay 3 8 0,"drei Uhr acht")
  , (TimeOfDay 3 9 0,"drei Uhr neun")
  , (TimeOfDay 3 10 0,"drei Uhr zehn")
  , (TimeOfDay 3 11 0,"drei Uhr elf")
  , (TimeOfDay 3 12 0,"drei Uhr zw\246lf")
  , (TimeOfDay 3 13 0,"drei Uhr dreizehn")
  , (TimeOfDay 3 14 0,"drei Uhr vierzehn")
  , (TimeOfDay 3 15 0,"drei Uhr f\252nfzehn")
  , (TimeOfDay 3 16 0,"drei Uhr sechzehn")
  , (TimeOfDay 3 17 0,"drei Uhr siebzehn")
  , (TimeOfDay 3 18 0,"drei Uhr achtzehn")
  , (TimeOfDay 3 19 0,"drei Uhr neunzehn")
  , (TimeOfDay 3 20 0,"drei Uhr zwanzig")
  , (TimeOfDay 3 21 0,"drei Uhr einundzwanzig")
  , (TimeOfDay 3 22 0,"drei Uhr zweiundzwanzig")
  , (TimeOfDay 3 23 0,"drei Uhr dreiundzwanzig")
  , (TimeOfDay 3 24 0,"drei Uhr vierundzwanzig")
  , (TimeOfDay 3 25 0,"drei Uhr f\252nfundzwanzig")
  , (TimeOfDay 3 26 0,"drei Uhr sechsundzwanzig")
  , (TimeOfDay 3 27 0,"drei Uhr siebenundzwanzig")
  , (TimeOfDay 3 28 0,"drei Uhr achtundzwanzig")
  , (TimeOfDay 3 29 0,"drei Uhr neunundzwanzig")
  , (TimeOfDay 3 30 0,"drei Uhr drei\223ig")
  , (TimeOfDay 3 31 0,"drei Uhr einunddrei\223ig")
  , (TimeOfDay 3 32 0,"drei Uhr zweiunddrei\223ig")
  , (TimeOfDay 3 33 0,"drei Uhr dreiunddrei\223ig")
  , (TimeOfDay 3 34 0,"drei Uhr vierunddrei\223ig")
  , (TimeOfDay 3 35 0,"drei Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 3 36 0,"drei Uhr sechsunddrei\223ig")
  , (TimeOfDay 3 37 0,"drei Uhr siebenunddrei\223ig")
  , (TimeOfDay 3 38 0,"drei Uhr achtunddrei\223ig")
  , (TimeOfDay 3 39 0,"drei Uhr neununddrei\223ig")
  , (TimeOfDay 3 40 0,"drei Uhr vierzig")
  , (TimeOfDay 3 41 0,"drei Uhr einundvierzig")
  , (TimeOfDay 3 42 0,"drei Uhr zweiundvierzig")
  , (TimeOfDay 3 43 0,"drei Uhr dreiundvierzig")
  , (TimeOfDay 3 44 0,"drei Uhr vierundvierzig")
  , (TimeOfDay 3 45 0,"drei Uhr f\252nfundvierzig")
  , (TimeOfDay 3 46 0,"drei Uhr sechsundvierzig")
  , (TimeOfDay 3 47 0,"drei Uhr siebenundvierzig")
  , (TimeOfDay 3 48 0,"drei Uhr achtundvierzig")
  , (TimeOfDay 3 49 0,"drei Uhr neunundvierzig")
  , (TimeOfDay 3 50 0,"drei Uhr f\252nfzig")
  , (TimeOfDay 3 51 0,"drei Uhr einundf\252nfzig")
  , (TimeOfDay 3 52 0,"drei Uhr zweiundf\252nfzig")
  , (TimeOfDay 3 53 0,"drei Uhr dreiundf\252nfzig")
  , (TimeOfDay 3 54 0,"drei Uhr vierundf\252nfzig")
  , (TimeOfDay 3 55 0,"drei Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 3 56 0,"drei Uhr sechsundf\252nfzig")
  , (TimeOfDay 3 57 0,"drei Uhr siebenundf\252nfzig")
  , (TimeOfDay 3 58 0,"drei Uhr achtundf\252nfzig")
  , (TimeOfDay 3 59 0,"drei Uhr neunundf\252nfzig")
  , (TimeOfDay 4 0 0,"vier Uhr")
  , (TimeOfDay 4 1 0,"vier Uhr eins")
  , (TimeOfDay 4 2 0,"vier Uhr zwei")
  , (TimeOfDay 4 3 0,"vier Uhr drei")
  , (TimeOfDay 4 4 0,"vier Uhr vier")
  , (TimeOfDay 4 5 0,"vier Uhr f\252nf")
  , (TimeOfDay 4 6 0,"vier Uhr sechs")
  , (TimeOfDay 4 7 0,"vier Uhr sieben")
  , (TimeOfDay 4 8 0,"vier Uhr acht")
  , (TimeOfDay 4 9 0,"vier Uhr neun")
  , (TimeOfDay 4 10 0,"vier Uhr zehn")
  , (TimeOfDay 4 11 0,"vier Uhr elf")
  , (TimeOfDay 4 12 0,"vier Uhr zw\246lf")
  , (TimeOfDay 4 13 0,"vier Uhr dreizehn")
  , (TimeOfDay 4 14 0,"vier Uhr vierzehn")
  , (TimeOfDay 4 15 0,"vier Uhr f\252nfzehn")
  , (TimeOfDay 4 16 0,"vier Uhr sechzehn")
  , (TimeOfDay 4 17 0,"vier Uhr siebzehn")
  , (TimeOfDay 4 18 0,"vier Uhr achtzehn")
  , (TimeOfDay 4 19 0,"vier Uhr neunzehn")
  , (TimeOfDay 4 20 0,"vier Uhr zwanzig")
  , (TimeOfDay 4 21 0,"vier Uhr einundzwanzig")
  , (TimeOfDay 4 22 0,"vier Uhr zweiundzwanzig")
  , (TimeOfDay 4 23 0,"vier Uhr dreiundzwanzig")
  , (TimeOfDay 4 24 0,"vier Uhr vierundzwanzig")
  , (TimeOfDay 4 25 0,"vier Uhr f\252nfundzwanzig")
  , (TimeOfDay 4 26 0,"vier Uhr sechsundzwanzig")
  , (TimeOfDay 4 27 0,"vier Uhr siebenundzwanzig")
  , (TimeOfDay 4 28 0,"vier Uhr achtundzwanzig")
  , (TimeOfDay 4 29 0,"vier Uhr neunundzwanzig")
  , (TimeOfDay 4 30 0,"vier Uhr drei\223ig")
  , (TimeOfDay 4 31 0,"vier Uhr einunddrei\223ig")
  , (TimeOfDay 4 32 0,"vier Uhr zweiunddrei\223ig")
  , (TimeOfDay 4 33 0,"vier Uhr dreiunddrei\223ig")
  , (TimeOfDay 4 34 0,"vier Uhr vierunddrei\223ig")
  , (TimeOfDay 4 35 0,"vier Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 4 36 0,"vier Uhr sechsunddrei\223ig")
  , (TimeOfDay 4 37 0,"vier Uhr siebenunddrei\223ig")
  , (TimeOfDay 4 38 0,"vier Uhr achtunddrei\223ig")
  , (TimeOfDay 4 39 0,"vier Uhr neununddrei\223ig")
  , (TimeOfDay 4 40 0,"vier Uhr vierzig")
  , (TimeOfDay 4 41 0,"vier Uhr einundvierzig")
  , (TimeOfDay 4 42 0,"vier Uhr zweiundvierzig")
  , (TimeOfDay 4 43 0,"vier Uhr dreiundvierzig")
  , (TimeOfDay 4 44 0,"vier Uhr vierundvierzig")
  , (TimeOfDay 4 45 0,"vier Uhr f\252nfundvierzig")
  , (TimeOfDay 4 46 0,"vier Uhr sechsundvierzig")
  , (TimeOfDay 4 47 0,"vier Uhr siebenundvierzig")
  , (TimeOfDay 4 48 0,"vier Uhr achtundvierzig")
  , (TimeOfDay 4 49 0,"vier Uhr neunundvierzig")
  , (TimeOfDay 4 50 0,"vier Uhr f\252nfzig")
  , (TimeOfDay 4 51 0,"vier Uhr einundf\252nfzig")
  , (TimeOfDay 4 52 0,"vier Uhr zweiundf\252nfzig")
  , (TimeOfDay 4 53 0,"vier Uhr dreiundf\252nfzig")
  , (TimeOfDay 4 54 0,"vier Uhr vierundf\252nfzig")
  , (TimeOfDay 4 55 0,"vier Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 4 56 0,"vier Uhr sechsundf\252nfzig")
  , (TimeOfDay 4 57 0,"vier Uhr siebenundf\252nfzig")
  , (TimeOfDay 4 58 0,"vier Uhr achtundf\252nfzig")
  , (TimeOfDay 4 59 0,"vier Uhr neunundf\252nfzig")
  , (TimeOfDay 5 0 0,"f\252nf Uhr")
  , (TimeOfDay 5 1 0,"f\252nf Uhr eins")
  , (TimeOfDay 5 2 0,"f\252nf Uhr zwei")
  , (TimeOfDay 5 3 0,"f\252nf Uhr drei")
  , (TimeOfDay 5 4 0,"f\252nf Uhr vier")
  , (TimeOfDay 5 5 0,"f\252nf Uhr f\252nf")
  , (TimeOfDay 5 6 0,"f\252nf Uhr sechs")
  , (TimeOfDay 5 7 0,"f\252nf Uhr sieben")
  , (TimeOfDay 5 8 0,"f\252nf Uhr acht")
  , (TimeOfDay 5 9 0,"f\252nf Uhr neun")
  , (TimeOfDay 5 10 0,"f\252nf Uhr zehn")
  , (TimeOfDay 5 11 0,"f\252nf Uhr elf")
  , (TimeOfDay 5 12 0,"f\252nf Uhr zw\246lf")
  , (TimeOfDay 5 13 0,"f\252nf Uhr dreizehn")
  , (TimeOfDay 5 14 0,"f\252nf Uhr vierzehn")
  , (TimeOfDay 5 15 0,"f\252nf Uhr f\252nfzehn")
  , (TimeOfDay 5 16 0,"f\252nf Uhr sechzehn")
  , (TimeOfDay 5 17 0,"f\252nf Uhr siebzehn")
  , (TimeOfDay 5 18 0,"f\252nf Uhr achtzehn")
  , (TimeOfDay 5 19 0,"f\252nf Uhr neunzehn")
  , (TimeOfDay 5 20 0,"f\252nf Uhr zwanzig")
  , (TimeOfDay 5 21 0,"f\252nf Uhr einundzwanzig")
  , (TimeOfDay 5 22 0,"f\252nf Uhr zweiundzwanzig")
  , (TimeOfDay 5 23 0,"f\252nf Uhr dreiundzwanzig")
  , (TimeOfDay 5 24 0,"f\252nf Uhr vierundzwanzig")
  , (TimeOfDay 5 25 0,"f\252nf Uhr f\252nfundzwanzig")
  , (TimeOfDay 5 26 0,"f\252nf Uhr sechsundzwanzig")
  , (TimeOfDay 5 27 0,"f\252nf Uhr siebenundzwanzig")
  , (TimeOfDay 5 28 0,"f\252nf Uhr achtundzwanzig")
  , (TimeOfDay 5 29 0,"f\252nf Uhr neunundzwanzig")
  , (TimeOfDay 5 30 0,"f\252nf Uhr drei\223ig")
  , (TimeOfDay 5 31 0,"f\252nf Uhr einunddrei\223ig")
  , (TimeOfDay 5 32 0,"f\252nf Uhr zweiunddrei\223ig")
  , (TimeOfDay 5 33 0,"f\252nf Uhr dreiunddrei\223ig")
  , (TimeOfDay 5 34 0,"f\252nf Uhr vierunddrei\223ig")
  , (TimeOfDay 5 35 0,"f\252nf Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 5 36 0,"f\252nf Uhr sechsunddrei\223ig")
  , (TimeOfDay 5 37 0,"f\252nf Uhr siebenunddrei\223ig")
  , (TimeOfDay 5 38 0,"f\252nf Uhr achtunddrei\223ig")
  , (TimeOfDay 5 39 0,"f\252nf Uhr neununddrei\223ig")
  , (TimeOfDay 5 40 0,"f\252nf Uhr vierzig")
  , (TimeOfDay 5 41 0,"f\252nf Uhr einundvierzig")
  , (TimeOfDay 5 42 0,"f\252nf Uhr zweiundvierzig")
  , (TimeOfDay 5 43 0,"f\252nf Uhr dreiundvierzig")
  , (TimeOfDay 5 44 0,"f\252nf Uhr vierundvierzig")
  , (TimeOfDay 5 45 0,"f\252nf Uhr f\252nfundvierzig")
  , (TimeOfDay 5 46 0,"f\252nf Uhr sechsundvierzig")
  , (TimeOfDay 5 47 0,"f\252nf Uhr siebenundvierzig")
  , (TimeOfDay 5 48 0,"f\252nf Uhr achtundvierzig")
  , (TimeOfDay 5 49 0,"f\252nf Uhr neunundvierzig")
  , (TimeOfDay 5 50 0,"f\252nf Uhr f\252nfzig")
  , (TimeOfDay 5 51 0,"f\252nf Uhr einundf\252nfzig")
  , (TimeOfDay 5 52 0,"f\252nf Uhr zweiundf\252nfzig")
  , (TimeOfDay 5 53 0,"f\252nf Uhr dreiundf\252nfzig")
  , (TimeOfDay 5 54 0,"f\252nf Uhr vierundf\252nfzig")
  , (TimeOfDay 5 55 0,"f\252nf Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 5 56 0,"f\252nf Uhr sechsundf\252nfzig")
  , (TimeOfDay 5 57 0,"f\252nf Uhr siebenundf\252nfzig")
  , (TimeOfDay 5 58 0,"f\252nf Uhr achtundf\252nfzig")
  , (TimeOfDay 5 59 0,"f\252nf Uhr neunundf\252nfzig")
  , (TimeOfDay 6 0 0,"sechs Uhr")
  , (TimeOfDay 6 1 0,"sechs Uhr eins")
  , (TimeOfDay 6 2 0,"sechs Uhr zwei")
  , (TimeOfDay 6 3 0,"sechs Uhr drei")
  , (TimeOfDay 6 4 0,"sechs Uhr vier")
  , (TimeOfDay 6 5 0,"sechs Uhr f\252nf")
  , (TimeOfDay 6 6 0,"sechs Uhr sechs")
  , (TimeOfDay 6 7 0,"sechs Uhr sieben")
  , (TimeOfDay 6 8 0,"sechs Uhr acht")
  , (TimeOfDay 6 9 0,"sechs Uhr neun")
  , (TimeOfDay 6 10 0,"sechs Uhr zehn")
  , (TimeOfDay 6 11 0,"sechs Uhr elf")
  , (TimeOfDay 6 12 0,"sechs Uhr zw\246lf")
  , (TimeOfDay 6 13 0,"sechs Uhr dreizehn")
  , (TimeOfDay 6 14 0,"sechs Uhr vierzehn")
  , (TimeOfDay 6 15 0,"sechs Uhr f\252nfzehn")
  , (TimeOfDay 6 16 0,"sechs Uhr sechzehn")
  , (TimeOfDay 6 17 0,"sechs Uhr siebzehn")
  , (TimeOfDay 6 18 0,"sechs Uhr achtzehn")
  , (TimeOfDay 6 19 0,"sechs Uhr neunzehn")
  , (TimeOfDay 6 20 0,"sechs Uhr zwanzig")
  , (TimeOfDay 6 21 0,"sechs Uhr einundzwanzig")
  , (TimeOfDay 6 22 0,"sechs Uhr zweiundzwanzig")
  , (TimeOfDay 6 23 0,"sechs Uhr dreiundzwanzig")
  , (TimeOfDay 6 24 0,"sechs Uhr vierundzwanzig")
  , (TimeOfDay 6 25 0,"sechs Uhr f\252nfundzwanzig")
  , (TimeOfDay 6 26 0,"sechs Uhr sechsundzwanzig")
  , (TimeOfDay 6 27 0,"sechs Uhr siebenundzwanzig")
  , (TimeOfDay 6 28 0,"sechs Uhr achtundzwanzig")
  , (TimeOfDay 6 29 0,"sechs Uhr neunundzwanzig")
  , (TimeOfDay 6 30 0,"sechs Uhr drei\223ig")
  , (TimeOfDay 6 31 0,"sechs Uhr einunddrei\223ig")
  , (TimeOfDay 6 32 0,"sechs Uhr zweiunddrei\223ig")
  , (TimeOfDay 6 33 0,"sechs Uhr dreiunddrei\223ig")
  , (TimeOfDay 6 34 0,"sechs Uhr vierunddrei\223ig")
  , (TimeOfDay 6 35 0,"sechs Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 6 36 0,"sechs Uhr sechsunddrei\223ig")
  , (TimeOfDay 6 37 0,"sechs Uhr siebenunddrei\223ig")
  , (TimeOfDay 6 38 0,"sechs Uhr achtunddrei\223ig")
  , (TimeOfDay 6 39 0,"sechs Uhr neununddrei\223ig")
  , (TimeOfDay 6 40 0,"sechs Uhr vierzig")
  , (TimeOfDay 6 41 0,"sechs Uhr einundvierzig")
  , (TimeOfDay 6 42 0,"sechs Uhr zweiundvierzig")
  , (TimeOfDay 6 43 0,"sechs Uhr dreiundvierzig")
  , (TimeOfDay 6 44 0,"sechs Uhr vierundvierzig")
  , (TimeOfDay 6 45 0,"sechs Uhr f\252nfundvierzig")
  , (TimeOfDay 6 46 0,"sechs Uhr sechsundvierzig")
  , (TimeOfDay 6 47 0,"sechs Uhr siebenundvierzig")
  , (TimeOfDay 6 48 0,"sechs Uhr achtundvierzig")
  , (TimeOfDay 6 49 0,"sechs Uhr neunundvierzig")
  , (TimeOfDay 6 50 0,"sechs Uhr f\252nfzig")
  , (TimeOfDay 6 51 0,"sechs Uhr einundf\252nfzig")
  , (TimeOfDay 6 52 0,"sechs Uhr zweiundf\252nfzig")
  , (TimeOfDay 6 53 0,"sechs Uhr dreiundf\252nfzig")
  , (TimeOfDay 6 54 0,"sechs Uhr vierundf\252nfzig")
  , (TimeOfDay 6 55 0,"sechs Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 6 56 0,"sechs Uhr sechsundf\252nfzig")
  , (TimeOfDay 6 57 0,"sechs Uhr siebenundf\252nfzig")
  , (TimeOfDay 6 58 0,"sechs Uhr achtundf\252nfzig")
  , (TimeOfDay 6 59 0,"sechs Uhr neunundf\252nfzig")
  , (TimeOfDay 7 0 0,"sieben Uhr")
  , (TimeOfDay 7 1 0,"sieben Uhr eins")
  , (TimeOfDay 7 2 0,"sieben Uhr zwei")
  , (TimeOfDay 7 3 0,"sieben Uhr drei")
  , (TimeOfDay 7 4 0,"sieben Uhr vier")
  , (TimeOfDay 7 5 0,"sieben Uhr f\252nf")
  , (TimeOfDay 7 6 0,"sieben Uhr sechs")
  , (TimeOfDay 7 7 0,"sieben Uhr sieben")
  , (TimeOfDay 7 8 0,"sieben Uhr acht")
  , (TimeOfDay 7 9 0,"sieben Uhr neun")
  , (TimeOfDay 7 10 0,"sieben Uhr zehn")
  , (TimeOfDay 7 11 0,"sieben Uhr elf")
  , (TimeOfDay 7 12 0,"sieben Uhr zw\246lf")
  , (TimeOfDay 7 13 0,"sieben Uhr dreizehn")
  , (TimeOfDay 7 14 0,"sieben Uhr vierzehn")
  , (TimeOfDay 7 15 0,"sieben Uhr f\252nfzehn")
  , (TimeOfDay 7 16 0,"sieben Uhr sechzehn")
  , (TimeOfDay 7 17 0,"sieben Uhr siebzehn")
  , (TimeOfDay 7 18 0,"sieben Uhr achtzehn")
  , (TimeOfDay 7 19 0,"sieben Uhr neunzehn")
  , (TimeOfDay 7 20 0,"sieben Uhr zwanzig")
  , (TimeOfDay 7 21 0,"sieben Uhr einundzwanzig")
  , (TimeOfDay 7 22 0,"sieben Uhr zweiundzwanzig")
  , (TimeOfDay 7 23 0,"sieben Uhr dreiundzwanzig")
  , (TimeOfDay 7 24 0,"sieben Uhr vierundzwanzig")
  , (TimeOfDay 7 25 0,"sieben Uhr f\252nfundzwanzig")
  , (TimeOfDay 7 26 0,"sieben Uhr sechsundzwanzig")
  , (TimeOfDay 7 27 0,"sieben Uhr siebenundzwanzig")
  , (TimeOfDay 7 28 0,"sieben Uhr achtundzwanzig")
  , (TimeOfDay 7 29 0,"sieben Uhr neunundzwanzig")
  , (TimeOfDay 7 30 0,"sieben Uhr drei\223ig")
  , (TimeOfDay 7 31 0,"sieben Uhr einunddrei\223ig")
  , (TimeOfDay 7 32 0,"sieben Uhr zweiunddrei\223ig")
  , (TimeOfDay 7 33 0,"sieben Uhr dreiunddrei\223ig")
  , (TimeOfDay 7 34 0,"sieben Uhr vierunddrei\223ig")
  , (TimeOfDay 7 35 0,"sieben Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 7 36 0,"sieben Uhr sechsunddrei\223ig")
  , (TimeOfDay 7 37 0,"sieben Uhr siebenunddrei\223ig")
  , (TimeOfDay 7 38 0,"sieben Uhr achtunddrei\223ig")
  , (TimeOfDay 7 39 0,"sieben Uhr neununddrei\223ig")
  , (TimeOfDay 7 40 0,"sieben Uhr vierzig")
  , (TimeOfDay 7 41 0,"sieben Uhr einundvierzig")
  , (TimeOfDay 7 42 0,"sieben Uhr zweiundvierzig")
  , (TimeOfDay 7 43 0,"sieben Uhr dreiundvierzig")
  , (TimeOfDay 7 44 0,"sieben Uhr vierundvierzig")
  , (TimeOfDay 7 45 0,"sieben Uhr f\252nfundvierzig")
  , (TimeOfDay 7 46 0,"sieben Uhr sechsundvierzig")
  , (TimeOfDay 7 47 0,"sieben Uhr siebenundvierzig")
  , (TimeOfDay 7 48 0,"sieben Uhr achtundvierzig")
  , (TimeOfDay 7 49 0,"sieben Uhr neunundvierzig")
  , (TimeOfDay 7 50 0,"sieben Uhr f\252nfzig")
  , (TimeOfDay 7 51 0,"sieben Uhr einundf\252nfzig")
  , (TimeOfDay 7 52 0,"sieben Uhr zweiundf\252nfzig")
  , (TimeOfDay 7 53 0,"sieben Uhr dreiundf\252nfzig")
  , (TimeOfDay 7 54 0,"sieben Uhr vierundf\252nfzig")
  , (TimeOfDay 7 55 0,"sieben Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 7 56 0,"sieben Uhr sechsundf\252nfzig")
  , (TimeOfDay 7 57 0,"sieben Uhr siebenundf\252nfzig")
  , (TimeOfDay 7 58 0,"sieben Uhr achtundf\252nfzig")
  , (TimeOfDay 7 59 0,"sieben Uhr neunundf\252nfzig")
  , (TimeOfDay 8 0 0,"acht Uhr")
  , (TimeOfDay 8 1 0,"acht Uhr eins")
  , (TimeOfDay 8 2 0,"acht Uhr zwei")
  , (TimeOfDay 8 3 0,"acht Uhr drei")
  , (TimeOfDay 8 4 0,"acht Uhr vier")
  , (TimeOfDay 8 5 0,"acht Uhr f\252nf")
  , (TimeOfDay 8 6 0,"acht Uhr sechs")
  , (TimeOfDay 8 7 0,"acht Uhr sieben")
  , (TimeOfDay 8 8 0,"acht Uhr acht")
  , (TimeOfDay 8 9 0,"acht Uhr neun")
  , (TimeOfDay 8 10 0,"acht Uhr zehn")
  , (TimeOfDay 8 11 0,"acht Uhr elf")
  , (TimeOfDay 8 12 0,"acht Uhr zw\246lf")
  , (TimeOfDay 8 13 0,"acht Uhr dreizehn")
  , (TimeOfDay 8 14 0,"acht Uhr vierzehn")
  , (TimeOfDay 8 15 0,"acht Uhr f\252nfzehn")
  , (TimeOfDay 8 16 0,"acht Uhr sechzehn")
  , (TimeOfDay 8 17 0,"acht Uhr siebzehn")
  , (TimeOfDay 8 18 0,"acht Uhr achtzehn")
  , (TimeOfDay 8 19 0,"acht Uhr neunzehn")
  , (TimeOfDay 8 20 0,"acht Uhr zwanzig")
  , (TimeOfDay 8 21 0,"acht Uhr einundzwanzig")
  , (TimeOfDay 8 22 0,"acht Uhr zweiundzwanzig")
  , (TimeOfDay 8 23 0,"acht Uhr dreiundzwanzig")
  , (TimeOfDay 8 24 0,"acht Uhr vierundzwanzig")
  , (TimeOfDay 8 25 0,"acht Uhr f\252nfundzwanzig")
  , (TimeOfDay 8 26 0,"acht Uhr sechsundzwanzig")
  , (TimeOfDay 8 27 0,"acht Uhr siebenundzwanzig")
  , (TimeOfDay 8 28 0,"acht Uhr achtundzwanzig")
  , (TimeOfDay 8 29 0,"acht Uhr neunundzwanzig")
  , (TimeOfDay 8 30 0,"acht Uhr drei\223ig")
  , (TimeOfDay 8 31 0,"acht Uhr einunddrei\223ig")
  , (TimeOfDay 8 32 0,"acht Uhr zweiunddrei\223ig")
  , (TimeOfDay 8 33 0,"acht Uhr dreiunddrei\223ig")
  , (TimeOfDay 8 34 0,"acht Uhr vierunddrei\223ig")
  , (TimeOfDay 8 35 0,"acht Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 8 36 0,"acht Uhr sechsunddrei\223ig")
  , (TimeOfDay 8 37 0,"acht Uhr siebenunddrei\223ig")
  , (TimeOfDay 8 38 0,"acht Uhr achtunddrei\223ig")
  , (TimeOfDay 8 39 0,"acht Uhr neununddrei\223ig")
  , (TimeOfDay 8 40 0,"acht Uhr vierzig")
  , (TimeOfDay 8 41 0,"acht Uhr einundvierzig")
  , (TimeOfDay 8 42 0,"acht Uhr zweiundvierzig")
  , (TimeOfDay 8 43 0,"acht Uhr dreiundvierzig")
  , (TimeOfDay 8 44 0,"acht Uhr vierundvierzig")
  , (TimeOfDay 8 45 0,"acht Uhr f\252nfundvierzig")
  , (TimeOfDay 8 46 0,"acht Uhr sechsundvierzig")
  , (TimeOfDay 8 47 0,"acht Uhr siebenundvierzig")
  , (TimeOfDay 8 48 0,"acht Uhr achtundvierzig")
  , (TimeOfDay 8 49 0,"acht Uhr neunundvierzig")
  , (TimeOfDay 8 50 0,"acht Uhr f\252nfzig")
  , (TimeOfDay 8 51 0,"acht Uhr einundf\252nfzig")
  , (TimeOfDay 8 52 0,"acht Uhr zweiundf\252nfzig")
  , (TimeOfDay 8 53 0,"acht Uhr dreiundf\252nfzig")
  , (TimeOfDay 8 54 0,"acht Uhr vierundf\252nfzig")
  , (TimeOfDay 8 55 0,"acht Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 8 56 0,"acht Uhr sechsundf\252nfzig")
  , (TimeOfDay 8 57 0,"acht Uhr siebenundf\252nfzig")
  , (TimeOfDay 8 58 0,"acht Uhr achtundf\252nfzig")
  , (TimeOfDay 8 59 0,"acht Uhr neunundf\252nfzig")
  , (TimeOfDay 9 0 0,"neun Uhr")
  , (TimeOfDay 9 1 0,"neun Uhr eins")
  , (TimeOfDay 9 2 0,"neun Uhr zwei")
  , (TimeOfDay 9 3 0,"neun Uhr drei")
  , (TimeOfDay 9 4 0,"neun Uhr vier")
  , (TimeOfDay 9 5 0,"neun Uhr f\252nf")
  , (TimeOfDay 9 6 0,"neun Uhr sechs")
  , (TimeOfDay 9 7 0,"neun Uhr sieben")
  , (TimeOfDay 9 8 0,"neun Uhr acht")
  , (TimeOfDay 9 9 0,"neun Uhr neun")
  , (TimeOfDay 9 10 0,"neun Uhr zehn")
  , (TimeOfDay 9 11 0,"neun Uhr elf")
  , (TimeOfDay 9 12 0,"neun Uhr zw\246lf")
  , (TimeOfDay 9 13 0,"neun Uhr dreizehn")
  , (TimeOfDay 9 14 0,"neun Uhr vierzehn")
  , (TimeOfDay 9 15 0,"neun Uhr f\252nfzehn")
  , (TimeOfDay 9 16 0,"neun Uhr sechzehn")
  , (TimeOfDay 9 17 0,"neun Uhr siebzehn")
  , (TimeOfDay 9 18 0,"neun Uhr achtzehn")
  , (TimeOfDay 9 19 0,"neun Uhr neunzehn")
  , (TimeOfDay 9 20 0,"neun Uhr zwanzig")
  , (TimeOfDay 9 21 0,"neun Uhr einundzwanzig")
  , (TimeOfDay 9 22 0,"neun Uhr zweiundzwanzig")
  , (TimeOfDay 9 23 0,"neun Uhr dreiundzwanzig")
  , (TimeOfDay 9 24 0,"neun Uhr vierundzwanzig")
  , (TimeOfDay 9 25 0,"neun Uhr f\252nfundzwanzig")
  , (TimeOfDay 9 26 0,"neun Uhr sechsundzwanzig")
  , (TimeOfDay 9 27 0,"neun Uhr siebenundzwanzig")
  , (TimeOfDay 9 28 0,"neun Uhr achtundzwanzig")
  , (TimeOfDay 9 29 0,"neun Uhr neunundzwanzig")
  , (TimeOfDay 9 30 0,"neun Uhr drei\223ig")
  , (TimeOfDay 9 31 0,"neun Uhr einunddrei\223ig")
  , (TimeOfDay 9 32 0,"neun Uhr zweiunddrei\223ig")
  , (TimeOfDay 9 33 0,"neun Uhr dreiunddrei\223ig")
  , (TimeOfDay 9 34 0,"neun Uhr vierunddrei\223ig")
  , (TimeOfDay 9 35 0,"neun Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 9 36 0,"neun Uhr sechsunddrei\223ig")
  , (TimeOfDay 9 37 0,"neun Uhr siebenunddrei\223ig")
  , (TimeOfDay 9 38 0,"neun Uhr achtunddrei\223ig")
  , (TimeOfDay 9 39 0,"neun Uhr neununddrei\223ig")
  , (TimeOfDay 9 40 0,"neun Uhr vierzig")
  , (TimeOfDay 9 41 0,"neun Uhr einundvierzig")
  , (TimeOfDay 9 42 0,"neun Uhr zweiundvierzig")
  , (TimeOfDay 9 43 0,"neun Uhr dreiundvierzig")
  , (TimeOfDay 9 44 0,"neun Uhr vierundvierzig")
  , (TimeOfDay 9 45 0,"neun Uhr f\252nfundvierzig")
  , (TimeOfDay 9 46 0,"neun Uhr sechsundvierzig")
  , (TimeOfDay 9 47 0,"neun Uhr siebenundvierzig")
  , (TimeOfDay 9 48 0,"neun Uhr achtundvierzig")
  , (TimeOfDay 9 49 0,"neun Uhr neunundvierzig")
  , (TimeOfDay 9 50 0,"neun Uhr f\252nfzig")
  , (TimeOfDay 9 51 0,"neun Uhr einundf\252nfzig")
  , (TimeOfDay 9 52 0,"neun Uhr zweiundf\252nfzig")
  , (TimeOfDay 9 53 0,"neun Uhr dreiundf\252nfzig")
  , (TimeOfDay 9 54 0,"neun Uhr vierundf\252nfzig")
  , (TimeOfDay 9 55 0,"neun Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 9 56 0,"neun Uhr sechsundf\252nfzig")
  , (TimeOfDay 9 57 0,"neun Uhr siebenundf\252nfzig")
  , (TimeOfDay 9 58 0,"neun Uhr achtundf\252nfzig")
  , (TimeOfDay 9 59 0,"neun Uhr neunundf\252nfzig")
  , (TimeOfDay 10 0 0,"zehn Uhr")
  , (TimeOfDay 10 1 0,"zehn Uhr eins")
  , (TimeOfDay 10 2 0,"zehn Uhr zwei")
  , (TimeOfDay 10 3 0,"zehn Uhr drei")
  , (TimeOfDay 10 4 0,"zehn Uhr vier")
  , (TimeOfDay 10 5 0,"zehn Uhr f\252nf")
  , (TimeOfDay 10 6 0,"zehn Uhr sechs")
  , (TimeOfDay 10 7 0,"zehn Uhr sieben")
  , (TimeOfDay 10 8 0,"zehn Uhr acht")
  , (TimeOfDay 10 9 0,"zehn Uhr neun")
  , (TimeOfDay 10 10 0,"zehn Uhr zehn")
  , (TimeOfDay 10 11 0,"zehn Uhr elf")
  , (TimeOfDay 10 12 0,"zehn Uhr zw\246lf")
  , (TimeOfDay 10 13 0,"zehn Uhr dreizehn")
  , (TimeOfDay 10 14 0,"zehn Uhr vierzehn")
  , (TimeOfDay 10 15 0,"zehn Uhr f\252nfzehn")
  , (TimeOfDay 10 16 0,"zehn Uhr sechzehn")
  , (TimeOfDay 10 17 0,"zehn Uhr siebzehn")
  , (TimeOfDay 10 18 0,"zehn Uhr achtzehn")
  , (TimeOfDay 10 19 0,"zehn Uhr neunzehn")
  , (TimeOfDay 10 20 0,"zehn Uhr zwanzig")
  , (TimeOfDay 10 21 0,"zehn Uhr einundzwanzig")
  , (TimeOfDay 10 22 0,"zehn Uhr zweiundzwanzig")
  , (TimeOfDay 10 23 0,"zehn Uhr dreiundzwanzig")
  , (TimeOfDay 10 24 0,"zehn Uhr vierundzwanzig")
  , (TimeOfDay 10 25 0,"zehn Uhr f\252nfundzwanzig")
  , (TimeOfDay 10 26 0,"zehn Uhr sechsundzwanzig")
  , (TimeOfDay 10 27 0,"zehn Uhr siebenundzwanzig")
  , (TimeOfDay 10 28 0,"zehn Uhr achtundzwanzig")
  , (TimeOfDay 10 29 0,"zehn Uhr neunundzwanzig")
  , (TimeOfDay 10 30 0,"zehn Uhr drei\223ig")
  , (TimeOfDay 10 31 0,"zehn Uhr einunddrei\223ig")
  , (TimeOfDay 10 32 0,"zehn Uhr zweiunddrei\223ig")
  , (TimeOfDay 10 33 0,"zehn Uhr dreiunddrei\223ig")
  , (TimeOfDay 10 34 0,"zehn Uhr vierunddrei\223ig")
  , (TimeOfDay 10 35 0,"zehn Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 10 36 0,"zehn Uhr sechsunddrei\223ig")
  , (TimeOfDay 10 37 0,"zehn Uhr siebenunddrei\223ig")
  , (TimeOfDay 10 38 0,"zehn Uhr achtunddrei\223ig")
  , (TimeOfDay 10 39 0,"zehn Uhr neununddrei\223ig")
  , (TimeOfDay 10 40 0,"zehn Uhr vierzig")
  , (TimeOfDay 10 41 0,"zehn Uhr einundvierzig")
  , (TimeOfDay 10 42 0,"zehn Uhr zweiundvierzig")
  , (TimeOfDay 10 43 0,"zehn Uhr dreiundvierzig")
  , (TimeOfDay 10 44 0,"zehn Uhr vierundvierzig")
  , (TimeOfDay 10 45 0,"zehn Uhr f\252nfundvierzig")
  , (TimeOfDay 10 46 0,"zehn Uhr sechsundvierzig")
  , (TimeOfDay 10 47 0,"zehn Uhr siebenundvierzig")
  , (TimeOfDay 10 48 0,"zehn Uhr achtundvierzig")
  , (TimeOfDay 10 49 0,"zehn Uhr neunundvierzig")
  , (TimeOfDay 10 50 0,"zehn Uhr f\252nfzig")
  , (TimeOfDay 10 51 0,"zehn Uhr einundf\252nfzig")
  , (TimeOfDay 10 52 0,"zehn Uhr zweiundf\252nfzig")
  , (TimeOfDay 10 53 0,"zehn Uhr dreiundf\252nfzig")
  , (TimeOfDay 10 54 0,"zehn Uhr vierundf\252nfzig")
  , (TimeOfDay 10 55 0,"zehn Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 10 56 0,"zehn Uhr sechsundf\252nfzig")
  , (TimeOfDay 10 57 0,"zehn Uhr siebenundf\252nfzig")
  , (TimeOfDay 10 58 0,"zehn Uhr achtundf\252nfzig")
  , (TimeOfDay 10 59 0,"zehn Uhr neunundf\252nfzig")
  , (TimeOfDay 11 0 0,"elf Uhr")
  , (TimeOfDay 11 1 0,"elf Uhr eins")
  , (TimeOfDay 11 2 0,"elf Uhr zwei")
  , (TimeOfDay 11 3 0,"elf Uhr drei")
  , (TimeOfDay 11 4 0,"elf Uhr vier")
  , (TimeOfDay 11 5 0,"elf Uhr f\252nf")
  , (TimeOfDay 11 6 0,"elf Uhr sechs")
  , (TimeOfDay 11 7 0,"elf Uhr sieben")
  , (TimeOfDay 11 8 0,"elf Uhr acht")
  , (TimeOfDay 11 9 0,"elf Uhr neun")
  , (TimeOfDay 11 10 0,"elf Uhr zehn")
  , (TimeOfDay 11 11 0,"elf Uhr elf")
  , (TimeOfDay 11 12 0,"elf Uhr zw\246lf")
  , (TimeOfDay 11 13 0,"elf Uhr dreizehn")
  , (TimeOfDay 11 14 0,"elf Uhr vierzehn")
  , (TimeOfDay 11 15 0,"elf Uhr f\252nfzehn")
  , (TimeOfDay 11 16 0,"elf Uhr sechzehn")
  , (TimeOfDay 11 17 0,"elf Uhr siebzehn")
  , (TimeOfDay 11 18 0,"elf Uhr achtzehn")
  , (TimeOfDay 11 19 0,"elf Uhr neunzehn")
  , (TimeOfDay 11 20 0,"elf Uhr zwanzig")
  , (TimeOfDay 11 21 0,"elf Uhr einundzwanzig")
  , (TimeOfDay 11 22 0,"elf Uhr zweiundzwanzig")
  , (TimeOfDay 11 23 0,"elf Uhr dreiundzwanzig")
  , (TimeOfDay 11 24 0,"elf Uhr vierundzwanzig")
  , (TimeOfDay 11 25 0,"elf Uhr f\252nfundzwanzig")
  , (TimeOfDay 11 26 0,"elf Uhr sechsundzwanzig")
  , (TimeOfDay 11 27 0,"elf Uhr siebenundzwanzig")
  , (TimeOfDay 11 28 0,"elf Uhr achtundzwanzig")
  , (TimeOfDay 11 29 0,"elf Uhr neunundzwanzig")
  , (TimeOfDay 11 30 0,"elf Uhr drei\223ig")
  , (TimeOfDay 11 31 0,"elf Uhr einunddrei\223ig")
  , (TimeOfDay 11 32 0,"elf Uhr zweiunddrei\223ig")
  , (TimeOfDay 11 33 0,"elf Uhr dreiunddrei\223ig")
  , (TimeOfDay 11 34 0,"elf Uhr vierunddrei\223ig")
  , (TimeOfDay 11 35 0,"elf Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 11 36 0,"elf Uhr sechsunddrei\223ig")
  , (TimeOfDay 11 37 0,"elf Uhr siebenunddrei\223ig")
  , (TimeOfDay 11 38 0,"elf Uhr achtunddrei\223ig")
  , (TimeOfDay 11 39 0,"elf Uhr neununddrei\223ig")
  , (TimeOfDay 11 40 0,"elf Uhr vierzig")
  , (TimeOfDay 11 41 0,"elf Uhr einundvierzig")
  , (TimeOfDay 11 42 0,"elf Uhr zweiundvierzig")
  , (TimeOfDay 11 43 0,"elf Uhr dreiundvierzig")
  , (TimeOfDay 11 44 0,"elf Uhr vierundvierzig")
  , (TimeOfDay 11 45 0,"elf Uhr f\252nfundvierzig")
  , (TimeOfDay 11 46 0,"elf Uhr sechsundvierzig")
  , (TimeOfDay 11 47 0,"elf Uhr siebenundvierzig")
  , (TimeOfDay 11 48 0,"elf Uhr achtundvierzig")
  , (TimeOfDay 11 49 0,"elf Uhr neunundvierzig")
  , (TimeOfDay 11 50 0,"elf Uhr f\252nfzig")
  , (TimeOfDay 11 51 0,"elf Uhr einundf\252nfzig")
  , (TimeOfDay 11 52 0,"elf Uhr zweiundf\252nfzig")
  , (TimeOfDay 11 53 0,"elf Uhr dreiundf\252nfzig")
  , (TimeOfDay 11 54 0,"elf Uhr vierundf\252nfzig")
  , (TimeOfDay 11 55 0,"elf Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 11 56 0,"elf Uhr sechsundf\252nfzig")
  , (TimeOfDay 11 57 0,"elf Uhr siebenundf\252nfzig")
  , (TimeOfDay 11 58 0,"elf Uhr achtundf\252nfzig")
  , (TimeOfDay 11 59 0,"elf Uhr neunundf\252nfzig")
  , (TimeOfDay 12 0 0,"zw\246lf Uhr")
  , (TimeOfDay 12 1 0,"zw\246lf Uhr eins")
  , (TimeOfDay 12 2 0,"zw\246lf Uhr zwei")
  , (TimeOfDay 12 3 0,"zw\246lf Uhr drei")
  , (TimeOfDay 12 4 0,"zw\246lf Uhr vier")
  , (TimeOfDay 12 5 0,"zw\246lf Uhr f\252nf")
  , (TimeOfDay 12 6 0,"zw\246lf Uhr sechs")
  , (TimeOfDay 12 7 0,"zw\246lf Uhr sieben")
  , (TimeOfDay 12 8 0,"zw\246lf Uhr acht")
  , (TimeOfDay 12 9 0,"zw\246lf Uhr neun")
  , (TimeOfDay 12 10 0,"zw\246lf Uhr zehn")
  , (TimeOfDay 12 11 0,"zw\246lf Uhr elf")
  , (TimeOfDay 12 12 0,"zw\246lf Uhr zw\246lf")
  , (TimeOfDay 12 13 0,"zw\246lf Uhr dreizehn")
  , (TimeOfDay 12 14 0,"zw\246lf Uhr vierzehn")
  , (TimeOfDay 12 15 0,"zw\246lf Uhr f\252nfzehn")
  , (TimeOfDay 12 16 0,"zw\246lf Uhr sechzehn")
  , (TimeOfDay 12 17 0,"zw\246lf Uhr siebzehn")
  , (TimeOfDay 12 18 0,"zw\246lf Uhr achtzehn")
  , (TimeOfDay 12 19 0,"zw\246lf Uhr neunzehn")
  , (TimeOfDay 12 20 0,"zw\246lf Uhr zwanzig")
  , (TimeOfDay 12 21 0,"zw\246lf Uhr einundzwanzig")
  , (TimeOfDay 12 22 0,"zw\246lf Uhr zweiundzwanzig")
  , (TimeOfDay 12 23 0,"zw\246lf Uhr dreiundzwanzig")
  , (TimeOfDay 12 24 0,"zw\246lf Uhr vierundzwanzig")
  , (TimeOfDay 12 25 0,"zw\246lf Uhr f\252nfundzwanzig")
  , (TimeOfDay 12 26 0,"zw\246lf Uhr sechsundzwanzig")
  , (TimeOfDay 12 27 0,"zw\246lf Uhr siebenundzwanzig")
  , (TimeOfDay 12 28 0,"zw\246lf Uhr achtundzwanzig")
  , (TimeOfDay 12 29 0,"zw\246lf Uhr neunundzwanzig")
  , (TimeOfDay 12 30 0,"zw\246lf Uhr drei\223ig")
  , (TimeOfDay 12 31 0,"zw\246lf Uhr einunddrei\223ig")
  , (TimeOfDay 12 32 0,"zw\246lf Uhr zweiunddrei\223ig")
  , (TimeOfDay 12 33 0,"zw\246lf Uhr dreiunddrei\223ig")
  , (TimeOfDay 12 34 0,"zw\246lf Uhr vierunddrei\223ig")
  , (TimeOfDay 12 35 0,"zw\246lf Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 12 36 0,"zw\246lf Uhr sechsunddrei\223ig")
  , (TimeOfDay 12 37 0,"zw\246lf Uhr siebenunddrei\223ig")
  , (TimeOfDay 12 38 0,"zw\246lf Uhr achtunddrei\223ig")
  , (TimeOfDay 12 39 0,"zw\246lf Uhr neununddrei\223ig")
  , (TimeOfDay 12 40 0,"zw\246lf Uhr vierzig")
  , (TimeOfDay 12 41 0,"zw\246lf Uhr einundvierzig")
  , (TimeOfDay 12 42 0,"zw\246lf Uhr zweiundvierzig")
  , (TimeOfDay 12 43 0,"zw\246lf Uhr dreiundvierzig")
  , (TimeOfDay 12 44 0,"zw\246lf Uhr vierundvierzig")
  , (TimeOfDay 12 45 0,"zw\246lf Uhr f\252nfundvierzig")
  , (TimeOfDay 12 46 0,"zw\246lf Uhr sechsundvierzig")
  , (TimeOfDay 12 47 0,"zw\246lf Uhr siebenundvierzig")
  , (TimeOfDay 12 48 0,"zw\246lf Uhr achtundvierzig")
  , (TimeOfDay 12 49 0,"zw\246lf Uhr neunundvierzig")
  , (TimeOfDay 12 50 0,"zw\246lf Uhr f\252nfzig")
  , (TimeOfDay 12 51 0,"zw\246lf Uhr einundf\252nfzig")
  , (TimeOfDay 12 52 0,"zw\246lf Uhr zweiundf\252nfzig")
  , (TimeOfDay 12 53 0,"zw\246lf Uhr dreiundf\252nfzig")
  , (TimeOfDay 12 54 0,"zw\246lf Uhr vierundf\252nfzig")
  , (TimeOfDay 12 55 0,"zw\246lf Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 12 56 0,"zw\246lf Uhr sechsundf\252nfzig")
  , (TimeOfDay 12 57 0,"zw\246lf Uhr siebenundf\252nfzig")
  , (TimeOfDay 12 58 0,"zw\246lf Uhr achtundf\252nfzig")
  , (TimeOfDay 12 59 0,"zw\246lf Uhr neunundf\252nfzig")
  , (TimeOfDay 13 0 0,"dreizehn Uhr")
  , (TimeOfDay 13 1 0,"dreizehn Uhr eins")
  , (TimeOfDay 13 2 0,"dreizehn Uhr zwei")
  , (TimeOfDay 13 3 0,"dreizehn Uhr drei")
  , (TimeOfDay 13 4 0,"dreizehn Uhr vier")
  , (TimeOfDay 13 5 0,"dreizehn Uhr f\252nf")
  , (TimeOfDay 13 6 0,"dreizehn Uhr sechs")
  , (TimeOfDay 13 7 0,"dreizehn Uhr sieben")
  , (TimeOfDay 13 8 0,"dreizehn Uhr acht")
  , (TimeOfDay 13 9 0,"dreizehn Uhr neun")
  , (TimeOfDay 13 10 0,"dreizehn Uhr zehn")
  , (TimeOfDay 13 11 0,"dreizehn Uhr elf")
  , (TimeOfDay 13 12 0,"dreizehn Uhr zw\246lf")
  , (TimeOfDay 13 13 0,"dreizehn Uhr dreizehn")
  , (TimeOfDay 13 14 0,"dreizehn Uhr vierzehn")
  , (TimeOfDay 13 15 0,"dreizehn Uhr f\252nfzehn")
  , (TimeOfDay 13 16 0,"dreizehn Uhr sechzehn")
  , (TimeOfDay 13 17 0,"dreizehn Uhr siebzehn")
  , (TimeOfDay 13 18 0,"dreizehn Uhr achtzehn")
  , (TimeOfDay 13 19 0,"dreizehn Uhr neunzehn")
  , (TimeOfDay 13 20 0,"dreizehn Uhr zwanzig")
  , (TimeOfDay 13 21 0,"dreizehn Uhr einundzwanzig")
  , (TimeOfDay 13 22 0,"dreizehn Uhr zweiundzwanzig")
  , (TimeOfDay 13 23 0,"dreizehn Uhr dreiundzwanzig")
  , (TimeOfDay 13 24 0,"dreizehn Uhr vierundzwanzig")
  , (TimeOfDay 13 25 0,"dreizehn Uhr f\252nfundzwanzig")
  , (TimeOfDay 13 26 0,"dreizehn Uhr sechsundzwanzig")
  , (TimeOfDay 13 27 0,"dreizehn Uhr siebenundzwanzig")
  , (TimeOfDay 13 28 0,"dreizehn Uhr achtundzwanzig")
  , (TimeOfDay 13 29 0,"dreizehn Uhr neunundzwanzig")
  , (TimeOfDay 13 30 0,"dreizehn Uhr drei\223ig")
  , (TimeOfDay 13 31 0,"dreizehn Uhr einunddrei\223ig")
  , (TimeOfDay 13 32 0,"dreizehn Uhr zweiunddrei\223ig")
  , (TimeOfDay 13 33 0,"dreizehn Uhr dreiunddrei\223ig")
  , (TimeOfDay 13 34 0,"dreizehn Uhr vierunddrei\223ig")
  , (TimeOfDay 13 35 0,"dreizehn Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 13 36 0,"dreizehn Uhr sechsunddrei\223ig")
  , (TimeOfDay 13 37 0,"dreizehn Uhr siebenunddrei\223ig")
  , (TimeOfDay 13 38 0,"dreizehn Uhr achtunddrei\223ig")
  , (TimeOfDay 13 39 0,"dreizehn Uhr neununddrei\223ig")
  , (TimeOfDay 13 40 0,"dreizehn Uhr vierzig")
  , (TimeOfDay 13 41 0,"dreizehn Uhr einundvierzig")
  , (TimeOfDay 13 42 0,"dreizehn Uhr zweiundvierzig")
  , (TimeOfDay 13 43 0,"dreizehn Uhr dreiundvierzig")
  , (TimeOfDay 13 44 0,"dreizehn Uhr vierundvierzig")
  , (TimeOfDay 13 45 0,"dreizehn Uhr f\252nfundvierzig")
  , (TimeOfDay 13 46 0,"dreizehn Uhr sechsundvierzig")
  , (TimeOfDay 13 47 0,"dreizehn Uhr siebenundvierzig")
  , (TimeOfDay 13 48 0,"dreizehn Uhr achtundvierzig")
  , (TimeOfDay 13 49 0,"dreizehn Uhr neunundvierzig")
  , (TimeOfDay 13 50 0,"dreizehn Uhr f\252nfzig")
  , (TimeOfDay 13 51 0,"dreizehn Uhr einundf\252nfzig")
  , (TimeOfDay 13 52 0,"dreizehn Uhr zweiundf\252nfzig")
  , (TimeOfDay 13 53 0,"dreizehn Uhr dreiundf\252nfzig")
  , (TimeOfDay 13 54 0,"dreizehn Uhr vierundf\252nfzig")
  , (TimeOfDay 13 55 0,"dreizehn Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 13 56 0,"dreizehn Uhr sechsundf\252nfzig")
  , (TimeOfDay 13 57 0,"dreizehn Uhr siebenundf\252nfzig")
  , (TimeOfDay 13 58 0,"dreizehn Uhr achtundf\252nfzig")
  , (TimeOfDay 13 59 0,"dreizehn Uhr neunundf\252nfzig")
  , (TimeOfDay 14 0 0,"vierzehn Uhr")
  , (TimeOfDay 14 1 0,"vierzehn Uhr eins")
  , (TimeOfDay 14 2 0,"vierzehn Uhr zwei")
  , (TimeOfDay 14 3 0,"vierzehn Uhr drei")
  , (TimeOfDay 14 4 0,"vierzehn Uhr vier")
  , (TimeOfDay 14 5 0,"vierzehn Uhr f\252nf")
  , (TimeOfDay 14 6 0,"vierzehn Uhr sechs")
  , (TimeOfDay 14 7 0,"vierzehn Uhr sieben")
  , (TimeOfDay 14 8 0,"vierzehn Uhr acht")
  , (TimeOfDay 14 9 0,"vierzehn Uhr neun")
  , (TimeOfDay 14 10 0,"vierzehn Uhr zehn")
  , (TimeOfDay 14 11 0,"vierzehn Uhr elf")
  , (TimeOfDay 14 12 0,"vierzehn Uhr zw\246lf")
  , (TimeOfDay 14 13 0,"vierzehn Uhr dreizehn")
  , (TimeOfDay 14 14 0,"vierzehn Uhr vierzehn")
  , (TimeOfDay 14 15 0,"vierzehn Uhr f\252nfzehn")
  , (TimeOfDay 14 16 0,"vierzehn Uhr sechzehn")
  , (TimeOfDay 14 17 0,"vierzehn Uhr siebzehn")
  , (TimeOfDay 14 18 0,"vierzehn Uhr achtzehn")
  , (TimeOfDay 14 19 0,"vierzehn Uhr neunzehn")
  , (TimeOfDay 14 20 0,"vierzehn Uhr zwanzig")
  , (TimeOfDay 14 21 0,"vierzehn Uhr einundzwanzig")
  , (TimeOfDay 14 22 0,"vierzehn Uhr zweiundzwanzig")
  , (TimeOfDay 14 23 0,"vierzehn Uhr dreiundzwanzig")
  , (TimeOfDay 14 24 0,"vierzehn Uhr vierundzwanzig")
  , (TimeOfDay 14 25 0,"vierzehn Uhr f\252nfundzwanzig")
  , (TimeOfDay 14 26 0,"vierzehn Uhr sechsundzwanzig")
  , (TimeOfDay 14 27 0,"vierzehn Uhr siebenundzwanzig")
  , (TimeOfDay 14 28 0,"vierzehn Uhr achtundzwanzig")
  , (TimeOfDay 14 29 0,"vierzehn Uhr neunundzwanzig")
  , (TimeOfDay 14 30 0,"vierzehn Uhr drei\223ig")
  , (TimeOfDay 14 31 0,"vierzehn Uhr einunddrei\223ig")
  , (TimeOfDay 14 32 0,"vierzehn Uhr zweiunddrei\223ig")
  , (TimeOfDay 14 33 0,"vierzehn Uhr dreiunddrei\223ig")
  , (TimeOfDay 14 34 0,"vierzehn Uhr vierunddrei\223ig")
  , (TimeOfDay 14 35 0,"vierzehn Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 14 36 0,"vierzehn Uhr sechsunddrei\223ig")
  , (TimeOfDay 14 37 0,"vierzehn Uhr siebenunddrei\223ig")
  , (TimeOfDay 14 38 0,"vierzehn Uhr achtunddrei\223ig")
  , (TimeOfDay 14 39 0,"vierzehn Uhr neununddrei\223ig")
  , (TimeOfDay 14 40 0,"vierzehn Uhr vierzig")
  , (TimeOfDay 14 41 0,"vierzehn Uhr einundvierzig")
  , (TimeOfDay 14 42 0,"vierzehn Uhr zweiundvierzig")
  , (TimeOfDay 14 43 0,"vierzehn Uhr dreiundvierzig")
  , (TimeOfDay 14 44 0,"vierzehn Uhr vierundvierzig")
  , (TimeOfDay 14 45 0,"vierzehn Uhr f\252nfundvierzig")
  , (TimeOfDay 14 46 0,"vierzehn Uhr sechsundvierzig")
  , (TimeOfDay 14 47 0,"vierzehn Uhr siebenundvierzig")
  , (TimeOfDay 14 48 0,"vierzehn Uhr achtundvierzig")
  , (TimeOfDay 14 49 0,"vierzehn Uhr neunundvierzig")
  , (TimeOfDay 14 50 0,"vierzehn Uhr f\252nfzig")
  , (TimeOfDay 14 51 0,"vierzehn Uhr einundf\252nfzig")
  , (TimeOfDay 14 52 0,"vierzehn Uhr zweiundf\252nfzig")
  , (TimeOfDay 14 53 0,"vierzehn Uhr dreiundf\252nfzig")
  , (TimeOfDay 14 54 0,"vierzehn Uhr vierundf\252nfzig")
  , (TimeOfDay 14 55 0,"vierzehn Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 14 56 0,"vierzehn Uhr sechsundf\252nfzig")
  , (TimeOfDay 14 57 0,"vierzehn Uhr siebenundf\252nfzig")
  , (TimeOfDay 14 58 0,"vierzehn Uhr achtundf\252nfzig")
  , (TimeOfDay 14 59 0,"vierzehn Uhr neunundf\252nfzig")
  , (TimeOfDay 15 0 0,"f\252nfzehn Uhr")
  , (TimeOfDay 15 1 0,"f\252nfzehn Uhr eins")
  , (TimeOfDay 15 2 0,"f\252nfzehn Uhr zwei")
  , (TimeOfDay 15 3 0,"f\252nfzehn Uhr drei")
  , (TimeOfDay 15 4 0,"f\252nfzehn Uhr vier")
  , (TimeOfDay 15 5 0,"f\252nfzehn Uhr f\252nf")
  , (TimeOfDay 15 6 0,"f\252nfzehn Uhr sechs")
  , (TimeOfDay 15 7 0,"f\252nfzehn Uhr sieben")
  , (TimeOfDay 15 8 0,"f\252nfzehn Uhr acht")
  , (TimeOfDay 15 9 0,"f\252nfzehn Uhr neun")
  , (TimeOfDay 15 10 0,"f\252nfzehn Uhr zehn")
  , (TimeOfDay 15 11 0,"f\252nfzehn Uhr elf")
  , (TimeOfDay 15 12 0,"f\252nfzehn Uhr zw\246lf")
  , (TimeOfDay 15 13 0,"f\252nfzehn Uhr dreizehn")
  , (TimeOfDay 15 14 0,"f\252nfzehn Uhr vierzehn")
  , (TimeOfDay 15 15 0,"f\252nfzehn Uhr f\252nfzehn")
  , (TimeOfDay 15 16 0,"f\252nfzehn Uhr sechzehn")
  , (TimeOfDay 15 17 0,"f\252nfzehn Uhr siebzehn")
  , (TimeOfDay 15 18 0,"f\252nfzehn Uhr achtzehn")
  , (TimeOfDay 15 19 0,"f\252nfzehn Uhr neunzehn")
  , (TimeOfDay 15 20 0,"f\252nfzehn Uhr zwanzig")
  , (TimeOfDay 15 21 0,"f\252nfzehn Uhr einundzwanzig")
  , (TimeOfDay 15 22 0,"f\252nfzehn Uhr zweiundzwanzig")
  , (TimeOfDay 15 23 0,"f\252nfzehn Uhr dreiundzwanzig")
  , (TimeOfDay 15 24 0,"f\252nfzehn Uhr vierundzwanzig")
  , (TimeOfDay 15 25 0,"f\252nfzehn Uhr f\252nfundzwanzig")
  , (TimeOfDay 15 26 0,"f\252nfzehn Uhr sechsundzwanzig")
  , (TimeOfDay 15 27 0,"f\252nfzehn Uhr siebenundzwanzig")
  , (TimeOfDay 15 28 0,"f\252nfzehn Uhr achtundzwanzig")
  , (TimeOfDay 15 29 0,"f\252nfzehn Uhr neunundzwanzig")
  , (TimeOfDay 15 30 0,"f\252nfzehn Uhr drei\223ig")
  , (TimeOfDay 15 31 0,"f\252nfzehn Uhr einunddrei\223ig")
  , (TimeOfDay 15 32 0,"f\252nfzehn Uhr zweiunddrei\223ig")
  , (TimeOfDay 15 33 0,"f\252nfzehn Uhr dreiunddrei\223ig")
  , (TimeOfDay 15 34 0,"f\252nfzehn Uhr vierunddrei\223ig")
  , (TimeOfDay 15 35 0,"f\252nfzehn Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 15 36 0,"f\252nfzehn Uhr sechsunddrei\223ig")
  , (TimeOfDay 15 37 0,"f\252nfzehn Uhr siebenunddrei\223ig")
  , (TimeOfDay 15 38 0,"f\252nfzehn Uhr achtunddrei\223ig")
  , (TimeOfDay 15 39 0,"f\252nfzehn Uhr neununddrei\223ig")
  , (TimeOfDay 15 40 0,"f\252nfzehn Uhr vierzig")
  , (TimeOfDay 15 41 0,"f\252nfzehn Uhr einundvierzig")
  , (TimeOfDay 15 42 0,"f\252nfzehn Uhr zweiundvierzig")
  , (TimeOfDay 15 43 0,"f\252nfzehn Uhr dreiundvierzig")
  , (TimeOfDay 15 44 0,"f\252nfzehn Uhr vierundvierzig")
  , (TimeOfDay 15 45 0,"f\252nfzehn Uhr f\252nfundvierzig")
  , (TimeOfDay 15 46 0,"f\252nfzehn Uhr sechsundvierzig")
  , (TimeOfDay 15 47 0,"f\252nfzehn Uhr siebenundvierzig")
  , (TimeOfDay 15 48 0,"f\252nfzehn Uhr achtundvierzig")
  , (TimeOfDay 15 49 0,"f\252nfzehn Uhr neunundvierzig")
  , (TimeOfDay 15 50 0,"f\252nfzehn Uhr f\252nfzig")
  , (TimeOfDay 15 51 0,"f\252nfzehn Uhr einundf\252nfzig")
  , (TimeOfDay 15 52 0,"f\252nfzehn Uhr zweiundf\252nfzig")
  , (TimeOfDay 15 53 0,"f\252nfzehn Uhr dreiundf\252nfzig")
  , (TimeOfDay 15 54 0,"f\252nfzehn Uhr vierundf\252nfzig")
  , (TimeOfDay 15 55 0,"f\252nfzehn Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 15 56 0,"f\252nfzehn Uhr sechsundf\252nfzig")
  , (TimeOfDay 15 57 0,"f\252nfzehn Uhr siebenundf\252nfzig")
  , (TimeOfDay 15 58 0,"f\252nfzehn Uhr achtundf\252nfzig")
  , (TimeOfDay 15 59 0,"f\252nfzehn Uhr neunundf\252nfzig")
  , (TimeOfDay 16 0 0,"sechzehn Uhr")
  , (TimeOfDay 16 1 0,"sechzehn Uhr eins")
  , (TimeOfDay 16 2 0,"sechzehn Uhr zwei")
  , (TimeOfDay 16 3 0,"sechzehn Uhr drei")
  , (TimeOfDay 16 4 0,"sechzehn Uhr vier")
  , (TimeOfDay 16 5 0,"sechzehn Uhr f\252nf")
  , (TimeOfDay 16 6 0,"sechzehn Uhr sechs")
  , (TimeOfDay 16 7 0,"sechzehn Uhr sieben")
  , (TimeOfDay 16 8 0,"sechzehn Uhr acht")
  , (TimeOfDay 16 9 0,"sechzehn Uhr neun")
  , (TimeOfDay 16 10 0,"sechzehn Uhr zehn")
  , (TimeOfDay 16 11 0,"sechzehn Uhr elf")
  , (TimeOfDay 16 12 0,"sechzehn Uhr zw\246lf")
  , (TimeOfDay 16 13 0,"sechzehn Uhr dreizehn")
  , (TimeOfDay 16 14 0,"sechzehn Uhr vierzehn")
  , (TimeOfDay 16 15 0,"sechzehn Uhr f\252nfzehn")
  , (TimeOfDay 16 16 0,"sechzehn Uhr sechzehn")
  , (TimeOfDay 16 17 0,"sechzehn Uhr siebzehn")
  , (TimeOfDay 16 18 0,"sechzehn Uhr achtzehn")
  , (TimeOfDay 16 19 0,"sechzehn Uhr neunzehn")
  , (TimeOfDay 16 20 0,"sechzehn Uhr zwanzig")
  , (TimeOfDay 16 21 0,"sechzehn Uhr einundzwanzig")
  , (TimeOfDay 16 22 0,"sechzehn Uhr zweiundzwanzig")
  , (TimeOfDay 16 23 0,"sechzehn Uhr dreiundzwanzig")
  , (TimeOfDay 16 24 0,"sechzehn Uhr vierundzwanzig")
  , (TimeOfDay 16 25 0,"sechzehn Uhr f\252nfundzwanzig")
  , (TimeOfDay 16 26 0,"sechzehn Uhr sechsundzwanzig")
  , (TimeOfDay 16 27 0,"sechzehn Uhr siebenundzwanzig")
  , (TimeOfDay 16 28 0,"sechzehn Uhr achtundzwanzig")
  , (TimeOfDay 16 29 0,"sechzehn Uhr neunundzwanzig")
  , (TimeOfDay 16 30 0,"sechzehn Uhr drei\223ig")
  , (TimeOfDay 16 31 0,"sechzehn Uhr einunddrei\223ig")
  , (TimeOfDay 16 32 0,"sechzehn Uhr zweiunddrei\223ig")
  , (TimeOfDay 16 33 0,"sechzehn Uhr dreiunddrei\223ig")
  , (TimeOfDay 16 34 0,"sechzehn Uhr vierunddrei\223ig")
  , (TimeOfDay 16 35 0,"sechzehn Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 16 36 0,"sechzehn Uhr sechsunddrei\223ig")
  , (TimeOfDay 16 37 0,"sechzehn Uhr siebenunddrei\223ig")
  , (TimeOfDay 16 38 0,"sechzehn Uhr achtunddrei\223ig")
  , (TimeOfDay 16 39 0,"sechzehn Uhr neununddrei\223ig")
  , (TimeOfDay 16 40 0,"sechzehn Uhr vierzig")
  , (TimeOfDay 16 41 0,"sechzehn Uhr einundvierzig")
  , (TimeOfDay 16 42 0,"sechzehn Uhr zweiundvierzig")
  , (TimeOfDay 16 43 0,"sechzehn Uhr dreiundvierzig")
  , (TimeOfDay 16 44 0,"sechzehn Uhr vierundvierzig")
  , (TimeOfDay 16 45 0,"sechzehn Uhr f\252nfundvierzig")
  , (TimeOfDay 16 46 0,"sechzehn Uhr sechsundvierzig")
  , (TimeOfDay 16 47 0,"sechzehn Uhr siebenundvierzig")
  , (TimeOfDay 16 48 0,"sechzehn Uhr achtundvierzig")
  , (TimeOfDay 16 49 0,"sechzehn Uhr neunundvierzig")
  , (TimeOfDay 16 50 0,"sechzehn Uhr f\252nfzig")
  , (TimeOfDay 16 51 0,"sechzehn Uhr einundf\252nfzig")
  , (TimeOfDay 16 52 0,"sechzehn Uhr zweiundf\252nfzig")
  , (TimeOfDay 16 53 0,"sechzehn Uhr dreiundf\252nfzig")
  , (TimeOfDay 16 54 0,"sechzehn Uhr vierundf\252nfzig")
  , (TimeOfDay 16 55 0,"sechzehn Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 16 56 0,"sechzehn Uhr sechsundf\252nfzig")
  , (TimeOfDay 16 57 0,"sechzehn Uhr siebenundf\252nfzig")
  , (TimeOfDay 16 58 0,"sechzehn Uhr achtundf\252nfzig")
  , (TimeOfDay 16 59 0,"sechzehn Uhr neunundf\252nfzig")
  , (TimeOfDay 17 0 0,"siebzehn Uhr")
  , (TimeOfDay 17 1 0,"siebzehn Uhr eins")
  , (TimeOfDay 17 2 0,"siebzehn Uhr zwei")
  , (TimeOfDay 17 3 0,"siebzehn Uhr drei")
  , (TimeOfDay 17 4 0,"siebzehn Uhr vier")
  , (TimeOfDay 17 5 0,"siebzehn Uhr f\252nf")
  , (TimeOfDay 17 6 0,"siebzehn Uhr sechs")
  , (TimeOfDay 17 7 0,"siebzehn Uhr sieben")
  , (TimeOfDay 17 8 0,"siebzehn Uhr acht")
  , (TimeOfDay 17 9 0,"siebzehn Uhr neun")
  , (TimeOfDay 17 10 0,"siebzehn Uhr zehn")
  , (TimeOfDay 17 11 0,"siebzehn Uhr elf")
  , (TimeOfDay 17 12 0,"siebzehn Uhr zw\246lf")
  , (TimeOfDay 17 13 0,"siebzehn Uhr dreizehn")
  , (TimeOfDay 17 14 0,"siebzehn Uhr vierzehn")
  , (TimeOfDay 17 15 0,"siebzehn Uhr f\252nfzehn")
  , (TimeOfDay 17 16 0,"siebzehn Uhr sechzehn")
  , (TimeOfDay 17 17 0,"siebzehn Uhr siebzehn")
  , (TimeOfDay 17 18 0,"siebzehn Uhr achtzehn")
  , (TimeOfDay 17 19 0,"siebzehn Uhr neunzehn")
  , (TimeOfDay 17 20 0,"siebzehn Uhr zwanzig")
  , (TimeOfDay 17 21 0,"siebzehn Uhr einundzwanzig")
  , (TimeOfDay 17 22 0,"siebzehn Uhr zweiundzwanzig")
  , (TimeOfDay 17 23 0,"siebzehn Uhr dreiundzwanzig")
  , (TimeOfDay 17 24 0,"siebzehn Uhr vierundzwanzig")
  , (TimeOfDay 17 25 0,"siebzehn Uhr f\252nfundzwanzig")
  , (TimeOfDay 17 26 0,"siebzehn Uhr sechsundzwanzig")
  , (TimeOfDay 17 27 0,"siebzehn Uhr siebenundzwanzig")
  , (TimeOfDay 17 28 0,"siebzehn Uhr achtundzwanzig")
  , (TimeOfDay 17 29 0,"siebzehn Uhr neunundzwanzig")
  , (TimeOfDay 17 30 0,"siebzehn Uhr drei\223ig")
  , (TimeOfDay 17 31 0,"siebzehn Uhr einunddrei\223ig")
  , (TimeOfDay 17 32 0,"siebzehn Uhr zweiunddrei\223ig")
  , (TimeOfDay 17 33 0,"siebzehn Uhr dreiunddrei\223ig")
  , (TimeOfDay 17 34 0,"siebzehn Uhr vierunddrei\223ig")
  , (TimeOfDay 17 35 0,"siebzehn Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 17 36 0,"siebzehn Uhr sechsunddrei\223ig")
  , (TimeOfDay 17 37 0,"siebzehn Uhr siebenunddrei\223ig")
  , (TimeOfDay 17 38 0,"siebzehn Uhr achtunddrei\223ig")
  , (TimeOfDay 17 39 0,"siebzehn Uhr neununddrei\223ig")
  , (TimeOfDay 17 40 0,"siebzehn Uhr vierzig")
  , (TimeOfDay 17 41 0,"siebzehn Uhr einundvierzig")
  , (TimeOfDay 17 42 0,"siebzehn Uhr zweiundvierzig")
  , (TimeOfDay 17 43 0,"siebzehn Uhr dreiundvierzig")
  , (TimeOfDay 17 44 0,"siebzehn Uhr vierundvierzig")
  , (TimeOfDay 17 45 0,"siebzehn Uhr f\252nfundvierzig")
  , (TimeOfDay 17 46 0,"siebzehn Uhr sechsundvierzig")
  , (TimeOfDay 17 47 0,"siebzehn Uhr siebenundvierzig")
  , (TimeOfDay 17 48 0,"siebzehn Uhr achtundvierzig")
  , (TimeOfDay 17 49 0,"siebzehn Uhr neunundvierzig")
  , (TimeOfDay 17 50 0,"siebzehn Uhr f\252nfzig")
  , (TimeOfDay 17 51 0,"siebzehn Uhr einundf\252nfzig")
  , (TimeOfDay 17 52 0,"siebzehn Uhr zweiundf\252nfzig")
  , (TimeOfDay 17 53 0,"siebzehn Uhr dreiundf\252nfzig")
  , (TimeOfDay 17 54 0,"siebzehn Uhr vierundf\252nfzig")
  , (TimeOfDay 17 55 0,"siebzehn Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 17 56 0,"siebzehn Uhr sechsundf\252nfzig")
  , (TimeOfDay 17 57 0,"siebzehn Uhr siebenundf\252nfzig")
  , (TimeOfDay 17 58 0,"siebzehn Uhr achtundf\252nfzig")
  , (TimeOfDay 17 59 0,"siebzehn Uhr neunundf\252nfzig")
  , (TimeOfDay 18 0 0,"achtzehn Uhr")
  , (TimeOfDay 18 1 0,"achtzehn Uhr eins")
  , (TimeOfDay 18 2 0,"achtzehn Uhr zwei")
  , (TimeOfDay 18 3 0,"achtzehn Uhr drei")
  , (TimeOfDay 18 4 0,"achtzehn Uhr vier")
  , (TimeOfDay 18 5 0,"achtzehn Uhr f\252nf")
  , (TimeOfDay 18 6 0,"achtzehn Uhr sechs")
  , (TimeOfDay 18 7 0,"achtzehn Uhr sieben")
  , (TimeOfDay 18 8 0,"achtzehn Uhr acht")
  , (TimeOfDay 18 9 0,"achtzehn Uhr neun")
  , (TimeOfDay 18 10 0,"achtzehn Uhr zehn")
  , (TimeOfDay 18 11 0,"achtzehn Uhr elf")
  , (TimeOfDay 18 12 0,"achtzehn Uhr zw\246lf")
  , (TimeOfDay 18 13 0,"achtzehn Uhr dreizehn")
  , (TimeOfDay 18 14 0,"achtzehn Uhr vierzehn")
  , (TimeOfDay 18 15 0,"achtzehn Uhr f\252nfzehn")
  , (TimeOfDay 18 16 0,"achtzehn Uhr sechzehn")
  , (TimeOfDay 18 17 0,"achtzehn Uhr siebzehn")
  , (TimeOfDay 18 18 0,"achtzehn Uhr achtzehn")
  , (TimeOfDay 18 19 0,"achtzehn Uhr neunzehn")
  , (TimeOfDay 18 20 0,"achtzehn Uhr zwanzig")
  , (TimeOfDay 18 21 0,"achtzehn Uhr einundzwanzig")
  , (TimeOfDay 18 22 0,"achtzehn Uhr zweiundzwanzig")
  , (TimeOfDay 18 23 0,"achtzehn Uhr dreiundzwanzig")
  , (TimeOfDay 18 24 0,"achtzehn Uhr vierundzwanzig")
  , (TimeOfDay 18 25 0,"achtzehn Uhr f\252nfundzwanzig")
  , (TimeOfDay 18 26 0,"achtzehn Uhr sechsundzwanzig")
  , (TimeOfDay 18 27 0,"achtzehn Uhr siebenundzwanzig")
  , (TimeOfDay 18 28 0,"achtzehn Uhr achtundzwanzig")
  , (TimeOfDay 18 29 0,"achtzehn Uhr neunundzwanzig")
  , (TimeOfDay 18 30 0,"achtzehn Uhr drei\223ig")
  , (TimeOfDay 18 31 0,"achtzehn Uhr einunddrei\223ig")
  , (TimeOfDay 18 32 0,"achtzehn Uhr zweiunddrei\223ig")
  , (TimeOfDay 18 33 0,"achtzehn Uhr dreiunddrei\223ig")
  , (TimeOfDay 18 34 0,"achtzehn Uhr vierunddrei\223ig")
  , (TimeOfDay 18 35 0,"achtzehn Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 18 36 0,"achtzehn Uhr sechsunddrei\223ig")
  , (TimeOfDay 18 37 0,"achtzehn Uhr siebenunddrei\223ig")
  , (TimeOfDay 18 38 0,"achtzehn Uhr achtunddrei\223ig")
  , (TimeOfDay 18 39 0,"achtzehn Uhr neununddrei\223ig")
  , (TimeOfDay 18 40 0,"achtzehn Uhr vierzig")
  , (TimeOfDay 18 41 0,"achtzehn Uhr einundvierzig")
  , (TimeOfDay 18 42 0,"achtzehn Uhr zweiundvierzig")
  , (TimeOfDay 18 43 0,"achtzehn Uhr dreiundvierzig")
  , (TimeOfDay 18 44 0,"achtzehn Uhr vierundvierzig")
  , (TimeOfDay 18 45 0,"achtzehn Uhr f\252nfundvierzig")
  , (TimeOfDay 18 46 0,"achtzehn Uhr sechsundvierzig")
  , (TimeOfDay 18 47 0,"achtzehn Uhr siebenundvierzig")
  , (TimeOfDay 18 48 0,"achtzehn Uhr achtundvierzig")
  , (TimeOfDay 18 49 0,"achtzehn Uhr neunundvierzig")
  , (TimeOfDay 18 50 0,"achtzehn Uhr f\252nfzig")
  , (TimeOfDay 18 51 0,"achtzehn Uhr einundf\252nfzig")
  , (TimeOfDay 18 52 0,"achtzehn Uhr zweiundf\252nfzig")
  , (TimeOfDay 18 53 0,"achtzehn Uhr dreiundf\252nfzig")
  , (TimeOfDay 18 54 0,"achtzehn Uhr vierundf\252nfzig")
  , (TimeOfDay 18 55 0,"achtzehn Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 18 56 0,"achtzehn Uhr sechsundf\252nfzig")
  , (TimeOfDay 18 57 0,"achtzehn Uhr siebenundf\252nfzig")
  , (TimeOfDay 18 58 0,"achtzehn Uhr achtundf\252nfzig")
  , (TimeOfDay 18 59 0,"achtzehn Uhr neunundf\252nfzig")
  , (TimeOfDay 19 0 0,"neunzehn Uhr")
  , (TimeOfDay 19 1 0,"neunzehn Uhr eins")
  , (TimeOfDay 19 2 0,"neunzehn Uhr zwei")
  , (TimeOfDay 19 3 0,"neunzehn Uhr drei")
  , (TimeOfDay 19 4 0,"neunzehn Uhr vier")
  , (TimeOfDay 19 5 0,"neunzehn Uhr f\252nf")
  , (TimeOfDay 19 6 0,"neunzehn Uhr sechs")
  , (TimeOfDay 19 7 0,"neunzehn Uhr sieben")
  , (TimeOfDay 19 8 0,"neunzehn Uhr acht")
  , (TimeOfDay 19 9 0,"neunzehn Uhr neun")
  , (TimeOfDay 19 10 0,"neunzehn Uhr zehn")
  , (TimeOfDay 19 11 0,"neunzehn Uhr elf")
  , (TimeOfDay 19 12 0,"neunzehn Uhr zw\246lf")
  , (TimeOfDay 19 13 0,"neunzehn Uhr dreizehn")
  , (TimeOfDay 19 14 0,"neunzehn Uhr vierzehn")
  , (TimeOfDay 19 15 0,"neunzehn Uhr f\252nfzehn")
  , (TimeOfDay 19 16 0,"neunzehn Uhr sechzehn")
  , (TimeOfDay 19 17 0,"neunzehn Uhr siebzehn")
  , (TimeOfDay 19 18 0,"neunzehn Uhr achtzehn")
  , (TimeOfDay 19 19 0,"neunzehn Uhr neunzehn")
  , (TimeOfDay 19 20 0,"neunzehn Uhr zwanzig")
  , (TimeOfDay 19 21 0,"neunzehn Uhr einundzwanzig")
  , (TimeOfDay 19 22 0,"neunzehn Uhr zweiundzwanzig")
  , (TimeOfDay 19 23 0,"neunzehn Uhr dreiundzwanzig")
  , (TimeOfDay 19 24 0,"neunzehn Uhr vierundzwanzig")
  , (TimeOfDay 19 25 0,"neunzehn Uhr f\252nfundzwanzig")
  , (TimeOfDay 19 26 0,"neunzehn Uhr sechsundzwanzig")
  , (TimeOfDay 19 27 0,"neunzehn Uhr siebenundzwanzig")
  , (TimeOfDay 19 28 0,"neunzehn Uhr achtundzwanzig")
  , (TimeOfDay 19 29 0,"neunzehn Uhr neunundzwanzig")
  , (TimeOfDay 19 30 0,"neunzehn Uhr drei\223ig")
  , (TimeOfDay 19 31 0,"neunzehn Uhr einunddrei\223ig")
  , (TimeOfDay 19 32 0,"neunzehn Uhr zweiunddrei\223ig")
  , (TimeOfDay 19 33 0,"neunzehn Uhr dreiunddrei\223ig")
  , (TimeOfDay 19 34 0,"neunzehn Uhr vierunddrei\223ig")
  , (TimeOfDay 19 35 0,"neunzehn Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 19 36 0,"neunzehn Uhr sechsunddrei\223ig")
  , (TimeOfDay 19 37 0,"neunzehn Uhr siebenunddrei\223ig")
  , (TimeOfDay 19 38 0,"neunzehn Uhr achtunddrei\223ig")
  , (TimeOfDay 19 39 0,"neunzehn Uhr neununddrei\223ig")
  , (TimeOfDay 19 40 0,"neunzehn Uhr vierzig")
  , (TimeOfDay 19 41 0,"neunzehn Uhr einundvierzig")
  , (TimeOfDay 19 42 0,"neunzehn Uhr zweiundvierzig")
  , (TimeOfDay 19 43 0,"neunzehn Uhr dreiundvierzig")
  , (TimeOfDay 19 44 0,"neunzehn Uhr vierundvierzig")
  , (TimeOfDay 19 45 0,"neunzehn Uhr f\252nfundvierzig")
  , (TimeOfDay 19 46 0,"neunzehn Uhr sechsundvierzig")
  , (TimeOfDay 19 47 0,"neunzehn Uhr siebenundvierzig")
  , (TimeOfDay 19 48 0,"neunzehn Uhr achtundvierzig")
  , (TimeOfDay 19 49 0,"neunzehn Uhr neunundvierzig")
  , (TimeOfDay 19 50 0,"neunzehn Uhr f\252nfzig")
  , (TimeOfDay 19 51 0,"neunzehn Uhr einundf\252nfzig")
  , (TimeOfDay 19 52 0,"neunzehn Uhr zweiundf\252nfzig")
  , (TimeOfDay 19 53 0,"neunzehn Uhr dreiundf\252nfzig")
  , (TimeOfDay 19 54 0,"neunzehn Uhr vierundf\252nfzig")
  , (TimeOfDay 19 55 0,"neunzehn Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 19 56 0,"neunzehn Uhr sechsundf\252nfzig")
  , (TimeOfDay 19 57 0,"neunzehn Uhr siebenundf\252nfzig")
  , (TimeOfDay 19 58 0,"neunzehn Uhr achtundf\252nfzig")
  , (TimeOfDay 19 59 0,"neunzehn Uhr neunundf\252nfzig")
  , (TimeOfDay 20 0 0,"zwanzig Uhr")
  , (TimeOfDay 20 1 0,"zwanzig Uhr eins")
  , (TimeOfDay 20 2 0,"zwanzig Uhr zwei")
  , (TimeOfDay 20 3 0,"zwanzig Uhr drei")
  , (TimeOfDay 20 4 0,"zwanzig Uhr vier")
  , (TimeOfDay 20 5 0,"zwanzig Uhr f\252nf")
  , (TimeOfDay 20 6 0,"zwanzig Uhr sechs")
  , (TimeOfDay 20 7 0,"zwanzig Uhr sieben")
  , (TimeOfDay 20 8 0,"zwanzig Uhr acht")
  , (TimeOfDay 20 9 0,"zwanzig Uhr neun")
  , (TimeOfDay 20 10 0,"zwanzig Uhr zehn")
  , (TimeOfDay 20 11 0,"zwanzig Uhr elf")
  , (TimeOfDay 20 12 0,"zwanzig Uhr zw\246lf")
  , (TimeOfDay 20 13 0,"zwanzig Uhr dreizehn")
  , (TimeOfDay 20 14 0,"zwanzig Uhr vierzehn")
  , (TimeOfDay 20 15 0,"zwanzig Uhr f\252nfzehn")
  , (TimeOfDay 20 16 0,"zwanzig Uhr sechzehn")
  , (TimeOfDay 20 17 0,"zwanzig Uhr siebzehn")
  , (TimeOfDay 20 18 0,"zwanzig Uhr achtzehn")
  , (TimeOfDay 20 19 0,"zwanzig Uhr neunzehn")
  , (TimeOfDay 20 20 0,"zwanzig Uhr zwanzig")
  , (TimeOfDay 20 21 0,"zwanzig Uhr einundzwanzig")
  , (TimeOfDay 20 22 0,"zwanzig Uhr zweiundzwanzig")
  , (TimeOfDay 20 23 0,"zwanzig Uhr dreiundzwanzig")
  , (TimeOfDay 20 24 0,"zwanzig Uhr vierundzwanzig")
  , (TimeOfDay 20 25 0,"zwanzig Uhr f\252nfundzwanzig")
  , (TimeOfDay 20 26 0,"zwanzig Uhr sechsundzwanzig")
  , (TimeOfDay 20 27 0,"zwanzig Uhr siebenundzwanzig")
  , (TimeOfDay 20 28 0,"zwanzig Uhr achtundzwanzig")
  , (TimeOfDay 20 29 0,"zwanzig Uhr neunundzwanzig")
  , (TimeOfDay 20 30 0,"zwanzig Uhr drei\223ig")
  , (TimeOfDay 20 31 0,"zwanzig Uhr einunddrei\223ig")
  , (TimeOfDay 20 32 0,"zwanzig Uhr zweiunddrei\223ig")
  , (TimeOfDay 20 33 0,"zwanzig Uhr dreiunddrei\223ig")
  , (TimeOfDay 20 34 0,"zwanzig Uhr vierunddrei\223ig")
  , (TimeOfDay 20 35 0,"zwanzig Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 20 36 0,"zwanzig Uhr sechsunddrei\223ig")
  , (TimeOfDay 20 37 0,"zwanzig Uhr siebenunddrei\223ig")
  , (TimeOfDay 20 38 0,"zwanzig Uhr achtunddrei\223ig")
  , (TimeOfDay 20 39 0,"zwanzig Uhr neununddrei\223ig")
  , (TimeOfDay 20 40 0,"zwanzig Uhr vierzig")
  , (TimeOfDay 20 41 0,"zwanzig Uhr einundvierzig")
  , (TimeOfDay 20 42 0,"zwanzig Uhr zweiundvierzig")
  , (TimeOfDay 20 43 0,"zwanzig Uhr dreiundvierzig")
  , (TimeOfDay 20 44 0,"zwanzig Uhr vierundvierzig")
  , (TimeOfDay 20 45 0,"zwanzig Uhr f\252nfundvierzig")
  , (TimeOfDay 20 46 0,"zwanzig Uhr sechsundvierzig")
  , (TimeOfDay 20 47 0,"zwanzig Uhr siebenundvierzig")
  , (TimeOfDay 20 48 0,"zwanzig Uhr achtundvierzig")
  , (TimeOfDay 20 49 0,"zwanzig Uhr neunundvierzig")
  , (TimeOfDay 20 50 0,"zwanzig Uhr f\252nfzig")
  , (TimeOfDay 20 51 0,"zwanzig Uhr einundf\252nfzig")
  , (TimeOfDay 20 52 0,"zwanzig Uhr zweiundf\252nfzig")
  , (TimeOfDay 20 53 0,"zwanzig Uhr dreiundf\252nfzig")
  , (TimeOfDay 20 54 0,"zwanzig Uhr vierundf\252nfzig")
  , (TimeOfDay 20 55 0,"zwanzig Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 20 56 0,"zwanzig Uhr sechsundf\252nfzig")
  , (TimeOfDay 20 57 0,"zwanzig Uhr siebenundf\252nfzig")
  , (TimeOfDay 20 58 0,"zwanzig Uhr achtundf\252nfzig")
  , (TimeOfDay 20 59 0,"zwanzig Uhr neunundf\252nfzig")
  , (TimeOfDay 21 0 0,"einundzwanzig Uhr")
  , (TimeOfDay 21 1 0,"einundzwanzig Uhr eins")
  , (TimeOfDay 21 2 0,"einundzwanzig Uhr zwei")
  , (TimeOfDay 21 3 0,"einundzwanzig Uhr drei")
  , (TimeOfDay 21 4 0,"einundzwanzig Uhr vier")
  , (TimeOfDay 21 5 0,"einundzwanzig Uhr f\252nf")
  , (TimeOfDay 21 6 0,"einundzwanzig Uhr sechs")
  , (TimeOfDay 21 7 0,"einundzwanzig Uhr sieben")
  , (TimeOfDay 21 8 0,"einundzwanzig Uhr acht")
  , (TimeOfDay 21 9 0,"einundzwanzig Uhr neun")
  , (TimeOfDay 21 10 0,"einundzwanzig Uhr zehn")
  , (TimeOfDay 21 11 0,"einundzwanzig Uhr elf")
  , (TimeOfDay 21 12 0,"einundzwanzig Uhr zw\246lf")
  , (TimeOfDay 21 13 0,"einundzwanzig Uhr dreizehn")
  , (TimeOfDay 21 14 0,"einundzwanzig Uhr vierzehn")
  , (TimeOfDay 21 15 0,"einundzwanzig Uhr f\252nfzehn")
  , (TimeOfDay 21 16 0,"einundzwanzig Uhr sechzehn")
  , (TimeOfDay 21 17 0,"einundzwanzig Uhr siebzehn")
  , (TimeOfDay 21 18 0,"einundzwanzig Uhr achtzehn")
  , (TimeOfDay 21 19 0,"einundzwanzig Uhr neunzehn")
  , (TimeOfDay 21 20 0,"einundzwanzig Uhr zwanzig")
  , (TimeOfDay 21 21 0,"einundzwanzig Uhr einundzwanzig")
  , (TimeOfDay 21 22 0,"einundzwanzig Uhr zweiundzwanzig")
  , (TimeOfDay 21 23 0,"einundzwanzig Uhr dreiundzwanzig")
  , (TimeOfDay 21 24 0,"einundzwanzig Uhr vierundzwanzig")
  , (TimeOfDay 21 25 0,"einundzwanzig Uhr f\252nfundzwanzig")
  , (TimeOfDay 21 26 0,"einundzwanzig Uhr sechsundzwanzig")
  , (TimeOfDay 21 27 0,"einundzwanzig Uhr siebenundzwanzig")
  , (TimeOfDay 21 28 0,"einundzwanzig Uhr achtundzwanzig")
  , (TimeOfDay 21 29 0,"einundzwanzig Uhr neunundzwanzig")
  , (TimeOfDay 21 30 0,"einundzwanzig Uhr drei\223ig")
  , (TimeOfDay 21 31 0,"einundzwanzig Uhr einunddrei\223ig")
  , (TimeOfDay 21 32 0,"einundzwanzig Uhr zweiunddrei\223ig")
  , (TimeOfDay 21 33 0,"einundzwanzig Uhr dreiunddrei\223ig")
  , (TimeOfDay 21 34 0,"einundzwanzig Uhr vierunddrei\223ig")
  , (TimeOfDay 21 35 0,"einundzwanzig Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 21 36 0,"einundzwanzig Uhr sechsunddrei\223ig")
  , (TimeOfDay 21 37 0,"einundzwanzig Uhr siebenunddrei\223ig")
  , (TimeOfDay 21 38 0,"einundzwanzig Uhr achtunddrei\223ig")
  , (TimeOfDay 21 39 0,"einundzwanzig Uhr neununddrei\223ig")
  , (TimeOfDay 21 40 0,"einundzwanzig Uhr vierzig")
  , (TimeOfDay 21 41 0,"einundzwanzig Uhr einundvierzig")
  , (TimeOfDay 21 42 0,"einundzwanzig Uhr zweiundvierzig")
  , (TimeOfDay 21 43 0,"einundzwanzig Uhr dreiundvierzig")
  , (TimeOfDay 21 44 0,"einundzwanzig Uhr vierundvierzig")
  , (TimeOfDay 21 45 0,"einundzwanzig Uhr f\252nfundvierzig")
  , (TimeOfDay 21 46 0,"einundzwanzig Uhr sechsundvierzig")
  , (TimeOfDay 21 47 0,"einundzwanzig Uhr siebenundvierzig")
  , (TimeOfDay 21 48 0,"einundzwanzig Uhr achtundvierzig")
  , (TimeOfDay 21 49 0,"einundzwanzig Uhr neunundvierzig")
  , (TimeOfDay 21 50 0,"einundzwanzig Uhr f\252nfzig")
  , (TimeOfDay 21 51 0,"einundzwanzig Uhr einundf\252nfzig")
  , (TimeOfDay 21 52 0,"einundzwanzig Uhr zweiundf\252nfzig")
  , (TimeOfDay 21 53 0,"einundzwanzig Uhr dreiundf\252nfzig")
  , (TimeOfDay 21 54 0,"einundzwanzig Uhr vierundf\252nfzig")
  , (TimeOfDay 21 55 0,"einundzwanzig Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 21 56 0,"einundzwanzig Uhr sechsundf\252nfzig")
  , (TimeOfDay 21 57 0,"einundzwanzig Uhr siebenundf\252nfzig")
  , (TimeOfDay 21 58 0,"einundzwanzig Uhr achtundf\252nfzig")
  , (TimeOfDay 21 59 0,"einundzwanzig Uhr neunundf\252nfzig")
  , (TimeOfDay 22 0 0,"zweiundzwanzig Uhr")
  , (TimeOfDay 22 1 0,"zweiundzwanzig Uhr eins")
  , (TimeOfDay 22 2 0,"zweiundzwanzig Uhr zwei")
  , (TimeOfDay 22 3 0,"zweiundzwanzig Uhr drei")
  , (TimeOfDay 22 4 0,"zweiundzwanzig Uhr vier")
  , (TimeOfDay 22 5 0,"zweiundzwanzig Uhr f\252nf")
  , (TimeOfDay 22 6 0,"zweiundzwanzig Uhr sechs")
  , (TimeOfDay 22 7 0,"zweiundzwanzig Uhr sieben")
  , (TimeOfDay 22 8 0,"zweiundzwanzig Uhr acht")
  , (TimeOfDay 22 9 0,"zweiundzwanzig Uhr neun")
  , (TimeOfDay 22 10 0,"zweiundzwanzig Uhr zehn")
  , (TimeOfDay 22 11 0,"zweiundzwanzig Uhr elf")
  , (TimeOfDay 22 12 0,"zweiundzwanzig Uhr zw\246lf")
  , (TimeOfDay 22 13 0,"zweiundzwanzig Uhr dreizehn")
  , (TimeOfDay 22 14 0,"zweiundzwanzig Uhr vierzehn")
  , (TimeOfDay 22 15 0,"zweiundzwanzig Uhr f\252nfzehn")
  , (TimeOfDay 22 16 0,"zweiundzwanzig Uhr sechzehn")
  , (TimeOfDay 22 17 0,"zweiundzwanzig Uhr siebzehn")
  , (TimeOfDay 22 18 0,"zweiundzwanzig Uhr achtzehn")
  , (TimeOfDay 22 19 0,"zweiundzwanzig Uhr neunzehn")
  , (TimeOfDay 22 20 0,"zweiundzwanzig Uhr zwanzig")
  , (TimeOfDay 22 21 0,"zweiundzwanzig Uhr einundzwanzig")
  , (TimeOfDay 22 22 0,"zweiundzwanzig Uhr zweiundzwanzig")
  , (TimeOfDay 22 23 0,"zweiundzwanzig Uhr dreiundzwanzig")
  , (TimeOfDay 22 24 0,"zweiundzwanzig Uhr vierundzwanzig")
  , (TimeOfDay 22 25 0,"zweiundzwanzig Uhr f\252nfundzwanzig")
  , (TimeOfDay 22 26 0,"zweiundzwanzig Uhr sechsundzwanzig")
  , (TimeOfDay 22 27 0,"zweiundzwanzig Uhr siebenundzwanzig")
  , (TimeOfDay 22 28 0,"zweiundzwanzig Uhr achtundzwanzig")
  , (TimeOfDay 22 29 0,"zweiundzwanzig Uhr neunundzwanzig")
  , (TimeOfDay 22 30 0,"zweiundzwanzig Uhr drei\223ig")
  , (TimeOfDay 22 31 0,"zweiundzwanzig Uhr einunddrei\223ig")
  , (TimeOfDay 22 32 0,"zweiundzwanzig Uhr zweiunddrei\223ig")
  , (TimeOfDay 22 33 0,"zweiundzwanzig Uhr dreiunddrei\223ig")
  , (TimeOfDay 22 34 0,"zweiundzwanzig Uhr vierunddrei\223ig")
  , (TimeOfDay 22 35 0,"zweiundzwanzig Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 22 36 0,"zweiundzwanzig Uhr sechsunddrei\223ig")
  , (TimeOfDay 22 37 0,"zweiundzwanzig Uhr siebenunddrei\223ig")
  , (TimeOfDay 22 38 0,"zweiundzwanzig Uhr achtunddrei\223ig")
  , (TimeOfDay 22 39 0,"zweiundzwanzig Uhr neununddrei\223ig")
  , (TimeOfDay 22 40 0,"zweiundzwanzig Uhr vierzig")
  , (TimeOfDay 22 41 0,"zweiundzwanzig Uhr einundvierzig")
  , (TimeOfDay 22 42 0,"zweiundzwanzig Uhr zweiundvierzig")
  , (TimeOfDay 22 43 0,"zweiundzwanzig Uhr dreiundvierzig")
  , (TimeOfDay 22 44 0,"zweiundzwanzig Uhr vierundvierzig")
  , (TimeOfDay 22 45 0,"zweiundzwanzig Uhr f\252nfundvierzig")
  , (TimeOfDay 22 46 0,"zweiundzwanzig Uhr sechsundvierzig")
  , (TimeOfDay 22 47 0,"zweiundzwanzig Uhr siebenundvierzig")
  , (TimeOfDay 22 48 0,"zweiundzwanzig Uhr achtundvierzig")
  , (TimeOfDay 22 49 0,"zweiundzwanzig Uhr neunundvierzig")
  , (TimeOfDay 22 50 0,"zweiundzwanzig Uhr f\252nfzig")
  , (TimeOfDay 22 51 0,"zweiundzwanzig Uhr einundf\252nfzig")
  , (TimeOfDay 22 52 0,"zweiundzwanzig Uhr zweiundf\252nfzig")
  , (TimeOfDay 22 53 0,"zweiundzwanzig Uhr dreiundf\252nfzig")
  , (TimeOfDay 22 54 0,"zweiundzwanzig Uhr vierundf\252nfzig")
  , (TimeOfDay 22 55 0,"zweiundzwanzig Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 22 56 0,"zweiundzwanzig Uhr sechsundf\252nfzig")
  , (TimeOfDay 22 57 0,"zweiundzwanzig Uhr siebenundf\252nfzig")
  , (TimeOfDay 22 58 0,"zweiundzwanzig Uhr achtundf\252nfzig")
  , (TimeOfDay 22 59 0,"zweiundzwanzig Uhr neunundf\252nfzig")
  , (TimeOfDay 23 0 0,"dreiundzwanzig Uhr")
  , (TimeOfDay 23 1 0,"dreiundzwanzig Uhr eins")
  , (TimeOfDay 23 2 0,"dreiundzwanzig Uhr zwei")
  , (TimeOfDay 23 3 0,"dreiundzwanzig Uhr drei")
  , (TimeOfDay 23 4 0,"dreiundzwanzig Uhr vier")
  , (TimeOfDay 23 5 0,"dreiundzwanzig Uhr f\252nf")
  , (TimeOfDay 23 6 0,"dreiundzwanzig Uhr sechs")
  , (TimeOfDay 23 7 0,"dreiundzwanzig Uhr sieben")
  , (TimeOfDay 23 8 0,"dreiundzwanzig Uhr acht")
  , (TimeOfDay 23 9 0,"dreiundzwanzig Uhr neun")
  , (TimeOfDay 23 10 0,"dreiundzwanzig Uhr zehn")
  , (TimeOfDay 23 11 0,"dreiundzwanzig Uhr elf")
  , (TimeOfDay 23 12 0,"dreiundzwanzig Uhr zw\246lf")
  , (TimeOfDay 23 13 0,"dreiundzwanzig Uhr dreizehn")
  , (TimeOfDay 23 14 0,"dreiundzwanzig Uhr vierzehn")
  , (TimeOfDay 23 15 0,"dreiundzwanzig Uhr f\252nfzehn")
  , (TimeOfDay 23 16 0,"dreiundzwanzig Uhr sechzehn")
  , (TimeOfDay 23 17 0,"dreiundzwanzig Uhr siebzehn")
  , (TimeOfDay 23 18 0,"dreiundzwanzig Uhr achtzehn")
  , (TimeOfDay 23 19 0,"dreiundzwanzig Uhr neunzehn")
  , (TimeOfDay 23 20 0,"dreiundzwanzig Uhr zwanzig")
  , (TimeOfDay 23 21 0,"dreiundzwanzig Uhr einundzwanzig")
  , (TimeOfDay 23 22 0,"dreiundzwanzig Uhr zweiundzwanzig")
  , (TimeOfDay 23 23 0,"dreiundzwanzig Uhr dreiundzwanzig")
  , (TimeOfDay 23 24 0,"dreiundzwanzig Uhr vierundzwanzig")
  , (TimeOfDay 23 25 0,"dreiundzwanzig Uhr f\252nfundzwanzig")
  , (TimeOfDay 23 26 0,"dreiundzwanzig Uhr sechsundzwanzig")
  , (TimeOfDay 23 27 0,"dreiundzwanzig Uhr siebenundzwanzig")
  , (TimeOfDay 23 28 0,"dreiundzwanzig Uhr achtundzwanzig")
  , (TimeOfDay 23 29 0,"dreiundzwanzig Uhr neunundzwanzig")
  , (TimeOfDay 23 30 0,"dreiundzwanzig Uhr drei\223ig")
  , (TimeOfDay 23 31 0,"dreiundzwanzig Uhr einunddrei\223ig")
  , (TimeOfDay 23 32 0,"dreiundzwanzig Uhr zweiunddrei\223ig")
  , (TimeOfDay 23 33 0,"dreiundzwanzig Uhr dreiunddrei\223ig")
  , (TimeOfDay 23 34 0,"dreiundzwanzig Uhr vierunddrei\223ig")
  , (TimeOfDay 23 35 0,"dreiundzwanzig Uhr f\252nfunddrei\223ig")
  , (TimeOfDay 23 36 0,"dreiundzwanzig Uhr sechsunddrei\223ig")
  , (TimeOfDay 23 37 0,"dreiundzwanzig Uhr siebenunddrei\223ig")
  , (TimeOfDay 23 38 0,"dreiundzwanzig Uhr achtunddrei\223ig")
  , (TimeOfDay 23 39 0,"dreiundzwanzig Uhr neununddrei\223ig")
  , (TimeOfDay 23 40 0,"dreiundzwanzig Uhr vierzig")
  , (TimeOfDay 23 41 0,"dreiundzwanzig Uhr einundvierzig")
  , (TimeOfDay 23 42 0,"dreiundzwanzig Uhr zweiundvierzig")
  , (TimeOfDay 23 43 0,"dreiundzwanzig Uhr dreiundvierzig")
  , (TimeOfDay 23 44 0,"dreiundzwanzig Uhr vierundvierzig")
  , (TimeOfDay 23 45 0,"dreiundzwanzig Uhr f\252nfundvierzig")
  , (TimeOfDay 23 46 0,"dreiundzwanzig Uhr sechsundvierzig")
  , (TimeOfDay 23 47 0,"dreiundzwanzig Uhr siebenundvierzig")
  , (TimeOfDay 23 48 0,"dreiundzwanzig Uhr achtundvierzig")
  , (TimeOfDay 23 49 0,"dreiundzwanzig Uhr neunundvierzig")
  , (TimeOfDay 23 50 0,"dreiundzwanzig Uhr f\252nfzig")
  , (TimeOfDay 23 51 0,"dreiundzwanzig Uhr einundf\252nfzig")
  , (TimeOfDay 23 52 0,"dreiundzwanzig Uhr zweiundf\252nfzig")
  , (TimeOfDay 23 53 0,"dreiundzwanzig Uhr dreiundf\252nfzig")
  , (TimeOfDay 23 54 0,"dreiundzwanzig Uhr vierundf\252nfzig")
  , (TimeOfDay 23 55 0,"dreiundzwanzig Uhr f\252nfundf\252nfzig")
  , (TimeOfDay 23 56 0,"dreiundzwanzig Uhr sechsundf\252nfzig")
  , (TimeOfDay 23 57 0,"dreiundzwanzig Uhr siebenundf\252nfzig")
  , (TimeOfDay 23 58 0,"dreiundzwanzig Uhr achtundf\252nfzig")
  , (TimeOfDay 23 59 0,"dreiundzwanzig Uhr neunundf\252nfzig")
  ]
